Class: Google::Apis::SecuritycenterV1beta1::AiModel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Contains information about the AI model associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AiModel

Returns a new instance of AiModel.



345
346
347
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 345

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deployment_platformString

The platform on which the model is deployed. Corresponds to the JSON property deploymentPlatform

Returns:

  • (String)


308
309
310
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 308

def deployment_platform
  @deployment_platform
end

#display_nameString

The user defined display name of model. Ex. baseline-classification-model Corresponds to the JSON property displayName

Returns:

  • (String)


313
314
315
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 313

def display_name
  @display_name
end

#domainString

The domain of the model, for example, “image-classification”. Corresponds to the JSON property domain

Returns:

  • (String)


318
319
320
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 318

def domain
  @domain
end

#libraryString

The name of the model library, for example, “transformers”. Corresponds to the JSON property library

Returns:

  • (String)


323
324
325
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 323

def library
  @library
end

#locationString

The region in which the model is used, for example, “us-central1”. Corresponds to the JSON property location

Returns:

  • (String)


328
329
330
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 328

def location
  @location
end

#nameString

The name of the AI model, for example, "gemini:1.0.0". Corresponds to the JSON property name

Returns:

  • (String)


333
334
335
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 333

def name
  @name
end

#publisherString

The publisher of the model, for example, “google” or “nvidia”. Corresponds to the JSON property publisher

Returns:

  • (String)


338
339
340
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 338

def publisher
  @publisher
end

#usage_categoryString

The purpose of the model, for example, "Inteference" or "Training". Corresponds to the JSON property usageCategory

Returns:

  • (String)


343
344
345
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 343

def usage_category
  @usage_category
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



350
351
352
353
354
355
356
357
358
359
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 350

def update!(**args)
  @deployment_platform = args[:deployment_platform] if args.key?(:deployment_platform)
  @display_name = args[:display_name] if args.key?(:display_name)
  @domain = args[:domain] if args.key?(:domain)
  @library = args[:library] if args.key?(:library)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @publisher = args[:publisher] if args.key?(:publisher)
  @usage_category = args[:usage_category] if args.key?(:usage_category)
end