Class: Google::Apis::SecuritycenterV1beta1::Asset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Security Command Center representation of a Google Cloud resource. The Asset is a Security Command Center resource that captures information about a single Google Cloud resource. All modifications to an Asset are only within the context of Security Command Center and don't affect the referenced Google Cloud resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Asset

Returns a new instance of Asset.



550
551
552
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 550

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

The time at which the asset was created in Security Command Center. Corresponds to the JSON property createTime

Returns:

  • (String)


515
516
517
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 515

def create_time
  @create_time
end

#nameString

The relative resource name of this asset. See: https://cloud.google.com/apis/ design/resource_names#relative_resource_name Example: "organizations/ organization_id/assets/asset_id". Corresponds to the JSON property name

Returns:

  • (String)


522
523
524
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 522

def name
  @name
end

#resource_propertiesHash<String,Object>

Resource managed properties. These properties are managed and defined by the Google Cloud resource and cannot be modified by the user. Corresponds to the JSON property resourceProperties

Returns:



528
529
530
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 528

def resource_properties
  @resource_properties
end

#security_center_propertiesGoogle::Apis::SecuritycenterV1beta1::SecurityCenterProperties

Security Command Center managed properties. These properties are managed by Security Command Center and cannot be modified by the user. Corresponds to the JSON property securityCenterProperties



534
535
536
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 534

def security_center_properties
  @security_center_properties
end

#security_marksGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1beta1SecurityMarks

User specified security marks that are attached to the parent Security Command Center resource. Security marks are scoped within a Security Command Center organization -- they can be modified and viewed by all users who have proper permissions on the organization. Corresponds to the JSON property securityMarks



542
543
544
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 542

def security_marks
  @security_marks
end

#update_timeString

The time at which the asset was last updated, added, or deleted in Security Command Center. Corresponds to the JSON property updateTime

Returns:

  • (String)


548
549
550
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 548

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



555
556
557
558
559
560
561
562
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 555

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @name = args[:name] if args.key?(:name)
  @resource_properties = args[:resource_properties] if args.key?(:resource_properties)
  @security_center_properties = args[:security_center_properties] if args.key?(:security_center_properties)
  @security_marks = args[:security_marks] if args.key?(:security_marks)
  @update_time = args[:update_time] if args.key?(:update_time)
end