Class: Google::Apis::SecuritycenterV1beta1::AzureMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Azure metadata associated with the resource, only applicable if the finding's cloud provider is Microsoft Azure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AzureMetadata

Returns a new instance of AzureMetadata.



897
898
899
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 897

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#management_groupsArray<Google::Apis::SecuritycenterV1beta1::AzureManagementGroup>

A list of Azure management groups associated with the resource, ordered from lowest level (closest to the subscription) to highest level. Corresponds to the JSON property managementGroups



880
881
882
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 880

def management_groups
  @management_groups
end

#resource_groupGoogle::Apis::SecuritycenterV1beta1::AzureResourceGroup

Represents an Azure resource group. Corresponds to the JSON property resourceGroup



885
886
887
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 885

def resource_group
  @resource_group
end

#subscriptionGoogle::Apis::SecuritycenterV1beta1::AzureSubscription

Represents an Azure subscription. Corresponds to the JSON property subscription



890
891
892
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 890

def subscription
  @subscription
end

#tenantGoogle::Apis::SecuritycenterV1beta1::AzureTenant

Represents a Microsoft Entra tenant. Corresponds to the JSON property tenant



895
896
897
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 895

def tenant
  @tenant
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



902
903
904
905
906
907
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 902

def update!(**args)
  @management_groups = args[:management_groups] if args.key?(:management_groups)
  @resource_group = args[:resource_group] if args.key?(:resource_group)
  @subscription = args[:subscription] if args.key?(:subscription)
  @tenant = args[:tenant] if args.key?(:tenant)
end