Class: Google::Apis::SecuritycenterV1beta1::CloudArmor
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::CloudArmor
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Fields related to Google Cloud Armor findings.
Instance Attribute Summary collapse
-
#adaptive_protection ⇒ Google::Apis::SecuritycenterV1beta1::AdaptiveProtection
Information about Google Cloud Armor Adaptive Protection.
-
#attack ⇒ Google::Apis::SecuritycenterV1beta1::Attack
Information about DDoS attack volume and classification.
-
#duration ⇒ String
Duration of attack from the start until the current moment (updated every 5 minutes).
-
#requests ⇒ Google::Apis::SecuritycenterV1beta1::Requests
Information about the requests relevant to the finding.
-
#security_policy ⇒ Google::Apis::SecuritycenterV1beta1::SecurityPolicy
Information about the Google Cloud Armor security policy relevant to the finding.
-
#threat_vector ⇒ String
Distinguish between volumetric & protocol DDoS attack and application layer attacks.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudArmor
constructor
A new instance of CloudArmor.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudArmor
Returns a new instance of CloudArmor.
1282 1283 1284 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1282 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adaptive_protection ⇒ Google::Apis::SecuritycenterV1beta1::AdaptiveProtection
Information about Google Cloud Armor Adaptive Protection.
Corresponds to the JSON property adaptiveProtection
1251 1252 1253 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1251 def adaptive_protection @adaptive_protection end |
#attack ⇒ Google::Apis::SecuritycenterV1beta1::Attack
Information about DDoS attack volume and classification.
Corresponds to the JSON property attack
1256 1257 1258 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1256 def attack @attack end |
#duration ⇒ String
Duration of attack from the start until the current moment (updated every 5
minutes).
Corresponds to the JSON property duration
1262 1263 1264 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1262 def duration @duration end |
#requests ⇒ Google::Apis::SecuritycenterV1beta1::Requests
Information about the requests relevant to the finding.
Corresponds to the JSON property requests
1267 1268 1269 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1267 def requests @requests end |
#security_policy ⇒ Google::Apis::SecuritycenterV1beta1::SecurityPolicy
Information about the Google Cloud Armor security policy relevant to the finding.
Corresponds to the JSON property securityPolicy
1273 1274 1275 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1273 def security_policy @security_policy end |
#threat_vector ⇒ String
Distinguish between volumetric & protocol DDoS attack and application layer
attacks. For example, "L3_4" for Layer 3 and Layer 4 DDoS attacks, or "L_7"
for Layer 7 DDoS attacks.
Corresponds to the JSON property threatVector
1280 1281 1282 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1280 def threat_vector @threat_vector end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1287 1288 1289 1290 1291 1292 1293 1294 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1287 def update!(**args) @adaptive_protection = args[:adaptive_protection] if args.key?(:adaptive_protection) @attack = args[:attack] if args.key?(:attack) @duration = args[:duration] if args.key?(:duration) @requests = args[:requests] if args.key?(:requests) @security_policy = args[:security_policy] if args.key?(:security_policy) @threat_vector = args[:threat_vector] if args.key?(:threat_vector) end |