Class: Google::Apis::SecuritycenterV1beta1::CloudDlpInspection
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::CloudDlpInspection
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Details about the Cloud Data Loss Prevention (Cloud DLP) inspection job that produced the finding.
Instance Attribute Summary collapse
-
#full_scan ⇒ Boolean
(also: #full_scan?)
Whether Cloud DLP scanned the complete resource or a sampled subset.
-
#info_type ⇒ String
The type of information (or infoType) found, for example,
EMAIL_ADDRESSorSTREET_ADDRESS. -
#info_type_count ⇒ Fixnum
The number of times Cloud DLP found this infoType within this job and resource.
-
#inspect_job ⇒ String
Name of the inspection job, for example,
projects/123/locations/europe/ dlpJobs/i-8383929.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudDlpInspection
constructor
A new instance of CloudDlpInspection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudDlpInspection
Returns a new instance of CloudDlpInspection.
1435 1436 1437 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1435 def initialize(**args) update!(**args) end |
Instance Attribute Details
#full_scan ⇒ Boolean Also known as: full_scan?
Whether Cloud DLP scanned the complete resource or a sampled subset.
Corresponds to the JSON property fullScan
1415 1416 1417 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1415 def full_scan @full_scan end |
#info_type ⇒ String
The type of information (or infoType) found, for example, EMAIL_ADDRESS or STREET_ADDRESS.
Corresponds to the JSON property infoType
1422 1423 1424 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1422 def info_type @info_type end |
#info_type_count ⇒ Fixnum
The number of times Cloud DLP found this infoType within this job and resource.
Corresponds to the JSON property infoTypeCount
1427 1428 1429 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1427 def info_type_count @info_type_count end |
#inspect_job ⇒ String
Name of the inspection job, for example, projects/123/locations/europe/
dlpJobs/i-8383929.
Corresponds to the JSON property inspectJob
1433 1434 1435 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1433 def inspect_job @inspect_job end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1440 1441 1442 1443 1444 1445 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1440 def update!(**args) @full_scan = args[:full_scan] if args.key?(:full_scan) @info_type = args[:info_type] if args.key?(:info_type) @info_type_count = args[:info_type_count] if args.key?(:info_type_count) @inspect_job = args[:inspect_job] if args.key?(:inspect_job) end |