Class: Google::Apis::SecuritycenterV1beta1::CloudLoggingEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Metadata taken from a Cloud Logging LogEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudLoggingEntry

Returns a new instance of CloudLoggingEntry.



1439
1440
1441
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1439

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#insert_idString

A unique identifier for the log entry. Corresponds to the JSON property insertId

Returns:

  • (String)


1418
1419
1420
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1418

def insert_id
  @insert_id
end

#log_idString

The type of the log (part of log_name. log_name is the resource name of the log to which this log entry belongs). For example: cloudresourcemanager. googleapis.com/activity. Note that this field is not URL-encoded, unlike the LOG_ID field in LogEntry. Corresponds to the JSON property logId

Returns:

  • (String)


1426
1427
1428
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1426

def log_id
  @log_id
end

#resource_containerString

The organization, folder, or project of the monitored resource that produced this log entry. Corresponds to the JSON property resourceContainer

Returns:

  • (String)


1432
1433
1434
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1432

def resource_container
  @resource_container
end

#timestampString

The time the event described by the log entry occurred. Corresponds to the JSON property timestamp

Returns:

  • (String)


1437
1438
1439
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1437

def timestamp
  @timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1444
1445
1446
1447
1448
1449
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1444

def update!(**args)
  @insert_id = args[:insert_id] if args.key?(:insert_id)
  @log_id = args[:log_id] if args.key?(:log_id)
  @resource_container = args[:resource_container] if args.key?(:resource_container)
  @timestamp = args[:timestamp] if args.key?(:timestamp)
end