Class: Google::Apis::SecuritycenterV1beta1::Container

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Container associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Container

Returns a new instance of Container.



1668
1669
1670
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1668

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

The time that the container was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1644
1645
1646
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1644

def create_time
  @create_time
end

#image_idString

Optional container image ID, if provided by the container runtime. Uniquely identifies the container image launched using a container image digest. Corresponds to the JSON property imageId

Returns:

  • (String)


1650
1651
1652
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1650

def image_id
  @image_id
end

#labelsArray<Google::Apis::SecuritycenterV1beta1::Label>

Container labels, as provided by the container runtime. Corresponds to the JSON property labels



1655
1656
1657
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1655

def labels
  @labels
end

#nameString

Name of the container. Corresponds to the JSON property name

Returns:

  • (String)


1660
1661
1662
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1660

def name
  @name
end

#uriString

Container image URI provided when configuring a pod or container. This string can identify a container image version using mutable tags. Corresponds to the JSON property uri

Returns:

  • (String)


1666
1667
1668
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1666

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1673
1674
1675
1676
1677
1678
1679
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1673

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @image_id = args[:image_id] if args.key?(:image_id)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @uri = args[:uri] if args.key?(:uri)
end