Class: Google::Apis::SecuritycenterV1beta1::ExternalExposure

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Details about the externally exposed resource associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExternalExposure

Returns a new instance of ExternalExposure.



2624
2625
2626
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2624

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_bucketString

The full resource name of the load balancer backend bucket, for example, "// compute.googleapis.com/projects/project-id/global/backendBuckets/name" Corresponds to the JSON property backendBucket

Returns:

  • (String)


2507
2508
2509
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2507

def backend_bucket
  @backend_bucket
end

#backend_serviceString

The full resource name of load balancer backend service, for example, "// compute.googleapis.com/projects/project-id/global/backendServices/name". Corresponds to the JSON property backendService

Returns:

  • (String)


2513
2514
2515
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2513

def backend_service
  @backend_service
end

#exposed_applicationString

The name and version of the exposed web application, for example, "Jenkins 2. 184". Corresponds to the JSON property exposedApplication

Returns:

  • (String)


2519
2520
2521
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2519

def exposed_application
  @exposed_application
end

#exposed_endpointString

The resource which is running the exposed service, for example, "//compute. googleapis.com/projects/project-id/zones/zone/instances/instance.” Corresponds to the JSON property exposedEndpoint

Returns:

  • (String)


2525
2526
2527
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2525

def exposed_endpoint
  @exposed_endpoint
end

#exposed_serviceString

The name and version of the service, for example, "Jupyter Notebook 6.14.0". Corresponds to the JSON property exposedService

Returns:

  • (String)


2530
2531
2532
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2530

def exposed_service
  @exposed_service
end

#forwarding_ruleString

The full resource name of the forwarding rule, for example, "//compute. googleapis.com/projects/project-id/global/forwardingRules/forwarding-rule- name". Corresponds to the JSON property forwardingRule

Returns:

  • (String)


2537
2538
2539
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2537

def forwarding_rule
  @forwarding_rule
end

#hostname_uriString

Hostname of the exposed application, for example, "https://test-app.a.run.app/" Corresponds to the JSON property hostnameUri

Returns:

  • (String)


2542
2543
2544
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2542

def hostname_uri
  @hostname_uri
end

#http_responseArray<Google::Apis::SecuritycenterV1beta1::HttpResponse>

The http response returned by the web application. Corresponds to the JSON property httpResponse



2547
2548
2549
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2547

def http_response
  @http_response
end

#instance_groupString

The full resource name of the instance group, for example, "//compute. googleapis.com/projects/project-id/global/instanceGroups/name". Corresponds to the JSON property instanceGroup

Returns:

  • (String)


2553
2554
2555
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2553

def instance_group
  @instance_group
end

#internal_backend_serviceString

The full resource name of load balancer backend service in the internal project having resource exposed via PSC, for example, "//compute.googleapis. com/projects/project-id/global/backendServices/name". Corresponds to the JSON property internalBackendService

Returns:

  • (String)


2560
2561
2562
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2560

def internal_backend_service
  @internal_backend_service
end

#load_balancer_firewall_policyString

The full resource name of the load balancer firewall policy, for example, "// compute.googleapis.com/projects/project-id/global/firewallPolicies/policy- name". Corresponds to the JSON property loadBalancerFirewallPolicy

Returns:

  • (String)


2567
2568
2569
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2567

def load_balancer_firewall_policy
  @load_balancer_firewall_policy
end

#network_endpoint_groupString

The full resource name of the network endpoint group, for example, "//compute. googleapis.com/projects/project-id/global/networkEndpointGroups/name". Corresponds to the JSON property networkEndpointGroup

Returns:

  • (String)


2573
2574
2575
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2573

def network_endpoint_group
  @network_endpoint_group
end

#network_ingress_firewall_policyString

The full resource name of the network ingress firewall policy, for example, "// compute.googleapis.com/projects/project-id/global/firewallPolicies/name". Corresponds to the JSON property networkIngressFirewallPolicy

Returns:

  • (String)


2579
2580
2581
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2579

def network_ingress_firewall_policy
  @network_ingress_firewall_policy
end

#private_ip_addressString

Private IP address of the exposed endpoint. Corresponds to the JSON property privateIpAddress

Returns:

  • (String)


2584
2585
2586
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2584

def private_ip_address
  @private_ip_address
end

#private_portString

Port number associated with private IP address. Corresponds to the JSON property privatePort

Returns:

  • (String)


2589
2590
2591
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2589

def private_port
  @private_port
end

#psc_network_attachmentString

The full resource name of the PSC (Private Service Connect) network attachment that network interface controller is attached to, for example, "//compute. googleapis.com/projects/project-id/regions/region/networkAttachments/name " Corresponds to the JSON property pscNetworkAttachment

Returns:

  • (String)


2597
2598
2599
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2597

def psc_network_attachment
  @psc_network_attachment
end

#psc_service_attachmentString

The full resource name of the PSC (Private Service Connect) service attachment that the load balancer network endpoint group targets, for example, "//compute. googleapis.com/projects/project-id/regions/region/serviceAttachments/name " Corresponds to the JSON property pscServiceAttachment

Returns:

  • (String)


2605
2606
2607
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2605

def psc_service_attachment
  @psc_service_attachment
end

#public_ip_addressString

Public IP address of the exposed endpoint. Corresponds to the JSON property publicIpAddress

Returns:

  • (String)


2610
2611
2612
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2610

def public_ip_address
  @public_ip_address
end

#public_portString

Public port number of the exposed endpoint. Corresponds to the JSON property publicPort

Returns:

  • (String)


2615
2616
2617
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2615

def public_port
  @public_port
end

#service_firewall_policyString

The full resource name of the firewall policy of the exposed service, for example, "//compute.googleapis.com/projects/project-id/global/ firewallPolicies/policy-name". Corresponds to the JSON property serviceFirewallPolicy

Returns:

  • (String)


2622
2623
2624
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2622

def service_firewall_policy
  @service_firewall_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2629
2630
2631
2632
2633
2634
2635
2636
2637
2638
2639
2640
2641
2642
2643
2644
2645
2646
2647
2648
2649
2650
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2629

def update!(**args)
  @backend_bucket = args[:backend_bucket] if args.key?(:backend_bucket)
  @backend_service = args[:backend_service] if args.key?(:backend_service)
  @exposed_application = args[:exposed_application] if args.key?(:exposed_application)
  @exposed_endpoint = args[:exposed_endpoint] if args.key?(:exposed_endpoint)
  @exposed_service = args[:exposed_service] if args.key?(:exposed_service)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @hostname_uri = args[:hostname_uri] if args.key?(:hostname_uri)
  @http_response = args[:http_response] if args.key?(:http_response)
  @instance_group = args[:instance_group] if args.key?(:instance_group)
  @internal_backend_service = args[:internal_backend_service] if args.key?(:internal_backend_service)
  @load_balancer_firewall_policy = args[:load_balancer_firewall_policy] if args.key?(:load_balancer_firewall_policy)
  @network_endpoint_group = args[:network_endpoint_group] if args.key?(:network_endpoint_group)
  @network_ingress_firewall_policy = args[:network_ingress_firewall_policy] if args.key?(:network_ingress_firewall_policy)
  @private_ip_address = args[:private_ip_address] if args.key?(:private_ip_address)
  @private_port = args[:private_port] if args.key?(:private_port)
  @psc_network_attachment = args[:psc_network_attachment] if args.key?(:psc_network_attachment)
  @psc_service_attachment = args[:psc_service_attachment] if args.key?(:psc_service_attachment)
  @public_ip_address = args[:public_ip_address] if args.key?(:public_ip_address)
  @public_port = args[:public_port] if args.key?(:public_port)
  @service_firewall_policy = args[:service_firewall_policy] if args.key?(:service_firewall_policy)
end