Class: Google::Apis::SecuritycenterV1beta1::Framework

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Compliance framework associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Framework

Returns a new instance of Framework.



3308
3309
3310
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3308

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoryArray<String>

Category of the framework associated with the finding. E.g. Security Benchmark, or Assured Workloads Corresponds to the JSON property category

Returns:

  • (Array<String>)


3282
3283
3284
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3282

def category
  @category
end

#controlsArray<Google::Apis::SecuritycenterV1beta1::Control>

The controls associated with the framework. Corresponds to the JSON property controls



3287
3288
3289
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3287

def controls
  @controls
end

#display_nameString

Display name of the framework. For a standard framework, this will look like e. g. PCI DSS 3.2.1, whereas for a custom framework it can be a user defined string like MyFramework Corresponds to the JSON property displayName

Returns:

  • (String)


3294
3295
3296
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3294

def display_name
  @display_name
end

#nameString

Name of the framework associated with the finding Corresponds to the JSON property name

Returns:

  • (String)


3299
3300
3301
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3299

def name
  @name
end

#typeString

Type of the framework associated with the finding, to specify whether the framework is built-in (pre-defined and immutable) or a custom framework defined by the customer (equivalent to security posture) Corresponds to the JSON property type

Returns:

  • (String)


3306
3307
3308
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3306

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3313
3314
3315
3316
3317
3318
3319
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3313

def update!(**args)
  @category = args[:category] if args.key?(:category)
  @controls = args[:controls] if args.key?(:controls)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
end