Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1BigQueryExport

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Configures how to deliver Findings to BigQuery Instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV1BigQueryExport

Returns a new instance of GoogleCloudSecuritycenterV1BigQueryExport.



3447
3448
3449
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3447

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time at which the BigQuery export was created. This field is set by the server and will be ignored if provided on export on creation. Corresponds to the JSON property createTime

Returns:

  • (String)


3389
3390
3391
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3389

def create_time
  @create_time
end

#datasetString

The dataset to write findings' updates to. Its format is "projects/[project_id] /datasets/[bigquery_dataset_id]". BigQuery Dataset unique ID must contain only letters (a-z, A-Z), numbers (0-9), or underscores (_). Corresponds to the JSON property dataset

Returns:

  • (String)


3396
3397
3398
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3396

def dataset
  @dataset
end

#descriptionString

The description of the export (max of 1024 characters). Corresponds to the JSON property description

Returns:

  • (String)


3401
3402
3403
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3401

def description
  @description
end

#filterString

Expression that defines the filter to apply across create/update events of findings. The expression is a list of zero or more restrictions combined via logical operators AND and OR. Parentheses are supported, and OR has higher precedence than AND. Restrictions have the form and may have a - character in front of them to indicate negation. The fields map to those defined in the corresponding resource. The supported operators are: * = for all value types. * >, <, >=, <= for integer values. * :, meaning substring matching, for strings. The supported value types are: * string literals in quotes. * integer literals without quotes. * boolean literals true and false without quotes. Corresponds to the JSON property filter

Returns:

  • (String)


3415
3416
3417
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3415

def filter
  @filter
end

#most_recent_editorString

Output only. Email address of the user who last edited the BigQuery export. This field is set by the server and will be ignored if provided on export creation or update. Corresponds to the JSON property mostRecentEditor

Returns:

  • (String)


3422
3423
3424
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3422

def most_recent_editor
  @most_recent_editor
end

#nameString

The relative resource name of this export. See: https://cloud.google.com/apis/ design/resource_names#relative_resource_name. Example format: "organizations/ organization_id/bigQueryExports/export_id" Example format: "folders/ folder_id/bigQueryExports/export_id" Example format: "projects/project_id/ bigQueryExports/export_id" This field is provided in responses, and is ignored when provided in create requests. Corresponds to the JSON property name

Returns:

  • (String)


3432
3433
3434
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3432

def name
  @name
end

#principalString

Output only. The service account that needs permission to create table and upload data to the BigQuery dataset. Corresponds to the JSON property principal

Returns:

  • (String)


3438
3439
3440
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3438

def principal
  @principal
end

#update_timeString

Output only. The most recent time at which the BigQuery export was updated. This field is set by the server and will be ignored if provided on export creation or update. Corresponds to the JSON property updateTime

Returns:

  • (String)


3445
3446
3447
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3445

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3452

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dataset = args[:dataset] if args.key?(:dataset)
  @description = args[:description] if args.key?(:description)
  @filter = args[:filter] if args.key?(:filter)
  @most_recent_editor = args[:most_recent_editor] if args.key?(:most_recent_editor)
  @name = args[:name] if args.key?(:name)
  @principal = args[:principal] if args.key?(:principal)
  @update_time = args[:update_time] if args.key?(:update_time)
end