Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1MuteConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

A mute config is a Cloud SCC resource that contains the configuration to mute create/update events of findings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV1MuteConfig

Returns a new instance of GoogleCloudSecuritycenterV1MuteConfig.



3888
3889
3890
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3888

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time at which the mute config was created. This field is set by the server and will be ignored if provided on config creation. Corresponds to the JSON property createTime

Returns:

  • (String)


3824
3825
3826
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3824

def create_time
  @create_time
end

#descriptionString

A description of the mute config. Corresponds to the JSON property description

Returns:

  • (String)


3829
3830
3831
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3829

def description
  @description
end

#display_nameString

The human readable name to be displayed for the mute config. Corresponds to the JSON property displayName

Returns:

  • (String)


3834
3835
3836
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3834

def display_name
  @display_name
end

#expiry_timeString

Optional. The expiry of the mute config. Only applicable for dynamic configs. If the expiry is set, when the config expires, it is removed from all findings. Corresponds to the JSON property expiryTime

Returns:

  • (String)


3840
3841
3842
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3840

def expiry_time
  @expiry_time
end

#filterString

Required. An expression that defines the filter to apply across create/update events of findings. While creating a filter string, be mindful of the scope in which the mute configuration is being created. E.g., If a filter contains project = X but is created under the project = Y scope, it might not match any findings. The following field and operator combinations are supported: * severity: =, : * category: =, : * resource.name: =, : * resource. project_name: =, : * resource.project_display_name: =, : * resource. folders.resource_folder: =, : * resource.parent_name: =, : * resource. parent_display_name: =, : * resource.type: =, : * finding_class: =, : * indicator.ip_addresses: =, : * indicator.domains: =, : Corresponds to the JSON property filter

Returns:

  • (String)


3854
3855
3856
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3854

def filter
  @filter
end

#most_recent_editorString

Output only. Email address of the user who last edited the mute config. This field is set by the server and will be ignored if provided on config creation or update. Corresponds to the JSON property mostRecentEditor

Returns:

  • (String)


3861
3862
3863
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3861

def most_recent_editor
  @most_recent_editor
end

#nameString

This field will be ignored if provided on config creation. Format organizations/organization/muteConfigs/mute_config`folders/`folder`/ muteConfigs/`mute_config projects/project/muteConfigs/mute_config` organizations/`organization`/locations/global/muteConfigs/`mute_config folders/folder/locations/global/muteConfigs/mute_config`projects/` project`/locations/global/muteConfigs/`mute_config Corresponds to the JSON property name

Returns:

  • (String)


3871
3872
3873
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3871

def name
  @name
end

#typeString

Optional. The type of the mute config, which determines what type of mute state the config affects. The static mute state takes precedence over the dynamic mute state. Immutable after creation. STATIC by default if not set during creation. Corresponds to the JSON property type

Returns:

  • (String)


3879
3880
3881
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3879

def type
  @type
end

#update_timeString

Output only. The most recent time at which the mute config was updated. This field is set by the server and will be ignored if provided on config creation or update. Corresponds to the JSON property updateTime

Returns:

  • (String)


3886
3887
3888
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3886

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3893
3894
3895
3896
3897
3898
3899
3900
3901
3902
3903
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3893

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @expiry_time = args[:expiry_time] if args.key?(:expiry_time)
  @filter = args[:filter] if args.key?(:filter)
  @most_recent_editor = args[:most_recent_editor] if args.key?(:most_recent_editor)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end