Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1Property
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1Property
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
An individual name-value pair that defines a custom source property.
Instance Attribute Summary collapse
-
#name ⇒ String
Name of the property for the custom output.
-
#value_expression ⇒ Google::Apis::SecuritycenterV1beta1::Expr
Represents a textual expression in the Common Expression Language (CEL) syntax.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1Property
constructor
A new instance of GoogleCloudSecuritycenterV1Property.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1Property
Returns a new instance of GoogleCloudSecuritycenterV1Property.
3910 3911 3912 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3910 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Name of the property for the custom output.
Corresponds to the JSON property name
3889 3890 3891 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3889 def name @name end |
#value_expression ⇒ Google::Apis::SecuritycenterV1beta1::Expr
Represents a textual expression in the Common Expression Language (CEL) syntax.
CEL is a C-like expression language. The syntax and semantics of CEL are
documented at https://github.com/google/cel-spec. Example (Comparison): title:
"Summary size limit" description: "Determines if a summary is less than 100
chars" expression: "document.summary.size() < 100" Example (Equality): title: "
Requestor is owner" description: "Determines if requestor is the document
owner" expression: "document.owner == request.auth.claims.email" Example (
Logic): title: "Public documents" description: "Determine whether the document
should be publicly visible" expression: "document.type != 'private' &&
document.type != 'internal'" Example (Data Manipulation): title: "Notification
string" description: "Create a notification string with a timestamp."
expression: "'New message received at ' + string(document.create_time)" The
exact variables and functions that may be referenced within an expression are
determined by the service that evaluates it. See the service documentation for
additional information.
Corresponds to the JSON property valueExpression
3908 3909 3910 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3908 def value_expression @value_expression end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3915 3916 3917 3918 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3915 def update!(**args) @name = args[:name] if args.key?(:name) @value_expression = args[:value_expression] if args.key?(:value_expression) end |