Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1ResourceValueConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

A resource value configuration (RVC) is a mapping configuration of user's resources to resource values. Used in Attack path simulations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV1ResourceValueConfig

Returns a new instance of GoogleCloudSecuritycenterV1ResourceValueConfig.



4169
4170
4171
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4169

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_providerString

Cloud provider this configuration applies to Corresponds to the JSON property cloudProvider

Returns:

  • (String)


4104
4105
4106
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4104

def cloud_provider
  @cloud_provider
end

#create_timeString

Output only. Timestamp this resource value configuration was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4109
4110
4111
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4109

def create_time
  @create_time
end

#descriptionString

Description of the resource value configuration. Corresponds to the JSON property description

Returns:

  • (String)


4114
4115
4116
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4114

def description
  @description
end

#nameString

Name for the resource value configuration Corresponds to the JSON property name

Returns:

  • (String)


4119
4120
4121
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4119

def name
  @name
end

#resource_labels_selectorHash<String,String>

List of resource labels to search for, evaluated with AND. For example, " resource_labels_selector":"key": "value", "env": "prod"`will match resources with labels "key": "value"AND"env": "prod" https://cloud.google. com/resource-manager/docs/creating-managing-labels Corresponds to the JSON propertyresourceLabelsSelector`

Returns:

  • (Hash<String,String>)


4127
4128
4129
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4127

def resource_labels_selector
  @resource_labels_selector
end

#resource_typeString

Apply resource_value only to resources that match resource_type. resource_type will be checked with AND of other resources. For example, "storage. googleapis.com/Bucket" with resource_value "HIGH" will apply "HIGH" value only to "storage.googleapis.com/Bucket" resources. Corresponds to the JSON property resourceType

Returns:

  • (String)


4135
4136
4137
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4135

def resource_type
  @resource_type
end

#resource_valueString

Required. Resource value level this expression represents Corresponds to the JSON property resourceValue

Returns:

  • (String)


4140
4141
4142
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4140

def resource_value
  @resource_value
end

#scopeString

Project or folder to scope this configuration to. For example, "project/456" would apply this configuration only to resources in "project/456" scope will be checked with AND of other resources. Corresponds to the JSON property scope

Returns:

  • (String)


4147
4148
4149
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4147

def scope
  @scope
end

#sensitive_data_protection_mappingGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1SensitiveDataProtectionMapping

Resource value mapping for Sensitive Data Protection findings. If any of these mappings have a resource value that is not unspecified, the resource_value field will be ignored when reading this configuration. Corresponds to the JSON property sensitiveDataProtectionMapping



4154
4155
4156
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4154

def sensitive_data_protection_mapping
  @sensitive_data_protection_mapping
end

#tag_valuesArray<String>

Required. Tag values combined with AND to check against. For Google Cloud resources, they are tag value IDs in the form of "tagValues/123". Example: [ " tagValues/123", "tagValues/456", "tagValues/789" ] https://cloud.google.com/ resource-manager/docs/tags/tags-creating-and-managing Corresponds to the JSON property tagValues

Returns:

  • (Array<String>)


4162
4163
4164
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4162

def tag_values
  @tag_values
end

#update_timeString

Output only. Timestamp this resource value configuration was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4167
4168
4169
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4167

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4174
4175
4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4174

def update!(**args)
  @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @resource_labels_selector = args[:resource_labels_selector] if args.key?(:resource_labels_selector)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @resource_value = args[:resource_value] if args.key?(:resource_value)
  @scope = args[:scope] if args.key?(:scope)
  @sensitive_data_protection_mapping = args[:sensitive_data_protection_mapping] if args.key?(:sensitive_data_protection_mapping)
  @tag_values = args[:tag_values] if args.key?(:tag_values)
  @update_time = args[:update_time] if args.key?(:update_time)
end