Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2AccessReview

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Conveys information about a Kubernetes access review (such as one returned by a kubectl auth can-i command) that was involved in a finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AccessReview

Returns a new instance of GoogleCloudSecuritycenterV2AccessReview.



5106
5107
5108
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5106

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#groupString

The API group of the resource. "*" means all. Corresponds to the JSON property group

Returns:

  • (String)


5072
5073
5074
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5072

def group
  @group
end

#nameString

The name of the resource being requested. Empty means all. Corresponds to the JSON property name

Returns:

  • (String)


5077
5078
5079
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5077

def name
  @name
end

#nsString

Namespace of the action being requested. Currently, there is no distinction between no namespace and all namespaces. Both are represented by "" (empty). Corresponds to the JSON property ns

Returns:

  • (String)


5083
5084
5085
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5083

def ns
  @ns
end

#resourceString

The optional resource type requested. "*" means all. Corresponds to the JSON property resource

Returns:

  • (String)


5088
5089
5090
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5088

def resource
  @resource
end

#subresourceString

The optional subresource type. Corresponds to the JSON property subresource

Returns:

  • (String)


5093
5094
5095
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5093

def subresource
  @subresource
end

#verbString

A Kubernetes resource API verb, like get, list, watch, create, update, delete, proxy. "*" means all. Corresponds to the JSON property verb

Returns:

  • (String)


5099
5100
5101
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5099

def verb
  @verb
end

#versionString

The API version of the resource. "*" means all. Corresponds to the JSON property version

Returns:

  • (String)


5104
5105
5106
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5104

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5111
5112
5113
5114
5115
5116
5117
5118
5119
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5111

def update!(**args)
  @group = args[:group] if args.key?(:group)
  @name = args[:name] if args.key?(:name)
  @ns = args[:ns] if args.key?(:ns)
  @resource = args[:resource] if args.key?(:resource)
  @subresource = args[:subresource] if args.key?(:subresource)
  @verb = args[:verb] if args.key?(:verb)
  @version = args[:version] if args.key?(:version)
end