Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2AiModel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Contains information about the AI model associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AiModel

Returns a new instance of GoogleCloudSecuritycenterV2AiModel.



5316
5317
5318
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5316

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deployment_platformString

The platform on which the model is deployed. Corresponds to the JSON property deploymentPlatform

Returns:

  • (String)


5279
5280
5281
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5279

def deployment_platform
  @deployment_platform
end

#display_nameString

The user defined display name of model. Ex. baseline-classification-model Corresponds to the JSON property displayName

Returns:

  • (String)


5284
5285
5286
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5284

def display_name
  @display_name
end

#domainString

The domain of the model, for example, “image-classification”. Corresponds to the JSON property domain

Returns:

  • (String)


5289
5290
5291
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5289

def domain
  @domain
end

#libraryString

The name of the model library, for example, “transformers”. Corresponds to the JSON property library

Returns:

  • (String)


5294
5295
5296
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5294

def library
  @library
end

#locationString

The region in which the model is used, for example, “us-central1”. Corresponds to the JSON property location

Returns:

  • (String)


5299
5300
5301
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5299

def location
  @location
end

#nameString

The name of the AI model, for example, "gemini:1.0.0". Corresponds to the JSON property name

Returns:

  • (String)


5304
5305
5306
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5304

def name
  @name
end

#publisherString

The publisher of the model, for example, “google” or “nvidia”. Corresponds to the JSON property publisher

Returns:

  • (String)


5309
5310
5311
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5309

def publisher
  @publisher
end

#usage_categoryString

The purpose of the model, for example, "Inteference" or "Training". Corresponds to the JSON property usageCategory

Returns:

  • (String)


5314
5315
5316
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5314

def usage_category
  @usage_category
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5321
5322
5323
5324
5325
5326
5327
5328
5329
5330
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5321

def update!(**args)
  @deployment_platform = args[:deployment_platform] if args.key?(:deployment_platform)
  @display_name = args[:display_name] if args.key?(:display_name)
  @domain = args[:domain] if args.key?(:domain)
  @library = args[:library] if args.key?(:library)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @publisher = args[:publisher] if args.key?(:publisher)
  @usage_category = args[:usage_category] if args.key?(:usage_category)
end