Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2AzureMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Azure metadata associated with the resource, only applicable if the finding's cloud provider is Microsoft Azure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AzureMetadata

Returns a new instance of GoogleCloudSecuritycenterV2AzureMetadata.



5495
5496
5497
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5495

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#management_groupsArray<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2AzureManagementGroup>

A list of Azure management groups associated with the resource, ordered from lowest level (closest to the subscription) to highest level. Corresponds to the JSON property managementGroups



5478
5479
5480
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5478

def management_groups
  @management_groups
end

#resource_groupGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2AzureResourceGroup

Represents an Azure resource group. Corresponds to the JSON property resourceGroup



5483
5484
5485
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5483

def resource_group
  @resource_group
end

#subscriptionGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2AzureSubscription

Represents an Azure subscription. Corresponds to the JSON property subscription



5488
5489
5490
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5488

def subscription
  @subscription
end

#tenantGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2AzureTenant

Represents a Microsoft Entra tenant. Corresponds to the JSON property tenant



5493
5494
5495
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5493

def tenant
  @tenant
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5500
5501
5502
5503
5504
5505
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5500

def update!(**args)
  @management_groups = args[:management_groups] if args.key?(:management_groups)
  @resource_group = args[:resource_group] if args.key?(:resource_group)
  @subscription = args[:subscription] if args.key?(:subscription)
  @tenant = args[:tenant] if args.key?(:tenant)
end