Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Binding
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Binding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Represents a Kubernetes RoleBinding or ClusterRoleBinding.
Instance Attribute Summary collapse
-
#name ⇒ String
Name for the binding.
-
#ns ⇒ String
Namespace for the binding.
-
#role ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Role
Kubernetes Role or ClusterRole.
-
#subjects ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Subject>
Represents one or more subjects that are bound to the role.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Binding
constructor
A new instance of GoogleCloudSecuritycenterV2Binding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Binding
Returns a new instance of GoogleCloudSecuritycenterV2Binding.
5956 5957 5958 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5956 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Name for the binding.
Corresponds to the JSON property name
5938 5939 5940 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5938 def name @name end |
#ns ⇒ String
Namespace for the binding.
Corresponds to the JSON property ns
5943 5944 5945 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5943 def ns @ns end |
#role ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Role
Kubernetes Role or ClusterRole.
Corresponds to the JSON property role
5948 5949 5950 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5948 def role @role end |
#subjects ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Subject>
Represents one or more subjects that are bound to the role. Not always
available for PATCH requests.
Corresponds to the JSON property subjects
5954 5955 5956 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5954 def subjects @subjects end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5961 5962 5963 5964 5965 5966 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5961 def update!(**args) @name = args[:name] if args.key?(:name) @ns = args[:ns] if args.key?(:ns) @role = args[:role] if args.key?(:role) @subjects = args[:subjects] if args.key?(:subjects) end |