Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2CloudArmor

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Fields related to Google Cloud Armor findings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2CloudArmor

Returns a new instance of GoogleCloudSecuritycenterV2CloudArmor.



6105
6106
6107
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6105

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adaptive_protectionGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2AdaptiveProtection

Information about Google Cloud Armor Adaptive Protection. Corresponds to the JSON property adaptiveProtection



6074
6075
6076
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6074

def adaptive_protection
  @adaptive_protection
end

#attackGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Attack

Information about DDoS attack volume and classification. Corresponds to the JSON property attack



6079
6080
6081
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6079

def attack
  @attack
end

#durationString

Duration of attack from the start until the current moment (updated every 5 minutes). Corresponds to the JSON property duration

Returns:

  • (String)


6085
6086
6087
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6085

def duration
  @duration
end

#requestsGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Requests

Information about the requests relevant to the finding. Corresponds to the JSON property requests



6090
6091
6092
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6090

def requests
  @requests
end

#security_policyGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2SecurityPolicy

Information about the Google Cloud Armor security policy relevant to the finding. Corresponds to the JSON property securityPolicy



6096
6097
6098
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6096

def security_policy
  @security_policy
end

#threat_vectorString

Distinguish between volumetric & protocol DDoS attack and application layer attacks. For example, "L3_4" for Layer 3 and Layer 4 DDoS attacks, or "L_7" for Layer 7 DDoS attacks. Corresponds to the JSON property threatVector

Returns:

  • (String)


6103
6104
6105
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6103

def threat_vector
  @threat_vector
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6110
6111
6112
6113
6114
6115
6116
6117
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6110

def update!(**args)
  @adaptive_protection = args[:adaptive_protection] if args.key?(:adaptive_protection)
  @attack = args[:attack] if args.key?(:attack)
  @duration = args[:duration] if args.key?(:duration)
  @requests = args[:requests] if args.key?(:requests)
  @security_policy = args[:security_policy] if args.key?(:security_policy)
  @threat_vector = args[:threat_vector] if args.key?(:threat_vector)
end