Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2CloudDlpDataProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

The data profile associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2CloudDlpDataProfile

Returns a new instance of GoogleCloudSecuritycenterV2CloudDlpDataProfile.



5963
5964
5965
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5963

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_profileString

Name of the data profile, for example, projects/123/locations/europe/ tableProfiles/8383929. Corresponds to the JSON property dataProfile

Returns:

  • (String)


5950
5951
5952
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5950

def data_profile
  @data_profile
end

#info_typesArray<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2InfoType>

Type of information detected by SDP. Info type includes name, version and sensitivity of the detected information type. Corresponds to the JSON property infoTypes



5956
5957
5958
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5956

def info_types
  @info_types
end

#parent_typeString

The resource hierarchy level at which the data profile was generated. Corresponds to the JSON property parentType

Returns:

  • (String)


5961
5962
5963
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5961

def parent_type
  @parent_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5968
5969
5970
5971
5972
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5968

def update!(**args)
  @data_profile = args[:data_profile] if args.key?(:data_profile)
  @info_types = args[:info_types] if args.key?(:info_types)
  @parent_type = args[:parent_type] if args.key?(:parent_type)
end