Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2CloudLoggingEntry
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2CloudLoggingEntry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Metadata taken from a Cloud Logging LogEntry
Instance Attribute Summary collapse
-
#insert_id ⇒ String
A unique identifier for the log entry.
-
#log_id ⇒ String
The type of the log (part of
log_name.log_nameis the resource name of the log to which this log entry belongs). -
#resource_container ⇒ String
The organization, folder, or project of the monitored resource that produced this log entry.
-
#timestamp ⇒ String
The time the event described by the log entry occurred.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2CloudLoggingEntry
constructor
A new instance of GoogleCloudSecuritycenterV2CloudLoggingEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2CloudLoggingEntry
Returns a new instance of GoogleCloudSecuritycenterV2CloudLoggingEntry.
6262 6263 6264 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6262 def initialize(**args) update!(**args) end |
Instance Attribute Details
#insert_id ⇒ String
A unique identifier for the log entry.
Corresponds to the JSON property insertId
6241 6242 6243 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6241 def insert_id @insert_id end |
#log_id ⇒ String
The type of the log (part of log_name. log_name is the resource name of
the log to which this log entry belongs). For example: cloudresourcemanager.
googleapis.com/activity Note that this field is not URL-encoded, unlike in
LogEntry.
Corresponds to the JSON property logId
6249 6250 6251 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6249 def log_id @log_id end |
#resource_container ⇒ String
The organization, folder, or project of the monitored resource that produced
this log entry.
Corresponds to the JSON property resourceContainer
6255 6256 6257 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6255 def resource_container @resource_container end |
#timestamp ⇒ String
The time the event described by the log entry occurred.
Corresponds to the JSON property timestamp
6260 6261 6262 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6260 def @timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6267 6268 6269 6270 6271 6272 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6267 def update!(**args) @insert_id = args[:insert_id] if args.key?(:insert_id) @log_id = args[:log_id] if args.key?(:log_id) @resource_container = args[:resource_container] if args.key?(:resource_container) @timestamp = args[:timestamp] if args.key?(:timestamp) end |