Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Compliance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Contains compliance information about a security standard indicating unmet recommendations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Compliance

Returns a new instance of GoogleCloudSecuritycenterV2Compliance.



6079
6080
6081
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6079

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idsArray<String>

Policies within the standard or benchmark, for example, A.12.4.1 Corresponds to the JSON property ids

Returns:

  • (Array<String>)


6067
6068
6069
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6067

def ids
  @ids
end

#standardString

Industry-wide compliance standards or benchmarks, such as CIS, PCI, and OWASP. Corresponds to the JSON property standard

Returns:

  • (String)


6072
6073
6074
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6072

def standard
  @standard
end

#versionString

Version of the standard or benchmark, for example, 1.1 Corresponds to the JSON property version

Returns:

  • (String)


6077
6078
6079
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6077

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6084
6085
6086
6087
6088
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6084

def update!(**args)
  @ids = args[:ids] if args.key?(:ids)
  @standard = args[:standard] if args.key?(:standard)
  @version = args[:version] if args.key?(:version)
end