Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Connection

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Contains information about the IP connection associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Connection

Returns a new instance of GoogleCloudSecuritycenterV2Connection.



6154
6155
6156
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6154

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destination_ipString

Destination IP address. Not present for sockets that are listening and not connected. Corresponds to the JSON property destinationIp

Returns:

  • (String)


6132
6133
6134
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6132

def destination_ip
  @destination_ip
end

#destination_portFixnum

Destination port. Not present for sockets that are listening and not connected. Corresponds to the JSON property destinationPort

Returns:

  • (Fixnum)


6137
6138
6139
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6137

def destination_port
  @destination_port
end

#protocolString

IANA Internet Protocol Number such as TCP(6) and UDP(17). Corresponds to the JSON property protocol

Returns:

  • (String)


6142
6143
6144
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6142

def protocol
  @protocol
end

#source_ipString

Source IP address. Corresponds to the JSON property sourceIp

Returns:

  • (String)


6147
6148
6149
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6147

def source_ip
  @source_ip
end

#source_portFixnum

Source port. Corresponds to the JSON property sourcePort

Returns:

  • (Fixnum)


6152
6153
6154
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6152

def source_port
  @source_port
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6159
6160
6161
6162
6163
6164
6165
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6159

def update!(**args)
  @destination_ip = args[:destination_ip] if args.key?(:destination_ip)
  @destination_port = args[:destination_port] if args.key?(:destination_port)
  @protocol = args[:protocol] if args.key?(:protocol)
  @source_ip = args[:source_ip] if args.key?(:source_ip)
  @source_port = args[:source_port] if args.key?(:source_port)
end