Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Container

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Container associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Container

Returns a new instance of GoogleCloudSecuritycenterV2Container.



6237
6238
6239
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6237

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

The time that the container was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6213
6214
6215
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6213

def create_time
  @create_time
end

#image_idString

Optional container image ID, if provided by the container runtime. Uniquely identifies the container image launched using a container image digest. Corresponds to the JSON property imageId

Returns:

  • (String)


6219
6220
6221
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6219

def image_id
  @image_id
end

#labelsArray<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Label>

Container labels, as provided by the container runtime. Corresponds to the JSON property labels



6224
6225
6226
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6224

def labels
  @labels
end

#nameString

Name of the container. Corresponds to the JSON property name

Returns:

  • (String)


6229
6230
6231
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6229

def name
  @name
end

#uriString

Container image URI provided when configuring a pod or container. This string can identify a container image version using mutable tags. Corresponds to the JSON property uri

Returns:

  • (String)


6235
6236
6237
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6235

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6242
6243
6244
6245
6246
6247
6248
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6242

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @image_id = args[:image_id] if args.key?(:image_id)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @uri = args[:uri] if args.key?(:uri)
end