Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2DataAccessEvent
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2DataAccessEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Details about a data access attempt made by a principal not authorized under applicable data security policy.
Instance Attribute Summary collapse
-
#event_id ⇒ String
Unique identifier for data access event.
-
#event_time ⇒ String
Timestamp of data access event.
-
#operation ⇒ String
The operation performed by the principal to access the data.
-
#principal_email ⇒ String
The email address of the principal that accessed the data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2DataAccessEvent
constructor
A new instance of GoogleCloudSecuritycenterV2DataAccessEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2DataAccessEvent
Returns a new instance of GoogleCloudSecuritycenterV2DataAccessEvent.
6485 6486 6487 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6485 def initialize(**args) update!(**args) end |
Instance Attribute Details
#event_id ⇒ String
Unique identifier for data access event.
Corresponds to the JSON property eventId
6467 6468 6469 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6467 def event_id @event_id end |
#event_time ⇒ String
Timestamp of data access event.
Corresponds to the JSON property eventTime
6472 6473 6474 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6472 def event_time @event_time end |
#operation ⇒ String
The operation performed by the principal to access the data.
Corresponds to the JSON property operation
6477 6478 6479 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6477 def operation @operation end |
#principal_email ⇒ String
The email address of the principal that accessed the data. The principal could
be a user account, service account, Google group, or other.
Corresponds to the JSON property principalEmail
6483 6484 6485 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6483 def principal_email @principal_email end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6490 6491 6492 6493 6494 6495 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6490 def update!(**args) @event_id = args[:event_id] if args.key?(:event_id) @event_time = args[:event_time] if args.key?(:event_time) @operation = args[:operation] if args.key?(:operation) @principal_email = args[:principal_email] if args.key?(:principal_email) end |