Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2DataRetentionDeletionEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Details about data retention deletion violations, in which the data is non- compliant based on their retention or deletion time, as defined in the applicable data security policy. The Data Retention Deletion (DRD) control is a control of the DSPM (Data Security Posture Management) suite that enables organizations to manage data retention and deletion policies in compliance with regulations, such as GDPR and CRPA. DRD supports two primary policy types: maximum storage length (max TTL) and minimum storage length (min TTL). Both are aimed at helping organizations meet regulatory and data management commitments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2DataRetentionDeletionEvent

Returns a new instance of GoogleCloudSecuritycenterV2DataRetentionDeletionEvent.



6747
6748
6749
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6747

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_object_countFixnum

Number of objects that violated the policy for this resource. If the number is less than 1,000, then the value of this field is the exact number. If the number of objects that violated the policy is greater than or equal to 1,000, then the value of this field is 1000. Corresponds to the JSON property dataObjectCount

Returns:

  • (Fixnum)


6719
6720
6721
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6719

def data_object_count
  @data_object_count
end

#event_detection_timeString

Timestamp indicating when the event was detected. Corresponds to the JSON property eventDetectionTime

Returns:

  • (String)


6724
6725
6726
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6724

def event_detection_time
  @event_detection_time
end

#event_typeString

Type of the DRD event. Corresponds to the JSON property eventType

Returns:

  • (String)


6729
6730
6731
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6729

def event_type
  @event_type
end

#max_retention_allowedString

Maximum duration of retention allowed from the DRD control. This comes from the DRD control where users set a max TTL for their data. For example, suppose that a user sets the max TTL for a Cloud Storage bucket to 90 days. However, an object in that bucket is 100 days old. In this case, a DataRetentionDeletionEvent will be generated for that Cloud Storage bucket, and the max_retention_allowed is 90 days. Corresponds to the JSON property maxRetentionAllowed

Returns:

  • (String)


6739
6740
6741
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6739

def max_retention_allowed
  @max_retention_allowed
end

#min_retention_allowedString

Min duration of retention allowed from the DSPM retention control. This field is only populated when event type is set to EVENT_TYPE_MIN_TTL_FROM_CREATION. Corresponds to the JSON property minRetentionAllowed

Returns:

  • (String)


6745
6746
6747
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6745

def min_retention_allowed
  @min_retention_allowed
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6752
6753
6754
6755
6756
6757
6758
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6752

def update!(**args)
  @data_object_count = args[:data_object_count] if args.key?(:data_object_count)
  @event_detection_time = args[:event_detection_time] if args.key?(:event_detection_time)
  @event_type = args[:event_type] if args.key?(:event_type)
  @max_retention_allowed = args[:max_retention_allowed] if args.key?(:max_retention_allowed)
  @min_retention_allowed = args[:min_retention_allowed] if args.key?(:min_retention_allowed)
end