Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2DiscoveredWorkload
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2DiscoveredWorkload
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Represents discovered, customer managed workload that is not registered with the respective GCP service.
Instance Attribute Summary collapse
-
#confidence ⇒ String
The confidence in detection of this workload.
-
#detected_relevant_hardware ⇒ Boolean
(also: #detected_relevant_hardware?)
A boolean flag set to true if associated hardware strongly predicts the workload type.
-
#detected_relevant_keywords ⇒ Boolean
(also: #detected_relevant_keywords?)
A boolean flag set to true if associated keywords strongly predict the workload type.
-
#detected_relevant_packages ⇒ Boolean
(also: #detected_relevant_packages?)
A boolean flag set to true if installed packages strongly predict the workload type.
-
#workload_type ⇒ String
The type of workload.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2DiscoveredWorkload
constructor
A new instance of GoogleCloudSecuritycenterV2DiscoveredWorkload.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2DiscoveredWorkload
Returns a new instance of GoogleCloudSecuritycenterV2DiscoveredWorkload.
6996 6997 6998 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6996 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence ⇒ String
The confidence in detection of this workload.
Corresponds to the JSON property confidence
6968 6969 6970 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6968 def confidence @confidence end |
#detected_relevant_hardware ⇒ Boolean Also known as: detected_relevant_hardware?
A boolean flag set to true if associated hardware strongly predicts the
workload type.
Corresponds to the JSON property detectedRelevantHardware
6974 6975 6976 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6974 def detected_relevant_hardware @detected_relevant_hardware end |
#detected_relevant_keywords ⇒ Boolean Also known as: detected_relevant_keywords?
A boolean flag set to true if associated keywords strongly predict the
workload type.
Corresponds to the JSON property detectedRelevantKeywords
6981 6982 6983 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6981 def detected_relevant_keywords @detected_relevant_keywords end |
#detected_relevant_packages ⇒ Boolean Also known as: detected_relevant_packages?
A boolean flag set to true if installed packages strongly predict the workload
type.
Corresponds to the JSON property detectedRelevantPackages
6988 6989 6990 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6988 def detected_relevant_packages @detected_relevant_packages end |
#workload_type ⇒ String
The type of workload.
Corresponds to the JSON property workloadType
6994 6995 6996 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6994 def workload_type @workload_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7001 7002 7003 7004 7005 7006 7007 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7001 def update!(**args) @confidence = args[:confidence] if args.key?(:confidence) @detected_relevant_hardware = args[:detected_relevant_hardware] if args.key?(:detected_relevant_hardware) @detected_relevant_keywords = args[:detected_relevant_keywords] if args.key?(:detected_relevant_keywords) @detected_relevant_packages = args[:detected_relevant_packages] if args.key?(:detected_relevant_packages) @workload_type = args[:workload_type] if args.key?(:workload_type) end |