Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2DynamicMuteRecord
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2DynamicMuteRecord
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
The record of a dynamic mute rule that matches the finding.
Instance Attribute Summary collapse
-
#match_time ⇒ String
When the dynamic mute rule first matched the finding.
-
#mute_config ⇒ String
The relative resource name of the mute rule, represented by a mute config, that created this record, for example
organizations/123/muteConfigs/ mymuteconfigororganizations/123/locations/global/muteConfigs/mymuteconfig.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2DynamicMuteRecord
constructor
A new instance of GoogleCloudSecuritycenterV2DynamicMuteRecord.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2DynamicMuteRecord
Returns a new instance of GoogleCloudSecuritycenterV2DynamicMuteRecord.
7014 7015 7016 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7014 def initialize(**args) update!(**args) end |
Instance Attribute Details
#match_time ⇒ String
When the dynamic mute rule first matched the finding.
Corresponds to the JSON property matchTime
7005 7006 7007 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7005 def match_time @match_time end |
#mute_config ⇒ String
The relative resource name of the mute rule, represented by a mute config,
that created this record, for example organizations/123/muteConfigs/
mymuteconfig or organizations/123/locations/global/muteConfigs/mymuteconfig.
Corresponds to the JSON property muteConfig
7012 7013 7014 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7012 def mute_config @mute_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7019 7020 7021 7022 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7019 def update!(**args) @match_time = args[:match_time] if args.key?(:match_time) @mute_config = args[:mute_config] if args.key?(:mute_config) end |