Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2File

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

File information about the related binary/library used by an executable, or the script used by a script interpreter

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2File

Returns a new instance of GoogleCloudSecuritycenterV2File.



7354
7355
7356
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7354

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentsString

Prefix of the file contents as a JSON-encoded string. Corresponds to the JSON property contents

Returns:

  • (String)


7309
7310
7311
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7309

def contents
  @contents
end

#disk_pathGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2DiskPath

Path of the file in terms of underlying disk/partition identifiers. Corresponds to the JSON property diskPath



7314
7315
7316
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7314

def disk_path
  @disk_path
end

#file_load_stateString

The load state of the file. Corresponds to the JSON property fileLoadState

Returns:

  • (String)


7319
7320
7321
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7319

def file_load_state
  @file_load_state
end

#hashed_sizeFixnum

The length in bytes of the file prefix that was hashed. If hashed_size == size, any hashes reported represent the entire file. Corresponds to the JSON property hashedSize

Returns:

  • (Fixnum)


7325
7326
7327
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7325

def hashed_size
  @hashed_size
end

#operationsArray<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2FileOperation>

Operation(s) performed on a file. Corresponds to the JSON property operations



7330
7331
7332
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7330

def operations
  @operations
end

#partially_hashedBoolean Also known as: partially_hashed?

True when the hash covers only a prefix of the file. Corresponds to the JSON property partiallyHashed

Returns:

  • (Boolean)


7335
7336
7337
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7335

def partially_hashed
  @partially_hashed
end

#pathString

Absolute path of the file as a JSON encoded string. Corresponds to the JSON property path

Returns:

  • (String)


7341
7342
7343
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7341

def path
  @path
end

#sha256String

SHA256 hash of the first hashed_size bytes of the file encoded as a hex string. If hashed_size == size, sha256 represents the SHA256 hash of the entire file. Corresponds to the JSON property sha256

Returns:

  • (String)


7347
7348
7349
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7347

def sha256
  @sha256
end

#sizeFixnum

Size of the file in bytes. Corresponds to the JSON property size

Returns:

  • (Fixnum)


7352
7353
7354
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7352

def size
  @size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7359
7360
7361
7362
7363
7364
7365
7366
7367
7368
7369
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7359

def update!(**args)
  @contents = args[:contents] if args.key?(:contents)
  @disk_path = args[:disk_path] if args.key?(:disk_path)
  @file_load_state = args[:file_load_state] if args.key?(:file_load_state)
  @hashed_size = args[:hashed_size] if args.key?(:hashed_size)
  @operations = args[:operations] if args.key?(:operations)
  @partially_hashed = args[:partially_hashed] if args.key?(:partially_hashed)
  @path = args[:path] if args.key?(:path)
  @sha256 = args[:sha256] if args.key?(:sha256)
  @size = args[:size] if args.key?(:size)
end