Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2GroupMembership

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Contains details about groups of which this finding is a member. A group is a collection of findings that are related in some way.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2GroupMembership

Returns a new instance of GoogleCloudSecuritycenterV2GroupMembership.



8140
8141
8142
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8140

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#group_idString

ID of the group. Corresponds to the JSON property groupId

Returns:

  • (String)


8133
8134
8135
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8133

def group_id
  @group_id
end

#group_typeString

Type of group. Corresponds to the JSON property groupType

Returns:

  • (String)


8138
8139
8140
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8138

def group_type
  @group_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8145
8146
8147
8148
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8145

def update!(**args)
  @group_id = args[:group_id] if args.key?(:group_id)
  @group_type = args[:group_type] if args.key?(:group_type)
end