Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2HttpResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

The http response returned by the web application.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2HttpResponse

Returns a new instance of GoogleCloudSecuritycenterV2HttpResponse.



8166
8167
8168
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8166

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#pathString

The http path for which response code was returned by web application, for example, "https://test-app.a.run.app/test". Corresponds to the JSON property path

Returns:

  • (String)


8159
8160
8161
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8159

def path
  @path
end

#status_codeString

The http response code returned by the web application, for example, 200. Corresponds to the JSON property statusCode

Returns:

  • (String)


8164
8165
8166
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8164

def status_code
  @status_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8171
8172
8173
8174
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8171

def update!(**args)
  @path = args[:path] if args.key?(:path)
  @status_code = args[:status_code] if args.key?(:status_code)
end