Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IamBinding
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IamBinding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Represents a particular IAM binding, which captures a member's role addition, removal, or state.
Instance Attribute Summary collapse
-
#action ⇒ String
The action that was performed on a Binding.
-
#member ⇒ String
A single identity requesting access for a Cloud Platform resource, for example, "foo@google.com".
-
#role ⇒ String
Role that is assigned to "members".
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IamBinding
constructor
A new instance of GoogleCloudSecuritycenterV2IamBinding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IamBinding
Returns a new instance of GoogleCloudSecuritycenterV2IamBinding.
8055 8056 8057 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8055 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
The action that was performed on a Binding.
Corresponds to the JSON property action
8041 8042 8043 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8041 def action @action end |
#member ⇒ String
A single identity requesting access for a Cloud Platform resource, for example,
"foo@google.com".
Corresponds to the JSON property member
8047 8048 8049 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8047 def member @member end |
#role ⇒ String
Role that is assigned to "members". For example, "roles/viewer", "roles/editor"
, or "roles/owner".
Corresponds to the JSON property role
8053 8054 8055 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8053 def role @role end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8060 8061 8062 8063 8064 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8060 def update!(**args) @action = args[:action] if args.key?(:action) @member = args[:member] if args.key?(:member) @role = args[:role] if args.key?(:role) end |