Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IpRules

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

IP rules associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IpRules

Returns a new instance of GoogleCloudSecuritycenterV2IpRules.



7976
7977
7978
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7976

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowedGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Allowed

Allowed IP rule. Corresponds to the JSON property allowed



7943
7944
7945
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7943

def allowed
  @allowed
end

#deniedGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Denied

Denied IP rule. Corresponds to the JSON property denied



7948
7949
7950
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7948

def denied
  @denied
end

#destination_ip_rangesArray<String>

If destination IP ranges are specified, the firewall rule applies only to traffic that has a destination IP address in these ranges. These ranges must be expressed in CIDR format. Only supports IPv4. Corresponds to the JSON property destinationIpRanges

Returns:

  • (Array<String>)


7955
7956
7957
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7955

def destination_ip_ranges
  @destination_ip_ranges
end

#directionString

The direction that the rule is applicable to, one of ingress or egress. Corresponds to the JSON property direction

Returns:

  • (String)


7960
7961
7962
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7960

def direction
  @direction
end

#exposed_servicesArray<String>

Name of the network protocol service, such as FTP, that is exposed by the open port. Follows the naming convention available at: https://www.iana.org/ assignments/service-names-port-numbers/service-names-port-numbers.xhtml. Corresponds to the JSON property exposedServices

Returns:

  • (Array<String>)


7967
7968
7969
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7967

def exposed_services
  @exposed_services
end

#source_ip_rangesArray<String>

If source IP ranges are specified, the firewall rule applies only to traffic that has a source IP address in these ranges. These ranges must be expressed in CIDR format. Only supports IPv4. Corresponds to the JSON property sourceIpRanges

Returns:

  • (Array<String>)


7974
7975
7976
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7974

def source_ip_ranges
  @source_ip_ranges
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7981
7982
7983
7984
7985
7986
7987
7988
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7981

def update!(**args)
  @allowed = args[:allowed] if args.key?(:allowed)
  @denied = args[:denied] if args.key?(:denied)
  @destination_ip_ranges = args[:destination_ip_ranges] if args.key?(:destination_ip_ranges)
  @direction = args[:direction] if args.key?(:direction)
  @exposed_services = args[:exposed_services] if args.key?(:exposed_services)
  @source_ip_ranges = args[:source_ip_ranges] if args.key?(:source_ip_ranges)
end