Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Issue
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Issue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Security Command Center Issue.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
The description of the issue in Markdown format.
-
#detection ⇒ String
The finding category or rule name that generated the issue.
-
#domains ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueDomain>
The domains of the issue.
-
#exposure_score ⇒ Float
The exposure score of the issue.
-
#issue_type ⇒ String
The type of the issue.
-
#last_observation_time ⇒ String
The time the issue was last observed.
-
#mute ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueMute
The mute information of the issue.
-
#name ⇒ String
Identifier.
-
#primary_resource ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResource
A resource associated with the an issue.
-
#related_findings ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueFinding>
The findings related to the issue.
-
#remediations ⇒ Array<String>
Approaches to remediate the issue in Markdown format.
-
#secondary_resources ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResource>
Additional resources associated with the issue.
-
#security_contexts ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueSecurityContext>
The security context of the issue.
-
#severity ⇒ String
The severity of the issue.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Issue
constructor
A new instance of GoogleCloudSecuritycenterV2Issue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Issue
Returns a new instance of GoogleCloudSecuritycenterV2Issue.
8463 8464 8465 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8463 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time the issue was created.
Corresponds to the JSON property createTime
8380 8381 8382 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8380 def create_time @create_time end |
#description ⇒ String
The description of the issue in Markdown format.
Corresponds to the JSON property description
8385 8386 8387 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8385 def description @description end |
#detection ⇒ String
The finding category or rule name that generated the issue.
Corresponds to the JSON property detection
8390 8391 8392 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8390 def detection @detection end |
#domains ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueDomain>
The domains of the issue.
Corresponds to the JSON property domains
8395 8396 8397 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8395 def domains @domains end |
#exposure_score ⇒ Float
The exposure score of the issue.
Corresponds to the JSON property exposureScore
8400 8401 8402 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8400 def exposure_score @exposure_score end |
#issue_type ⇒ String
The type of the issue.
Corresponds to the JSON property issueType
8405 8406 8407 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8405 def issue_type @issue_type end |
#last_observation_time ⇒ String
The time the issue was last observed.
Corresponds to the JSON property lastObservationTime
8410 8411 8412 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8410 def last_observation_time @last_observation_time end |
#mute ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueMute
The mute information of the issue.
Corresponds to the JSON property mute
8415 8416 8417 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8415 def mute @mute end |
#name ⇒ String
Identifier. The name of the issue. Format: organizations/organization/
locations/location/issues/issue
Corresponds to the JSON property name
8421 8422 8423 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8421 def name @name end |
#primary_resource ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResource
A resource associated with the an issue.
Corresponds to the JSON property primaryResource
8426 8427 8428 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8426 def primary_resource @primary_resource end |
#related_findings ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueFinding>
The findings related to the issue.
Corresponds to the JSON property relatedFindings
8431 8432 8433 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8431 def @related_findings end |
#remediations ⇒ Array<String>
Approaches to remediate the issue in Markdown format.
Corresponds to the JSON property remediations
8436 8437 8438 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8436 def remediations @remediations end |
#secondary_resources ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResource>
Additional resources associated with the issue.
Corresponds to the JSON property secondaryResources
8441 8442 8443 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8441 def secondary_resources @secondary_resources end |
#security_contexts ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueSecurityContext>
The security context of the issue.
Corresponds to the JSON property securityContexts
8446 8447 8448 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8446 def security_contexts @security_contexts end |
#severity ⇒ String
The severity of the issue.
Corresponds to the JSON property severity
8451 8452 8453 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8451 def severity @severity end |
#state ⇒ String
Output only. The state of the issue.
Corresponds to the JSON property state
8456 8457 8458 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8456 def state @state end |
#update_time ⇒ String
Output only. The time the issue was last updated.
Corresponds to the JSON property updateTime
8461 8462 8463 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8461 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8468 8469 8470 8471 8472 8473 8474 8475 8476 8477 8478 8479 8480 8481 8482 8483 8484 8485 8486 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8468 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @detection = args[:detection] if args.key?(:detection) @domains = args[:domains] if args.key?(:domains) @exposure_score = args[:exposure_score] if args.key?(:exposure_score) @issue_type = args[:issue_type] if args.key?(:issue_type) @last_observation_time = args[:last_observation_time] if args.key?(:last_observation_time) @mute = args[:mute] if args.key?(:mute) @name = args[:name] if args.key?(:name) @primary_resource = args[:primary_resource] if args.key?(:primary_resource) @related_findings = args[:related_findings] if args.key?(:related_findings) @remediations = args[:remediations] if args.key?(:remediations) @secondary_resources = args[:secondary_resources] if args.key?(:secondary_resources) @security_contexts = args[:security_contexts] if args.key?(:security_contexts) @severity = args[:severity] if args.key?(:severity) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |