Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Consumer provided attributes for the application

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResourceApplicationAttributes

Returns a new instance of GoogleCloudSecuritycenterV2IssueResourceApplicationAttributes.



8817
8818
8819
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8817

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#business_ownersArray<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesContactInfo>

Business team that ensures user needs are met and value is delivered Corresponds to the JSON property businessOwners



8795
8796
8797
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8795

def business_owners
  @business_owners
end

#criticalityGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesCriticality

Criticality of the Application, Service, or Workload Corresponds to the JSON property criticality



8800
8801
8802
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8800

def criticality
  @criticality
end

#developer_ownersArray<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesContactInfo>

Developer team that owns development and coding. Corresponds to the JSON property developerOwners



8805
8806
8807
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8805

def developer_owners
  @developer_owners
end

#environmentGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesEnvironment

Environment of the Application, Service, or Workload Corresponds to the JSON property environment



8810
8811
8812
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8810

def environment
  @environment
end

#operator_ownersArray<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesContactInfo>

Operator team that ensures runtime and operations. Corresponds to the JSON property operatorOwners



8815
8816
8817
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8815

def operator_owners
  @operator_owners
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8822
8823
8824
8825
8826
8827
8828
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8822

def update!(**args)
  @business_owners = args[:business_owners] if args.key?(:business_owners)
  @criticality = args[:criticality] if args.key?(:criticality)
  @developer_owners = args[:developer_owners] if args.key?(:developer_owners)
  @environment = args[:environment] if args.key?(:environment)
  @operator_owners = args[:operator_owners] if args.key?(:operator_owners)
end