Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceAwsMetadataAwsAccount

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

The AWS account of the resource associated with the issue.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResourceAwsMetadataAwsAccount

Returns a new instance of GoogleCloudSecuritycenterV2IssueResourceAwsMetadataAwsAccount.



8777
8778
8779
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8777

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

The AWS account ID of the resource associated with the issue. Corresponds to the JSON property id

Returns:

  • (String)


8770
8771
8772
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8770

def id
  @id
end

#nameString

The AWS account name of the resource associated with the issue. Corresponds to the JSON property name

Returns:

  • (String)


8775
8776
8777
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8775

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8782
8783
8784
8785
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8782

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
end