Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceAzureMetadataAzureSubscription

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

The Azure subscription of the resource associated with the issue.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResourceAzureMetadataAzureSubscription

Returns a new instance of GoogleCloudSecuritycenterV2IssueResourceAzureMetadataAzureSubscription.



8965
8966
8967
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8965

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

The Azure subscription display name of the resource associated with the issue. Corresponds to the JSON property displayName

Returns:

  • (String)


8958
8959
8960
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8958

def display_name
  @display_name
end

#idString

The Azure subscription ID of the resource associated with the issue. Corresponds to the JSON property id

Returns:

  • (String)


8963
8964
8965
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8963

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8970
8971
8972
8973
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8970

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @id = args[:id] if args.key?(:id)
end