Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Job
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Job
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Describes a job
Instance Attribute Summary collapse
-
#error_code ⇒ Fixnum
Optional.
-
#location ⇒ String
Optional.
-
#name ⇒ String
The fully-qualified name for a job.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Job
constructor
A new instance of GoogleCloudSecuritycenterV2Job.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Job
Returns a new instance of GoogleCloudSecuritycenterV2Job.
9094 9095 9096 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9094 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_code ⇒ Fixnum
Optional. If the job did not complete successfully, this field describes why.
Corresponds to the JSON property errorCode
9077 9078 9079 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9077 def error_code @error_code end |
#location ⇒ String
Optional. Gives the location where the job ran, such as US or europe-west1
Corresponds to the JSON property location
9082 9083 9084 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9082 def location @location end |
#name ⇒ String
The fully-qualified name for a job. e.g. projects//jobs/
Corresponds to the JSON property name
9087 9088 9089 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9087 def name @name end |
#state ⇒ String
Output only. State of the job, such as RUNNING or PENDING.
Corresponds to the JSON property state
9092 9093 9094 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9092 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9099 9100 9101 9102 9103 9104 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9099 def update!(**args) @error_code = args[:error_code] if args.key?(:error_code) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) end |