Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Kubernetes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Kubernetes-related attributes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Kubernetes

Returns a new instance of GoogleCloudSecuritycenterV2Kubernetes.



9237
9238
9239
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9237

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_reviewsArray<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2AccessReview>

Provides information on any Kubernetes access reviews (privilege checks) relevant to the finding. Corresponds to the JSON property accessReviews



9196
9197
9198
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9196

def access_reviews
  @access_reviews
end

#bindingsArray<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Binding>

Provides Kubernetes role binding information for findings that involve RoleBindings or ClusterRoleBindings. Corresponds to the JSON property bindings



9203
9204
9205
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9203

def bindings
  @bindings
end

#node_poolsArray<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2NodePool>

GKE node pools associated with the finding. This field contains node pool information for each node, when it is available. Corresponds to the JSON property nodePools



9210
9211
9212
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9210

def node_pools
  @node_pools
end

#nodesArray<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Node>

Provides Kubernetes node information. Corresponds to the JSON property nodes



9216
9217
9218
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9216

def nodes
  @nodes
end

#objectsArray<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Object>

Kubernetes objects related to the finding. Corresponds to the JSON property objects



9221
9222
9223
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9221

def objects
  @objects
end

#podsArray<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Pod>

Kubernetes Pods associated with the finding. This field contains Pod records for each container that is owned by a Pod. Corresponds to the JSON property pods



9228
9229
9230
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9228

def pods
  @pods
end

#rolesArray<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Role>

Provides Kubernetes role information for findings that involve Roles or ClusterRoles. Corresponds to the JSON property roles



9235
9236
9237
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9235

def roles
  @roles
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9242
9243
9244
9245
9246
9247
9248
9249
9250
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9242

def update!(**args)
  @access_reviews = args[:access_reviews] if args.key?(:access_reviews)
  @bindings = args[:bindings] if args.key?(:bindings)
  @node_pools = args[:node_pools] if args.key?(:node_pools)
  @nodes = args[:nodes] if args.key?(:nodes)
  @objects = args[:objects] if args.key?(:objects)
  @pods = args[:pods] if args.key?(:pods)
  @roles = args[:roles] if args.key?(:roles)
end