Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2LoadBalancer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Contains information related to the load balancer associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2LoadBalancer

Returns a new instance of GoogleCloudSecuritycenterV2LoadBalancer.



9291
9292
9293
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9291

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The name of the load balancer associated with the finding. Corresponds to the JSON property name

Returns:

  • (String)


9289
9290
9291
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9289

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9296
9297
9298
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9296

def update!(**args)
  @name = args[:name] if args.key?(:name)
end