Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Notebook

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Represents a Jupyter notebook IPYNB file, such as a Colab Enterprise notebook file, that is associated with a finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Notebook

Returns a new instance of GoogleCloudSecuritycenterV2Notebook.



9463
9464
9465
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9463

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_authorString

The user ID of the latest author to modify the notebook. Corresponds to the JSON property lastAuthor

Returns:

  • (String)


9446
9447
9448
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9446

def last_author
  @last_author
end

#nameString

The name of the notebook. Corresponds to the JSON property name

Returns:

  • (String)


9451
9452
9453
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9451

def name
  @name
end

#notebook_update_timeString

The most recent time the notebook was updated. Corresponds to the JSON property notebookUpdateTime

Returns:

  • (String)


9456
9457
9458
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9456

def notebook_update_time
  @notebook_update_time
end

#serviceString

The source notebook service, for example, "Colab Enterprise". Corresponds to the JSON property service

Returns:

  • (String)


9461
9462
9463
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9461

def service
  @service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9468
9469
9470
9471
9472
9473
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9468

def update!(**args)
  @last_author = args[:last_author] if args.key?(:last_author)
  @name = args[:name] if args.key?(:name)
  @notebook_update_time = args[:notebook_update_time] if args.key?(:notebook_update_time)
  @service = args[:service] if args.key?(:service)
end