Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Object

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Kubernetes object related to the finding, uniquely identified by GKNN. Used if the object Kind is not one of Pod, Node, NodePool, Binding, or AccessReview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Object

Returns a new instance of GoogleCloudSecuritycenterV2Object.



9688
9689
9690
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9688

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#containersArray<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Container>

Pod containers associated with this finding, if any. Corresponds to the JSON property containers



9663
9664
9665
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9663

def containers
  @containers
end

#groupString

Kubernetes object group, such as "policy.k8s.io/v1". Corresponds to the JSON property group

Returns:

  • (String)


9668
9669
9670
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9668

def group
  @group
end

#kindString

Kubernetes object kind, such as "Namespace". Corresponds to the JSON property kind

Returns:

  • (String)


9673
9674
9675
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9673

def kind
  @kind
end

#nameString

Kubernetes object name. For details see https://kubernetes.io/docs/concepts/ overview/working-with-objects/names/. Corresponds to the JSON property name

Returns:

  • (String)


9679
9680
9681
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9679

def name
  @name
end

#nsString

Kubernetes object namespace. Must be a valid DNS label. Named "ns" to avoid collision with C++ namespace keyword. For details see https://kubernetes.io/ docs/tasks/administer-cluster/namespaces/. Corresponds to the JSON property ns

Returns:

  • (String)


9686
9687
9688
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9686

def ns
  @ns
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9693
9694
9695
9696
9697
9698
9699
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9693

def update!(**args)
  @containers = args[:containers] if args.key?(:containers)
  @group = args[:group] if args.key?(:group)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @ns = args[:ns] if args.key?(:ns)
end