Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Package

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Package is a generic definition of a package.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Package

Returns a new instance of GoogleCloudSecuritycenterV2Package.



9746
9747
9748
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9746

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpe_uriString

The CPE URI where the vulnerability was detected. Corresponds to the JSON property cpeUri

Returns:

  • (String)


9729
9730
9731
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9729

def cpe_uri
  @cpe_uri
end

#package_nameString

The name of the package where the vulnerability was detected. Corresponds to the JSON property packageName

Returns:

  • (String)


9734
9735
9736
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9734

def package_name
  @package_name
end

#package_typeString

Type of package, for example, os, maven, or go. Corresponds to the JSON property packageType

Returns:

  • (String)


9739
9740
9741
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9739

def package_type
  @package_type
end

#package_versionString

The version of the package. Corresponds to the JSON property packageVersion

Returns:

  • (String)


9744
9745
9746
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9744

def package_version
  @package_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9751
9752
9753
9754
9755
9756
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9751

def update!(**args)
  @cpe_uri = args[:cpe_uri] if args.key?(:cpe_uri)
  @package_name = args[:package_name] if args.key?(:package_name)
  @package_type = args[:package_type] if args.key?(:package_type)
  @package_version = args[:package_version] if args.key?(:package_version)
end