Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2PolicyViolationSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Metadata summarizing policy violations of child resources of the affected resource. finding_category and resource determine the exact semantics of the counts. For example, when category= DATA_SECURITY_POSTURE_OBJECT_PUBLIC_ACCESS_VIOLATION and resource='storage. googleapis.com/buckets/my-bucket-name' then this counts the number of Cloud Storage objects in my-bucket-name which violate a Public Access control.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2PolicyViolationSummary

Returns a new instance of GoogleCloudSecuritycenterV2PolicyViolationSummary.



9743
9744
9745
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9743

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conformant_resources_countFixnum

Total number of child resources that conform to the policy. Corresponds to the JSON property conformantResourcesCount

Returns:

  • (Fixnum)


9725
9726
9727
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9725

def conformant_resources_count
  @conformant_resources_count
end

#evaluation_errors_countFixnum

Number of child resources for which errors during evaluation occurred. The evaluation result for these child resources is effectively "unknown". Corresponds to the JSON property evaluationErrorsCount

Returns:

  • (Fixnum)


9731
9732
9733
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9731

def evaluation_errors_count
  @evaluation_errors_count
end

#out_of_scope_resources_countFixnum

Total count of child resources which were not in scope for evaluation. Corresponds to the JSON property outOfScopeResourcesCount

Returns:

  • (Fixnum)


9736
9737
9738
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9736

def out_of_scope_resources_count
  @out_of_scope_resources_count
end

#policy_violations_countFixnum

Count of child resources in violation of the policy. Corresponds to the JSON property policyViolationsCount

Returns:

  • (Fixnum)


9741
9742
9743
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9741

def policy_violations_count
  @policy_violations_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9748
9749
9750
9751
9752
9753
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9748

def update!(**args)
  @conformant_resources_count = args[:conformant_resources_count] if args.key?(:conformant_resources_count)
  @evaluation_errors_count = args[:evaluation_errors_count] if args.key?(:evaluation_errors_count)
  @out_of_scope_resources_count = args[:out_of_scope_resources_count] if args.key?(:out_of_scope_resources_count)
  @policy_violations_count = args[:policy_violations_count] if args.key?(:policy_violations_count)
end