Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2PortRange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

A port range which is inclusive of the min and max values. Values are between 0 and 2^16-1. The max can be equal / must be not smaller than the min value. If min and max are equal this indicates that it is a single port.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2PortRange

Returns a new instance of GoogleCloudSecuritycenterV2PortRange.



9916
9917
9918
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9916

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#maxFixnum

Maximum port value. Corresponds to the JSON property max

Returns:

  • (Fixnum)


9909
9910
9911
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9909

def max
  @max
end

#minFixnum

Minimum port value. Corresponds to the JSON property min

Returns:

  • (Fixnum)


9914
9915
9916
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9914

def min
  @min
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9921
9922
9923
9924
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9921

def update!(**args)
  @max = args[:max] if args.key?(:max)
  @min = args[:min] if args.key?(:min)
end