Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Resource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Information related to the Google Cloud resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Resource

Returns a new instance of GoogleCloudSecuritycenterV2Resource.



10200
10201
10202
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10200

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adc_applicationGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2AdcApplication

Represents an ADC application associated with the finding. Corresponds to the JSON property adcApplication



10115
10116
10117
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10115

def adc_application
  @adc_application
end

#adc_application_templateGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2AdcApplicationTemplateRevision

Represents an ADC template associated with the finding. Corresponds to the JSON property adcApplicationTemplate



10120
10121
10122
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10120

def adc_application_template
  @adc_application_template
end

#adc_shared_templateGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2AdcSharedTemplateRevision

Represents an ADC shared template associated with the finding. Corresponds to the JSON property adcSharedTemplate



10125
10126
10127
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10125

def adc_shared_template
  @adc_shared_template
end

#applicationGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2ResourceApplication

The App Hub Application associated with the finding's resource. Corresponds to the JSON property application



10130
10131
10132
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10130

def application
  @application
end

#aws_metadataGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2AwsMetadata

AWS metadata associated with the resource, only applicable if the finding's cloud provider is Amazon Web Services. Corresponds to the JSON property awsMetadata



10136
10137
10138
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10136

def 
  @aws_metadata
end

#azure_metadataGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2AzureMetadata

Azure metadata associated with the resource, only applicable if the finding's cloud provider is Microsoft Azure. Corresponds to the JSON property azureMetadata



10142
10143
10144
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10142

def 
  @azure_metadata
end

#cloud_providerString

Indicates which cloud provider the finding is from. Corresponds to the JSON property cloudProvider

Returns:

  • (String)


10147
10148
10149
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10147

def cloud_provider
  @cloud_provider
end

#display_nameString

The human readable name of the resource. Corresponds to the JSON property displayName

Returns:

  • (String)


10152
10153
10154
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10152

def display_name
  @display_name
end

#gcp_metadataGoogle::Apis::SecuritycenterV1beta1::GcpMetadata

Google Cloud metadata associated with the resource. Only applicable if the finding's cloud provider is Google Cloud. Corresponds to the JSON property gcpMetadata



10158
10159
10160
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10158

def 
  @gcp_metadata
end

#locationString

The region or location of the service (if applicable). Corresponds to the JSON property location

Returns:

  • (String)


10163
10164
10165
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10163

def location
  @location
end

#nameString

The full resource name of the resource. See: https://cloud.google.com/apis/ design/resource_names#full_resource_name Corresponds to the JSON property name

Returns:

  • (String)


10169
10170
10171
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10169

def name
  @name
end

#resource_pathGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2ResourcePath

Represents the path of resources leading up to the resource this finding is about. Corresponds to the JSON property resourcePath



10175
10176
10177
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10175

def resource_path
  @resource_path
end

#resource_path_stringString

A string representation of the resource path. For Google Cloud, it has the format of organizations/organization_id/folders/folder_id/folders/ folder_id/projects/project_idwhere there can be any number of folders. For AWS, it has the format of `org/`organization_id`/ou/` organizational_unit_id`/ou/`organizational_unit_id`/account/`account_id where there can be any number of organizational units. For Azure, it has the format of mg/management_group_id/mg/management_group_id/subscription/ subscription_id/rg/resource_group_name`where there can be any number of management groups. Corresponds to the JSON propertyresourcePathString`

Returns:

  • (String)


10188
10189
10190
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10188

def resource_path_string
  @resource_path_string
end

#serviceString

The service or resource provider associated with the resource. Corresponds to the JSON property service

Returns:

  • (String)


10193
10194
10195
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10193

def service
  @service
end

#typeString

The full resource type of the resource. Corresponds to the JSON property type

Returns:

  • (String)


10198
10199
10200
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10198

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10205
10206
10207
10208
10209
10210
10211
10212
10213
10214
10215
10216
10217
10218
10219
10220
10221
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10205

def update!(**args)
  @adc_application = args[:adc_application] if args.key?(:adc_application)
  @adc_application_template = args[:adc_application_template] if args.key?(:adc_application_template)
  @adc_shared_template = args[:adc_shared_template] if args.key?(:adc_shared_template)
  @application = args[:application] if args.key?(:application)
  @aws_metadata = args[:aws_metadata] if args.key?(:aws_metadata)
  @azure_metadata = args[:azure_metadata] if args.key?(:azure_metadata)
  @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider)
  @display_name = args[:display_name] if args.key?(:display_name)
  @gcp_metadata = args[:gcp_metadata] if args.key?(:gcp_metadata)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @resource_path = args[:resource_path] if args.key?(:resource_path)
  @resource_path_string = args[:resource_path_string] if args.key?(:resource_path_string)
  @service = args[:service] if args.key?(:service)
  @type = args[:type] if args.key?(:type)
end