Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2SecretEnvironmentVariable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Environment variable containing the secret.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2SecretEnvironmentVariable

Returns a new instance of GoogleCloudSecuritycenterV2SecretEnvironmentVariable.



10432
10433
10434
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10432

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

Environment variable name as a JSON encoded string. Note that value is not included since the value contains the secret data, which is sensitive core content. Corresponds to the JSON property key

Returns:

  • (String)


10430
10431
10432
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10430

def key
  @key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10437
10438
10439
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10437

def update!(**args)
  @key = args[:key] if args.key?(:key)
end