Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2SecurityBulletin

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

SecurityBulletin are notifications of vulnerabilities of Google products.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2SecurityBulletin

Returns a new instance of GoogleCloudSecuritycenterV2SecurityBulletin.



10650
10651
10652
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10650

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bulletin_idString

ID of the bulletin corresponding to the vulnerability. Corresponds to the JSON property bulletinId

Returns:

  • (String)


10637
10638
10639
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10637

def bulletin_id
  @bulletin_id
end

#submission_timeString

Submission time of this Security Bulletin. Corresponds to the JSON property submissionTime

Returns:

  • (String)


10642
10643
10644
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10642

def submission_time
  @submission_time
end

#suggested_upgrade_versionString

This represents a version that the cluster receiving this notification should be upgraded to, based on its current version. For example, 1.15.0 Corresponds to the JSON property suggestedUpgradeVersion

Returns:

  • (String)


10648
10649
10650
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10648

def suggested_upgrade_version
  @suggested_upgrade_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10655
10656
10657
10658
10659
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10655

def update!(**args)
  @bulletin_id = args[:bulletin_id] if args.key?(:bulletin_id)
  @submission_time = args[:submission_time] if args.key?(:submission_time)
  @suggested_upgrade_version = args[:suggested_upgrade_version] if args.key?(:suggested_upgrade_version)
end