Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2SensitivityScore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2SensitivityScore

Returns a new instance of GoogleCloudSecuritycenterV2SensitivityScore.



10714
10715
10716
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10714

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#scoreString

The sensitivity score applied to the resource. Corresponds to the JSON property score

Returns:

  • (String)


10712
10713
10714
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10712

def score
  @score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10719
10720
10721
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10719

def update!(**args)
  @score = args[:score] if args.key?(:score)
end