Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2TicketInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Information about the ticket, if any, that is being used to track the resolution of the issue that is identified by this finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2TicketInfo

Returns a new instance of GoogleCloudSecuritycenterV2TicketInfo.



10993
10994
10995
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10993

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigneeString

The assignee of the ticket in the ticket system. Corresponds to the JSON property assignee

Returns:

  • (String)


10966
10967
10968
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10966

def assignee
  @assignee
end

#descriptionString

The description of the ticket in the ticket system. Corresponds to the JSON property description

Returns:

  • (String)


10971
10972
10973
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10971

def description
  @description
end

#idString

The identifier of the ticket in the ticket system. Corresponds to the JSON property id

Returns:

  • (String)


10976
10977
10978
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10976

def id
  @id
end

#statusString

The latest status of the ticket, as reported by the ticket system. Corresponds to the JSON property status

Returns:

  • (String)


10981
10982
10983
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10981

def status
  @status
end

#update_timeString

The time when the ticket was last updated, as reported by the ticket system. Corresponds to the JSON property updateTime

Returns:

  • (String)


10986
10987
10988
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10986

def update_time
  @update_time
end

#uriString

The link to the ticket in the ticket system. Corresponds to the JSON property uri

Returns:

  • (String)


10991
10992
10993
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10991

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10998
10999
11000
11001
11002
11003
11004
11005
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10998

def update!(**args)
  @assignee = args[:assignee] if args.key?(:assignee)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @status = args[:status] if args.key?(:status)
  @update_time = args[:update_time] if args.key?(:update_time)
  @uri = args[:uri] if args.key?(:uri)
end