Class: Google::Apis::SecuritycenterV1beta1::GroupAssetsRequest
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GroupAssetsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Request message for grouping by assets.
Instance Attribute Summary collapse
-
#compare_duration ⇒ String
When compare_duration is set, the Asset's "state" property is updated to indicate whether the asset was added, removed, or remained present during the compare_duration period of time that precedes the read_time.
-
#filter ⇒ String
Expression that defines the filter to apply across assets.
-
#group_by ⇒ String
Required.
-
#page_size ⇒ Fixnum
The maximum number of results to return in a single response.
-
#page_token ⇒ String
The value returned by the last
GroupAssetsResponse; indicates that this is a continuation of a priorGroupAssetscall, and that the system should return the next page of data. -
#read_time ⇒ String
Time used as a reference point when filtering assets.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GroupAssetsRequest
constructor
A new instance of GroupAssetsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GroupAssetsRequest
Returns a new instance of GroupAssetsRequest.
11070 11071 11072 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11070 def initialize(**args) update!(**args) end |
Instance Attribute Details
#compare_duration ⇒ String
When compare_duration is set, the Asset's "state" property is updated to
indicate whether the asset was added, removed, or remained present during the
compare_duration period of time that precedes the read_time. This is the time
between (read_time - compare_duration) and read_time. The state value is
derived based on the presence of the asset at the two points in time.
Intermediate state changes between the two times don't affect the result. For
example, the results aren't affected if the asset is removed and re-created
again. Possible "state" values when compare_duration is specified: * "ADDED":
indicates that the asset was not present before compare_duration, but present
at reference_time. * "REMOVED": indicates that the asset was present at the
start of compare_duration, but not present at reference_time. * "ACTIVE":
indicates that the asset was present at both the start and the end of the time
period defined by compare_duration and reference_time. This field is ignored
if state is not a field in group_by.
Corresponds to the JSON property compareDuration
11020 11021 11022 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11020 def compare_duration @compare_duration end |
#filter ⇒ String
Expression that defines the filter to apply across assets. The expression is a
list of zero or more restrictions combined via logical operators AND and OR
. Parentheses are not supported, and OR has higher precedence than AND.
Restrictions have the form and may have a - character in front of them
to indicate negation. The fields map to those defined in the Asset resource.
Examples include: * name * security_center_properties.resource_name *
resource_properties.a_property * security_marks.marks.marka The supported
operators are: * = for all value types. * >, <, >=, <= for integer
values. * :, meaning substring matching, for strings. The supported value
types are: * string literals in quotes. * integer literals without quotes. *
boolean literals true and false without quotes. For example,
resource_properties.size = 100 is a valid filter string.
Corresponds to the JSON property filter
11036 11037 11038 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11036 def filter @filter end |
#group_by ⇒ String
Required. Expression that defines what assets fields to use for grouping. The
string value should follow SQL syntax: comma separated list of fields. For
example: "security_center_properties.resource_project,
security_center_properties.project". The following fields are supported when
compare_duration is not set: * security_center_properties.resource_project *
security_center_properties.resource_type * security_center_properties.
resource_parent The following fields are supported when compare_duration is
set: * security_center_properties.resource_type
Corresponds to the JSON property groupBy
11048 11049 11050 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11048 def group_by @group_by end |
#page_size ⇒ Fixnum
The maximum number of results to return in a single response. Default is 10,
minimum is 1, maximum is 1000.
Corresponds to the JSON property pageSize
11054 11055 11056 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11054 def page_size @page_size end |
#page_token ⇒ String
The value returned by the last GroupAssetsResponse; indicates that this is a
continuation of a prior GroupAssets call, and that the system should return
the next page of data.
Corresponds to the JSON property pageToken
11061 11062 11063 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11061 def page_token @page_token end |
#read_time ⇒ String
Time used as a reference point when filtering assets. The filter is limited to
assets existing at the supplied time and their values are those at that
specific time. Absence of this field will default to the API's version of NOW.
Corresponds to the JSON property readTime
11068 11069 11070 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11068 def read_time @read_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11075 11076 11077 11078 11079 11080 11081 11082 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11075 def update!(**args) @compare_duration = args[:compare_duration] if args.key?(:compare_duration) @filter = args[:filter] if args.key?(:filter) @group_by = args[:group_by] if args.key?(:group_by) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @read_time = args[:read_time] if args.key?(:read_time) end |