Class: Google::Apis::SecuritycenterV1beta1::GroupAssetsResponse
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GroupAssetsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Response message for grouping by assets.
Instance Attribute Summary collapse
-
#group_by_results ⇒ Array<Google::Apis::SecuritycenterV1beta1::GroupResult>
Group results.
-
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more results.
-
#read_time ⇒ String
Time used for executing the groupBy request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GroupAssetsResponse
constructor
A new instance of GroupAssetsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GroupAssetsResponse
Returns a new instance of GroupAssetsResponse.
11107 11108 11109 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11107 def initialize(**args) update!(**args) end |
Instance Attribute Details
#group_by_results ⇒ Array<Google::Apis::SecuritycenterV1beta1::GroupResult>
Group results. There exists an element for each existing unique combination of
property/values. The element contains a count for the number of times those
specific property/values appear.
Corresponds to the JSON property groupByResults
11094 11095 11096 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11094 def group_by_results @group_by_results end |
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more
results.
Corresponds to the JSON property nextPageToken
11100 11101 11102 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11100 def next_page_token @next_page_token end |
#read_time ⇒ String
Time used for executing the groupBy request.
Corresponds to the JSON property readTime
11105 11106 11107 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11105 def read_time @read_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11112 11113 11114 11115 11116 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11112 def update!(**args) @group_by_results = args[:group_by_results] if args.key?(:group_by_results) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @read_time = args[:read_time] if args.key?(:read_time) end |