Class: Google::Apis::SecuritycenterV1beta1::GroupFindingsRequest
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GroupFindingsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Request message for grouping by findings.
Instance Attribute Summary collapse
-
#filter ⇒ String
Expression that defines the filter to apply across findings.
-
#group_by ⇒ String
Required.
-
#page_size ⇒ Fixnum
The maximum number of results to return in a single response.
-
#page_token ⇒ String
The value returned by the last
GroupFindingsResponse; indicates that this is a continuation of a priorGroupFindingscall, and that the system should return the next page of data. -
#read_time ⇒ String
Time used as a reference point when filtering findings.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GroupFindingsRequest
constructor
A new instance of GroupFindingsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GroupFindingsRequest
Returns a new instance of GroupFindingsRequest.
10885 10886 10887 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10885 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filter ⇒ String
Expression that defines the filter to apply across findings. The expression is
a list of one or more restrictions combined via logical operators AND and
OR. Parentheses are not supported, and OR has higher precedence than AND.
Restrictions have the form and may have a - character in front of them
to indicate negation. Examples include: * name * source_properties.a_property *
security_marks.marks.marka The supported operators are: * = for all value
types. * >, <, >=, <= for integer values. * :, meaning substring
matching, for strings. The supported value types are: * string literals in
quotes. * integer literals without quotes. * boolean literals true and
false without quotes. For example, source_properties.size = 100 is a valid
filter string.
Corresponds to the JSON property filter
10855 10856 10857 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10855 def filter @filter end |
#group_by ⇒ String
Required. Expression that defines what assets fields to use for grouping (
including state). The string value should follow SQL syntax: comma separated
list of fields. For example: "parent,resource_name". The following fields are
supported: * resource_name * category * state * parent
Corresponds to the JSON property groupBy
10863 10864 10865 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10863 def group_by @group_by end |
#page_size ⇒ Fixnum
The maximum number of results to return in a single response. Default is 10,
minimum is 1, maximum is 1000.
Corresponds to the JSON property pageSize
10869 10870 10871 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10869 def page_size @page_size end |
#page_token ⇒ String
The value returned by the last GroupFindingsResponse; indicates that this is
a continuation of a prior GroupFindings call, and that the system should
return the next page of data.
Corresponds to the JSON property pageToken
10876 10877 10878 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10876 def page_token @page_token end |
#read_time ⇒ String
Time used as a reference point when filtering findings. The filter is limited
to findings existing at the supplied time and their values are those at that
specific time. Absence of this field will default to the API's version of NOW.
Corresponds to the JSON property readTime
10883 10884 10885 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10883 def read_time @read_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10890 10891 10892 10893 10894 10895 10896 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10890 def update!(**args) @filter = args[:filter] if args.key?(:filter) @group_by = args[:group_by] if args.key?(:group_by) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @read_time = args[:read_time] if args.key?(:read_time) end |