Class: Google::Apis::SecuritycenterV1beta1::HttpResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

The http response returned by the web application.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpResponse

Returns a new instance of HttpResponse.



11424
11425
11426
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11424

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#pathString

The http path for which response code was returned by web application, for example, "https://test-app.a.run.app/test". Corresponds to the JSON property path

Returns:

  • (String)


11417
11418
11419
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11417

def path
  @path
end

#status_codeString

The http response code returned by the web application, for example, 200. Corresponds to the JSON property statusCode

Returns:

  • (String)


11422
11423
11424
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11422

def status_code
  @status_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11429
11430
11431
11432
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11429

def update!(**args)
  @path = args[:path] if args.key?(:path)
  @status_code = args[:status_code] if args.key?(:status_code)
end