Class: Google::Apis::SecuritycenterV1beta1::IpRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

IP rule information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IpRule

Returns a new instance of IpRule.



11395
11396
11397
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11395

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#port_rangesArray<Google::Apis::SecuritycenterV1beta1::PortRange>

Optional. An optional list of ports to which this rule applies. This field is only applicable for the UDP or (S)TCP protocols. Each entry must be either an integer or a range including a min and max port number. Corresponds to the JSON property portRanges



11386
11387
11388
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11386

def port_ranges
  @port_ranges
end

#protocolString

The IP protocol this rule applies to. This value can either be one of the following well known protocol strings (TCP, UDP, ICMP, ESP, AH, IPIP, SCTP) or a string representation of the integer value. Corresponds to the JSON property protocol

Returns:

  • (String)


11393
11394
11395
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11393

def protocol
  @protocol
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11400
11401
11402
11403
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11400

def update!(**args)
  @port_ranges = args[:port_ranges] if args.key?(:port_ranges)
  @protocol = args[:protocol] if args.key?(:protocol)
end