Class: Google::Apis::SecuritycenterV1beta1::IpRules
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::IpRules
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
IP rules associated with the finding.
Instance Attribute Summary collapse
-
#allowed ⇒ Google::Apis::SecuritycenterV1beta1::Allowed
Allowed IP rule.
-
#denied ⇒ Google::Apis::SecuritycenterV1beta1::Denied
Denied IP rule.
-
#destination_ip_ranges ⇒ Array<String>
If destination IP ranges are specified, the firewall rule applies only to traffic that has a destination IP address in these ranges.
-
#direction ⇒ String
The direction that the rule is applicable to, one of ingress or egress.
-
#exposed_services ⇒ Array<String>
Name of the network protocol service, such as FTP, that is exposed by the open port.
-
#source_ip_ranges ⇒ Array<String>
If source IP ranges are specified, the firewall rule applies only to traffic that has a source IP address in these ranges.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IpRules
constructor
A new instance of IpRules.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IpRules
Returns a new instance of IpRules.
11616 11617 11618 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11616 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed ⇒ Google::Apis::SecuritycenterV1beta1::Allowed
Allowed IP rule.
Corresponds to the JSON property allowed
11583 11584 11585 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11583 def allowed @allowed end |
#denied ⇒ Google::Apis::SecuritycenterV1beta1::Denied
Denied IP rule.
Corresponds to the JSON property denied
11588 11589 11590 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11588 def denied @denied end |
#destination_ip_ranges ⇒ Array<String>
If destination IP ranges are specified, the firewall rule applies only to
traffic that has a destination IP address in these ranges. These ranges must
be expressed in CIDR format. Only supports IPv4.
Corresponds to the JSON property destinationIpRanges
11595 11596 11597 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11595 def destination_ip_ranges @destination_ip_ranges end |
#direction ⇒ String
The direction that the rule is applicable to, one of ingress or egress.
Corresponds to the JSON property direction
11600 11601 11602 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11600 def direction @direction end |
#exposed_services ⇒ Array<String>
Name of the network protocol service, such as FTP, that is exposed by the open
port. Follows the naming convention available at: https://www.iana.org/
assignments/service-names-port-numbers/service-names-port-numbers.xhtml.
Corresponds to the JSON property exposedServices
11607 11608 11609 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11607 def exposed_services @exposed_services end |
#source_ip_ranges ⇒ Array<String>
If source IP ranges are specified, the firewall rule applies only to traffic
that has a source IP address in these ranges. These ranges must be expressed
in CIDR format. Only supports IPv4.
Corresponds to the JSON property sourceIpRanges
11614 11615 11616 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11614 def source_ip_ranges @source_ip_ranges end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11621 11622 11623 11624 11625 11626 11627 11628 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11621 def update!(**args) @allowed = args[:allowed] if args.key?(:allowed) @denied = args[:denied] if args.key?(:denied) @destination_ip_ranges = args[:destination_ip_ranges] if args.key?(:destination_ip_ranges) @direction = args[:direction] if args.key?(:direction) @exposed_services = args[:exposed_services] if args.key?(:exposed_services) @source_ip_ranges = args[:source_ip_ranges] if args.key?(:source_ip_ranges) end |