Class: Google::Apis::SecuritycenterV1beta1::Job

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Describes a job

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Job

Returns a new instance of Job.



11655
11656
11657
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11655

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_codeFixnum

Optional. If the job did not complete successfully, this field describes why. Corresponds to the JSON property errorCode

Returns:

  • (Fixnum)


11638
11639
11640
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11638

def error_code
  @error_code
end

#locationString

Optional. Gives the location where the job ran, such as US or europe-west1 Corresponds to the JSON property location

Returns:

  • (String)


11643
11644
11645
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11643

def location
  @location
end

#nameString

The fully-qualified name for a job. e.g. projects//jobs/ Corresponds to the JSON property name

Returns:

  • (String)


11648
11649
11650
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11648

def name
  @name
end

#stateString

Output only. State of the job, such as RUNNING or PENDING. Corresponds to the JSON property state

Returns:

  • (String)


11653
11654
11655
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11653

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11660
11661
11662
11663
11664
11665
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11660

def update!(**args)
  @error_code = args[:error_code] if args.key?(:error_code)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
end