Class: Google::Apis::SecuritycenterV1beta1::Kubernetes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Kubernetes-related attributes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Kubernetes

Returns a new instance of Kubernetes.



11798
11799
11800
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11798

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_reviewsArray<Google::Apis::SecuritycenterV1beta1::AccessReview>

Provides information on any Kubernetes access reviews (privilege checks) relevant to the finding. Corresponds to the JSON property accessReviews



11757
11758
11759
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11757

def access_reviews
  @access_reviews
end

#bindingsArray<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1Binding>

Provides Kubernetes role binding information for findings that involve RoleBindings or ClusterRoleBindings. Corresponds to the JSON property bindings



11764
11765
11766
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11764

def bindings
  @bindings
end

#node_poolsArray<Google::Apis::SecuritycenterV1beta1::NodePool>

GKE node pools associated with the finding. This field contains node pool information for each node, when it is available. Corresponds to the JSON property nodePools



11771
11772
11773
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11771

def node_pools
  @node_pools
end

#nodesArray<Google::Apis::SecuritycenterV1beta1::Node>

Provides Kubernetes node information. Corresponds to the JSON property nodes



11777
11778
11779
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11777

def nodes
  @nodes
end

#objectsArray<Google::Apis::SecuritycenterV1beta1::Object>

Kubernetes objects related to the finding. Corresponds to the JSON property objects



11782
11783
11784
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11782

def objects
  @objects
end

#podsArray<Google::Apis::SecuritycenterV1beta1::Pod>

Kubernetes Pods associated with the finding. This field contains Pod records for each container that is owned by a Pod. Corresponds to the JSON property pods



11789
11790
11791
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11789

def pods
  @pods
end

#rolesArray<Google::Apis::SecuritycenterV1beta1::Role>

Provides Kubernetes role information for findings that involve Roles or ClusterRoles. Corresponds to the JSON property roles



11796
11797
11798
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11796

def roles
  @roles
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11803
11804
11805
11806
11807
11808
11809
11810
11811
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11803

def update!(**args)
  @access_reviews = args[:access_reviews] if args.key?(:access_reviews)
  @bindings = args[:bindings] if args.key?(:bindings)
  @node_pools = args[:node_pools] if args.key?(:node_pools)
  @nodes = args[:nodes] if args.key?(:nodes)
  @objects = args[:objects] if args.key?(:objects)
  @pods = args[:pods] if args.key?(:pods)
  @roles = args[:roles] if args.key?(:roles)
end