Class: Google::Apis::SecuritycenterV1beta1::ListAssetsResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Result containing the Asset and its State.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListAssetsResult

Returns a new instance of ListAssetsResult.



11729
11730
11731
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11729

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assetGoogle::Apis::SecuritycenterV1beta1::Asset

Security Command Center representation of a Google Cloud resource. The Asset is a Security Command Center resource that captures information about a single Google Cloud resource. All modifications to an Asset are only within the context of Security Command Center and don't affect the referenced Google Cloud resource. Corresponds to the JSON property asset



11722
11723
11724
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11722

def asset
  @asset
end

#stateString

State of the asset. Corresponds to the JSON property state

Returns:

  • (String)


11727
11728
11729
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11727

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11734
11735
11736
11737
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11734

def update!(**args)
  @asset = args[:asset] if args.key?(:asset)
  @state = args[:state] if args.key?(:state)
end