Class: Google::Apis::SecuritycenterV1beta1::ListFindingsResponse
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::ListFindingsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Response message for listing findings.
Instance Attribute Summary collapse
-
#findings ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1beta1Finding>
Findings matching the list request.
-
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more results.
-
#read_time ⇒ String
Time used for executing the list request.
-
#total_size ⇒ Fixnum
The total number of findings matching the query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListFindingsResponse
constructor
A new instance of ListFindingsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListFindingsResponse
Returns a new instance of ListFindingsResponse.
11484 11485 11486 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11484 def initialize(**args) update!(**args) end |
Instance Attribute Details
#findings ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1beta1Finding>
Findings matching the list request.
Corresponds to the JSON property findings
11466 11467 11468 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11466 def findings @findings end |
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more
results.
Corresponds to the JSON property nextPageToken
11472 11473 11474 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11472 def next_page_token @next_page_token end |
#read_time ⇒ String
Time used for executing the list request.
Corresponds to the JSON property readTime
11477 11478 11479 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11477 def read_time @read_time end |
#total_size ⇒ Fixnum
The total number of findings matching the query.
Corresponds to the JSON property totalSize
11482 11483 11484 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11482 def total_size @total_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11489 11490 11491 11492 11493 11494 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11489 def update!(**args) @findings = args[:findings] if args.key?(:findings) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @read_time = args[:read_time] if args.key?(:read_time) @total_size = args[:total_size] if args.key?(:total_size) end |