Class: Google::Apis::SecuritycenterV1beta1::Notebook

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Represents a Jupyter notebook IPYNB file, such as a Colab Enterprise notebook file, that is associated with a finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Notebook

Returns a new instance of Notebook.



12071
12072
12073
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12071

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_authorString

The user ID of the latest author to modify the notebook. Corresponds to the JSON property lastAuthor

Returns:

  • (String)


12054
12055
12056
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12054

def last_author
  @last_author
end

#nameString

The name of the notebook. Corresponds to the JSON property name

Returns:

  • (String)


12059
12060
12061
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12059

def name
  @name
end

#notebook_update_timeString

The most recent time the notebook was updated. Corresponds to the JSON property notebookUpdateTime

Returns:

  • (String)


12064
12065
12066
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12064

def notebook_update_time
  @notebook_update_time
end

#serviceString

The source notebook service, for example, "Colab Enterprise". Corresponds to the JSON property service

Returns:

  • (String)


12069
12070
12071
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12069

def service
  @service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12076
12077
12078
12079
12080
12081
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12076

def update!(**args)
  @last_author = args[:last_author] if args.key?(:last_author)
  @name = args[:name] if args.key?(:name)
  @notebook_update_time = args[:notebook_update_time] if args.key?(:notebook_update_time)
  @service = args[:service] if args.key?(:service)
end