Class: Google::Apis::SecuritycenterV1beta1::Object

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Kubernetes object related to the finding, uniquely identified by GKNN. Used if the object Kind is not one of Pod, Node, NodePool, Binding, or AccessReview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Object

Returns a new instance of Object.



12287
12288
12289
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12287

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#containersArray<Google::Apis::SecuritycenterV1beta1::Container>

Pod containers associated with this finding, if any. Corresponds to the JSON property containers



12262
12263
12264
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12262

def containers
  @containers
end

#groupString

Kubernetes object group, such as "policy.k8s.io/v1". Corresponds to the JSON property group

Returns:

  • (String)


12267
12268
12269
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12267

def group
  @group
end

#kindString

Kubernetes object kind, such as "Namespace". Corresponds to the JSON property kind

Returns:

  • (String)


12272
12273
12274
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12272

def kind
  @kind
end

#nameString

Kubernetes object name. For details see https://kubernetes.io/docs/concepts/ overview/working-with-objects/names/. Corresponds to the JSON property name

Returns:

  • (String)


12278
12279
12280
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12278

def name
  @name
end

#nsString

Kubernetes object namespace. Must be a valid DNS label. Named "ns" to avoid collision with C++ namespace keyword. For details see https://kubernetes.io/ docs/tasks/administer-cluster/namespaces/. Corresponds to the JSON property ns

Returns:

  • (String)


12285
12286
12287
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12285

def ns
  @ns
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12292
12293
12294
12295
12296
12297
12298
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12292

def update!(**args)
  @containers = args[:containers] if args.key?(:containers)
  @group = args[:group] if args.key?(:group)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @ns = args[:ns] if args.key?(:ns)
end