Class: Google::Apis::SecuritycenterV1beta1::Operation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

This resource represents a long-running operation that is the result of a network API call.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Operation

Returns a new instance of Operation.



12349
12350
12351
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12349

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#doneBoolean Also known as: done?

If the value is false, it means the operation is still in progress. If true , the operation is completed, and either error or response is available. Corresponds to the JSON property done

Returns:

  • (Boolean)


12310
12311
12312
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12310

def done
  @done
end

#errorGoogle::Apis::SecuritycenterV1beta1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



12321
12322
12323
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12321

def error
  @error
end

#metadataHash<String,Object>

Service-specific metadata associated with the operation. It typically contains progress information and common metadata such as create time. Some services might not provide such metadata. Any method that returns a long-running operation should document the metadata type, if any. Corresponds to the JSON property metadata

Returns:



12329
12330
12331
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12329

def 
  @metadata
end

#nameString

The server-assigned name, which is only unique within the same service that originally returns it. If you use the default HTTP mapping, the name should be a resource name ending with operations/unique_id`. Corresponds to the JSON propertyname`

Returns:

  • (String)


12336
12337
12338
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12336

def name
  @name
end

#responseHash<String,Object>

The normal, successful response of the operation. If the original method returns no data on success, such as Delete, the response is google.protobuf. Empty. If the original method is standard Get/Create/Update, the response should be the resource. For other methods, the response should have the type XxxResponse, where Xxx is the original method name. For example, if the original method name is TakeSnapshot(), the inferred response type is TakeSnapshotResponse. Corresponds to the JSON property response

Returns:



12347
12348
12349
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12347

def response
  @response
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12354
12355
12356
12357
12358
12359
12360
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12354

def update!(**args)
  @done = args[:done] if args.key?(:done)
  @error = args[:error] if args.key?(:error)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @response = args[:response] if args.key?(:response)
end