Class: Google::Apis::SecuritycenterV1beta1::OrganizationSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

User specified settings that are attached to the Security Command Center organization.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OrganizationSettings

Returns a new instance of OrganizationSettings.



12408
12409
12410
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12408

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asset_discovery_configGoogle::Apis::SecuritycenterV1beta1::AssetDiscoveryConfig

The configuration used for Asset Discovery runs. Corresponds to the JSON property assetDiscoveryConfig



12391
12392
12393
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12391

def asset_discovery_config
  @asset_discovery_config
end

#enable_asset_discoveryBoolean Also known as: enable_asset_discovery?

A flag that indicates if Asset Discovery should be enabled. If the flag is set to true, then discovery of assets will occur. If it is set to false, all historical assets will remain, but discovery of future assets will not occur. Corresponds to the JSON property enableAssetDiscovery

Returns:

  • (Boolean)


12398
12399
12400
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12398

def enable_asset_discovery
  @enable_asset_discovery
end

#nameString

The relative resource name of the settings. See: https://cloud.google.com/apis/ design/resource_names#relative_resource_name Example: "organizations/ organization_id/organizationSettings". Corresponds to the JSON property name

Returns:

  • (String)


12406
12407
12408
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12406

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12413
12414
12415
12416
12417
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12413

def update!(**args)
  @asset_discovery_config = args[:asset_discovery_config] if args.key?(:asset_discovery_config)
  @enable_asset_discovery = args[:enable_asset_discovery] if args.key?(:enable_asset_discovery)
  @name = args[:name] if args.key?(:name)
end