Class: Google::Apis::SecuritycenterV1beta1::PortRange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

A port range which is inclusive of the min and max values. Values are between 0 and 2^16-1. The max can be equal / must be not smaller than the min value. If min and max are equal this indicates that it is a single port.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PortRange

Returns a new instance of PortRange.



12215
12216
12217
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12215

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#maxFixnum

Maximum port value. Corresponds to the JSON property max

Returns:

  • (Fixnum)


12208
12209
12210
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12208

def max
  @max
end

#minFixnum

Minimum port value. Corresponds to the JSON property min

Returns:

  • (Fixnum)


12213
12214
12215
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12213

def min
  @min
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12220
12221
12222
12223
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12220

def update!(**args)
  @max = args[:max] if args.key?(:max)
  @min = args[:min] if args.key?(:min)
end