Class: Google::Apis::SecuritycenterV1beta1::Process
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::Process
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Represents an operating system process.
Instance Attribute Summary collapse
-
#args ⇒ Array<String>
Process arguments as JSON encoded strings.
-
#arguments_truncated ⇒ Boolean
(also: #arguments_truncated?)
True if
argsis incomplete. -
#binary ⇒ Google::Apis::SecuritycenterV1beta1::File
File information about the related binary/library used by an executable, or the script used by a script interpreter Corresponds to the JSON property
binary. -
#env_variables ⇒ Array<Google::Apis::SecuritycenterV1beta1::EnvironmentVariable>
Process environment variables.
-
#env_variables_truncated ⇒ Boolean
(also: #env_variables_truncated?)
True if
env_variablesis incomplete. -
#libraries ⇒ Array<Google::Apis::SecuritycenterV1beta1::File>
File information for libraries loaded by the process.
-
#name ⇒ String
The process name, as displayed in utilities like
topandps. -
#parent_pid ⇒ Fixnum
The parent process ID.
-
#pid ⇒ Fixnum
The process ID.
-
#script ⇒ Google::Apis::SecuritycenterV1beta1::File
File information about the related binary/library used by an executable, or the script used by a script interpreter Corresponds to the JSON property
script. -
#user_id ⇒ Fixnum
The ID of the user that executed the process.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Process
constructor
A new instance of Process.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Process
Returns a new instance of Process.
12785 12786 12787 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12785 def initialize(**args) update!(**args) end |
Instance Attribute Details
#args ⇒ Array<String>
Process arguments as JSON encoded strings.
Corresponds to the JSON property args
12727 12728 12729 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12727 def args @args end |
#arguments_truncated ⇒ Boolean Also known as: arguments_truncated?
True if args is incomplete.
Corresponds to the JSON property argumentsTruncated
12732 12733 12734 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12732 def arguments_truncated @arguments_truncated end |
#binary ⇒ Google::Apis::SecuritycenterV1beta1::File
File information about the related binary/library used by an executable, or
the script used by a script interpreter
Corresponds to the JSON property binary
12739 12740 12741 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12739 def binary @binary end |
#env_variables ⇒ Array<Google::Apis::SecuritycenterV1beta1::EnvironmentVariable>
Process environment variables.
Corresponds to the JSON property envVariables
12744 12745 12746 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12744 def env_variables @env_variables end |
#env_variables_truncated ⇒ Boolean Also known as: env_variables_truncated?
True if env_variables is incomplete.
Corresponds to the JSON property envVariablesTruncated
12749 12750 12751 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12749 def env_variables_truncated @env_variables_truncated end |
#libraries ⇒ Array<Google::Apis::SecuritycenterV1beta1::File>
File information for libraries loaded by the process.
Corresponds to the JSON property libraries
12755 12756 12757 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12755 def libraries @libraries end |
#name ⇒ String
The process name, as displayed in utilities like top and ps. This name can
be accessed through /proc/[pid]/comm and changed with prctl(PR_SET_NAME).
Corresponds to the JSON property name
12761 12762 12763 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12761 def name @name end |
#parent_pid ⇒ Fixnum
The parent process ID.
Corresponds to the JSON property parentPid
12766 12767 12768 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12766 def parent_pid @parent_pid end |
#pid ⇒ Fixnum
The process ID.
Corresponds to the JSON property pid
12771 12772 12773 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12771 def pid @pid end |
#script ⇒ Google::Apis::SecuritycenterV1beta1::File
File information about the related binary/library used by an executable, or
the script used by a script interpreter
Corresponds to the JSON property script
12777 12778 12779 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12777 def script @script end |
#user_id ⇒ Fixnum
The ID of the user that executed the process. E.g. If this is the root user
this will always be 0.
Corresponds to the JSON property userId
12783 12784 12785 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12783 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12790 12791 12792 12793 12794 12795 12796 12797 12798 12799 12800 12801 12802 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12790 def update!(**args) @args = args[:args] if args.key?(:args) @arguments_truncated = args[:arguments_truncated] if args.key?(:arguments_truncated) @binary = args[:binary] if args.key?(:binary) @env_variables = args[:env_variables] if args.key?(:env_variables) @env_variables_truncated = args[:env_variables_truncated] if args.key?(:env_variables_truncated) @libraries = args[:libraries] if args.key?(:libraries) @name = args[:name] if args.key?(:name) @parent_pid = args[:parent_pid] if args.key?(:parent_pid) @pid = args[:pid] if args.key?(:pid) @script = args[:script] if args.key?(:script) @user_id = args[:user_id] if args.key?(:user_id) end |