Class: Google::Apis::SecuritycenterV1beta1::SecretEnvironmentVariable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Environment variable containing the secret.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecretEnvironmentVariable

Returns a new instance of SecretEnvironmentVariable.



12876
12877
12878
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12876

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

Environment variable name as a JSON encoded string. Note that value is not included since the value contains the secret data, which is sensitive core content. Corresponds to the JSON property key

Returns:

  • (String)


12874
12875
12876
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12874

def key
  @key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12881
12882
12883
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12881

def update!(**args)
  @key = args[:key] if args.key?(:key)
end