Class: Google::Apis::SecuritycenterV1beta1::SecurityBulletin

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

SecurityBulletin are notifications of vulnerabilities of Google products.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityBulletin

Returns a new instance of SecurityBulletin.



12626
12627
12628
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12626

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bulletin_idString

ID of the bulletin corresponding to the vulnerability. Corresponds to the JSON property bulletinId

Returns:

  • (String)


12613
12614
12615
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12613

def bulletin_id
  @bulletin_id
end

#submission_timeString

Submission time of this Security Bulletin. Corresponds to the JSON property submissionTime

Returns:

  • (String)


12618
12619
12620
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12618

def submission_time
  @submission_time
end

#suggested_upgrade_versionString

This represents a version that the cluster receiving this notification should be upgraded to, based on its current version. For example, 1.15.0 Corresponds to the JSON property suggestedUpgradeVersion

Returns:

  • (String)


12624
12625
12626
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12624

def suggested_upgrade_version
  @suggested_upgrade_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12631
12632
12633
12634
12635
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12631

def update!(**args)
  @bulletin_id = args[:bulletin_id] if args.key?(:bulletin_id)
  @submission_time = args[:submission_time] if args.key?(:submission_time)
  @suggested_upgrade_version = args[:suggested_upgrade_version] if args.key?(:suggested_upgrade_version)
end