Class: Google::Apis::SecuritycenterV1beta1::SecurityCenterProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Security Command Center managed properties. These properties are managed by Security Command Center and cannot be modified by the user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityCenterProperties

Returns a new instance of SecurityCenterProperties.



13168
13169
13170
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13168

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_nameString

Immutable. The full resource name of the Google Cloud resource this asset represents. This field is immutable after create time. See: https://cloud. google.com/apis/design/resource_names#full_resource_name Corresponds to the JSON property resourceName

Returns:

  • (String)


13142
13143
13144
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13142

def resource_name
  @resource_name
end

#resource_ownersArray<String>

Owners of the Google Cloud resource. Corresponds to the JSON property resourceOwners

Returns:

  • (Array<String>)


13147
13148
13149
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13147

def resource_owners
  @resource_owners
end

#resource_parentString

The full resource name of the immediate parent of the resource. See: https:// cloud.google.com/apis/design/resource_names#full_resource_name Corresponds to the JSON property resourceParent

Returns:

  • (String)


13153
13154
13155
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13153

def resource_parent
  @resource_parent
end

#resource_projectString

The full resource name of the project the resource belongs to. See: https:// cloud.google.com/apis/design/resource_names#full_resource_name Corresponds to the JSON property resourceProject

Returns:

  • (String)


13159
13160
13161
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13159

def resource_project
  @resource_project
end

#resource_typeString

The type of the Google Cloud resource. Examples include: APPLICATION, PROJECT, and ORGANIZATION. This is a case insensitive field defined by Security Command Center and/or the producer of the resource and is immutable after create time. Corresponds to the JSON property resourceType

Returns:

  • (String)


13166
13167
13168
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13166

def resource_type
  @resource_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13173
13174
13175
13176
13177
13178
13179
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13173

def update!(**args)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @resource_owners = args[:resource_owners] if args.key?(:resource_owners)
  @resource_parent = args[:resource_parent] if args.key?(:resource_parent)
  @resource_project = args[:resource_project] if args.key?(:resource_project)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
end