Class: Google::Apis::SecuritycenterV1beta1::SecurityPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Information about the Google Cloud Armor security policy relevant to the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicy

Returns a new instance of SecurityPolicy.



13253
13254
13255
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13253

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The name of the Google Cloud Armor security policy, for example, "my-security- policy". Corresponds to the JSON property name

Returns:

  • (String)


13238
13239
13240
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13238

def name
  @name
end

#previewBoolean Also known as: preview?

Whether or not the associated rule or policy is in preview mode. Corresponds to the JSON property preview

Returns:

  • (Boolean)


13243
13244
13245
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13243

def preview
  @preview
end

#typeString

The type of Google Cloud Armor security policy for example, 'backend security policy', 'edge security policy', 'network edge security policy', or 'always-on DDoS protection'. Corresponds to the JSON property type

Returns:

  • (String)


13251
13252
13253
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13251

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13258
13259
13260
13261
13262
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13258

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @preview = args[:preview] if args.key?(:preview)
  @type = args[:type] if args.key?(:type)
end