Class: Google::Apis::SecuritycenterV1beta1::SecurityPosture
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::SecurityPosture
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Represents a posture that is deployed on Google Cloud by the Security Command Center Posture Management service. A posture contains one or more policy sets. A policy set is a group of policies that enforce a set of security rules on Google Cloud.
Instance Attribute Summary collapse
-
#changed_policy ⇒ String
The name of the updated policy, for example,
projects/project_id/policies/constraint_name``. -
#name ⇒ String
Name of the posture, for example,
CIS-Posture. -
#policy ⇒ String
The ID of the updated policy, for example,
compute-policy-1. -
#policy_drift_details ⇒ Array<Google::Apis::SecuritycenterV1beta1::PolicyDriftDetails>
The details about a change in an updated policy that violates the deployed posture.
-
#policy_set ⇒ String
The name of the updated policyset, for example,
cis-policyset. -
#posture_deployment ⇒ String
The name of the posture deployment, for example,
organizations/org_id/ posturedeployments/posture_deployment_id``. -
#posture_deployment_resource ⇒ String
The project, folder, or organization on which the posture is deployed, for example,
projects/project_number``. -
#revision_id ⇒ String
The version of the posture, for example,
c7cfa2a8.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPosture
constructor
A new instance of SecurityPosture.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPosture
Returns a new instance of SecurityPosture.
12822 12823 12824 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12822 def initialize(**args) update!(**args) end |
Instance Attribute Details
#changed_policy ⇒ String
The name of the updated policy, for example, projects/project_id/policies/
constraint_name`.
Corresponds to the JSON propertychangedPolicy`
12782 12783 12784 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12782 def changed_policy @changed_policy end |
#name ⇒ String
Name of the posture, for example, CIS-Posture.
Corresponds to the JSON property name
12787 12788 12789 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12787 def name @name end |
#policy ⇒ String
The ID of the updated policy, for example, compute-policy-1.
Corresponds to the JSON property policy
12792 12793 12794 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12792 def policy @policy end |
#policy_drift_details ⇒ Array<Google::Apis::SecuritycenterV1beta1::PolicyDriftDetails>
The details about a change in an updated policy that violates the deployed
posture.
Corresponds to the JSON property policyDriftDetails
12798 12799 12800 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12798 def policy_drift_details @policy_drift_details end |
#policy_set ⇒ String
The name of the updated policyset, for example, cis-policyset.
Corresponds to the JSON property policySet
12803 12804 12805 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12803 def policy_set @policy_set end |
#posture_deployment ⇒ String
The name of the posture deployment, for example, organizations/org_id/
posturedeployments/posture_deployment_id`.
Corresponds to the JSON propertypostureDeployment`
12809 12810 12811 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12809 def posture_deployment @posture_deployment end |
#posture_deployment_resource ⇒ String
The project, folder, or organization on which the posture is deployed, for
example, projects/project_number`.
Corresponds to the JSON propertypostureDeploymentResource`
12815 12816 12817 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12815 def posture_deployment_resource @posture_deployment_resource end |
#revision_id ⇒ String
The version of the posture, for example, c7cfa2a8.
Corresponds to the JSON property revisionId
12820 12821 12822 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12820 def revision_id @revision_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12827 12828 12829 12830 12831 12832 12833 12834 12835 12836 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12827 def update!(**args) @changed_policy = args[:changed_policy] if args.key?(:changed_policy) @name = args[:name] if args.key?(:name) @policy = args[:policy] if args.key?(:policy) @policy_drift_details = args[:policy_drift_details] if args.key?(:policy_drift_details) @policy_set = args[:policy_set] if args.key?(:policy_set) @posture_deployment = args[:posture_deployment] if args.key?(:posture_deployment) @posture_deployment_resource = args[:posture_deployment_resource] if args.key?(:posture_deployment_resource) @revision_id = args[:revision_id] if args.key?(:revision_id) end |