Class: Google::Apis::SecuritycenterV1beta1::SensitivityScore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SensitivityScore

Returns a new instance of SensitivityScore.



12849
12850
12851
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12849

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#scoreString

The sensitivity score applied to the resource. Corresponds to the JSON property score

Returns:

  • (String)


12847
12848
12849
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12847

def score
  @score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12854
12855
12856
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12854

def update!(**args)
  @score = args[:score] if args.key?(:score)
end