Class: Google::Apis::SecuritycenterV1beta1::TicketInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Information about the ticket, if any, that is being used to track the resolution of the issue that is identified by this finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TicketInfo

Returns a new instance of TicketInfo.



13678
13679
13680
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13678

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigneeString

The assignee of the ticket in the ticket system. Corresponds to the JSON property assignee

Returns:

  • (String)


13651
13652
13653
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13651

def assignee
  @assignee
end

#descriptionString

The description of the ticket in the ticket system. Corresponds to the JSON property description

Returns:

  • (String)


13656
13657
13658
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13656

def description
  @description
end

#idString

The identifier of the ticket in the ticket system. Corresponds to the JSON property id

Returns:

  • (String)


13661
13662
13663
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13661

def id
  @id
end

#statusString

The latest status of the ticket, as reported by the ticket system. Corresponds to the JSON property status

Returns:

  • (String)


13666
13667
13668
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13666

def status
  @status
end

#update_timeString

The time when the ticket was last updated, as reported by the ticket system. Corresponds to the JSON property updateTime

Returns:

  • (String)


13671
13672
13673
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13671

def update_time
  @update_time
end

#uriString

The link to the ticket in the ticket system. Corresponds to the JSON property uri

Returns:

  • (String)


13676
13677
13678
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13676

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13683
13684
13685
13686
13687
13688
13689
13690
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13683

def update!(**args)
  @assignee = args[:assignee] if args.key?(:assignee)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @status = args[:status] if args.key?(:status)
  @update_time = args[:update_time] if args.key?(:update_time)
  @uri = args[:uri] if args.key?(:uri)
end