Class: Google::Apis::SecuritycenterV1beta1::Connection
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::Connection
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Contains information about the IP connection associated with the finding.
Instance Attribute Summary collapse
-
#destination_ip ⇒ String
Destination IP address.
-
#destination_port ⇒ Fixnum
Destination port.
-
#protocol ⇒ String
IANA Internet Protocol Number such as TCP(6) and UDP(17).
-
#source_ip ⇒ String
Source IP address.
-
#source_port ⇒ Fixnum
Source port.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Connection
constructor
A new instance of Connection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Connection
Returns a new instance of Connection.
1585 1586 1587 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1585 def initialize(**args) update!(**args) end |
Instance Attribute Details
#destination_ip ⇒ String
Destination IP address. Not present for sockets that are listening and not
connected.
Corresponds to the JSON property destinationIp
1563 1564 1565 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1563 def destination_ip @destination_ip end |
#destination_port ⇒ Fixnum
Destination port. Not present for sockets that are listening and not connected.
Corresponds to the JSON property destinationPort
1568 1569 1570 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1568 def destination_port @destination_port end |
#protocol ⇒ String
IANA Internet Protocol Number such as TCP(6) and UDP(17).
Corresponds to the JSON property protocol
1573 1574 1575 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1573 def protocol @protocol end |
#source_ip ⇒ String
Source IP address.
Corresponds to the JSON property sourceIp
1578 1579 1580 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1578 def source_ip @source_ip end |
#source_port ⇒ Fixnum
Source port.
Corresponds to the JSON property sourcePort
1583 1584 1585 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1583 def source_port @source_port end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1590 1591 1592 1593 1594 1595 1596 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1590 def update!(**args) @destination_ip = args[:destination_ip] if args.key?(:destination_ip) @destination_port = args[:destination_port] if args.key?(:destination_port) @protocol = args[:protocol] if args.key?(:protocol) @source_ip = args[:source_ip] if args.key?(:source_ip) @source_port = args[:source_port] if args.key?(:source_port) end |