Class: Google::Apis::SecuritycenterV1beta1::Connection

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Contains information about the IP connection associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Connection

Returns a new instance of Connection.



1547
1548
1549
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1547

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destination_ipString

Destination IP address. Not present for sockets that are listening and not connected. Corresponds to the JSON property destinationIp

Returns:

  • (String)


1525
1526
1527
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1525

def destination_ip
  @destination_ip
end

#destination_portFixnum

Destination port. Not present for sockets that are listening and not connected. Corresponds to the JSON property destinationPort

Returns:

  • (Fixnum)


1530
1531
1532
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1530

def destination_port
  @destination_port
end

#protocolString

IANA Internet Protocol Number such as TCP(6) and UDP(17). Corresponds to the JSON property protocol

Returns:

  • (String)


1535
1536
1537
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1535

def protocol
  @protocol
end

#source_ipString

Source IP address. Corresponds to the JSON property sourceIp

Returns:

  • (String)


1540
1541
1542
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1540

def source_ip
  @source_ip
end

#source_portFixnum

Source port. Corresponds to the JSON property sourcePort

Returns:

  • (Fixnum)


1545
1546
1547
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1545

def source_port
  @source_port
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1552
1553
1554
1555
1556
1557
1558
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 1552

def update!(**args)
  @destination_ip = args[:destination_ip] if args.key?(:destination_ip)
  @destination_port = args[:destination_port] if args.key?(:destination_port)
  @protocol = args[:protocol] if args.key?(:protocol)
  @source_ip = args[:source_ip] if args.key?(:source_ip)
  @source_port = args[:source_port] if args.key?(:source_port)
end