Class: Google::Apis::SecuritycenterV1beta1::ExfilResource
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::ExfilResource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Resource where data was exfiltrated from or exfiltrated to.
Instance Attribute Summary collapse
-
#components ⇒ Array<String>
Subcomponents of the asset that was exfiltrated, like URIs used during exfiltration, table names, databases, and filenames.
-
#name ⇒ String
The resource's full resource name.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExfilResource
constructor
A new instance of ExfilResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExfilResource
Returns a new instance of ExfilResource.
2264 2265 2266 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2264 def initialize(**args) update!(**args) end |
Instance Attribute Details
#components ⇒ Array<String>
Subcomponents of the asset that was exfiltrated, like URIs used during
exfiltration, table names, databases, and filenames. For example, multiple
tables might have been exfiltrated from the same Cloud SQL instance, or
multiple files might have been exfiltrated from the same Cloud Storage bucket.
Corresponds to the JSON property components
2256 2257 2258 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2256 def components @components end |
#name ⇒ String
The resource's full resource name.
Corresponds to the JSON property name
2262 2263 2264 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2262 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2269 2270 2271 2272 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2269 def update!(**args) @components = args[:components] if args.key?(:components) @name = args[:name] if args.key?(:name) end |