Class: Google::Apis::SecuritycenterV1beta1::Exfiltration
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::Exfiltration
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Exfiltration represents a data exfiltration attempt from one or more sources
to one or more targets. The sources attribute lists the sources of the
exfiltrated data. The targets attribute lists the destinations the data was
copied to.
Instance Attribute Summary collapse
-
#sources ⇒ Array<Google::Apis::SecuritycenterV1beta1::ExfilResource>
If there are multiple sources, then the data is considered "joined" between them.
-
#targets ⇒ Array<Google::Apis::SecuritycenterV1beta1::ExfilResource>
If there are multiple targets, each target would get a complete copy of the " joined" source data.
-
#total_exfiltrated_bytes ⇒ Fixnum
Total exfiltrated bytes processed for the entire job.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Exfiltration
constructor
A new instance of Exfiltration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Exfiltration
Returns a new instance of Exfiltration.
2395 2396 2397 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2395 def initialize(**args) update!(**args) end |
Instance Attribute Details
#sources ⇒ Array<Google::Apis::SecuritycenterV1beta1::ExfilResource>
If there are multiple sources, then the data is considered "joined" between
them. For instance, BigQuery can join multiple tables, and each table would be
considered a source.
Corresponds to the JSON property sources
2382 2383 2384 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2382 def sources @sources end |
#targets ⇒ Array<Google::Apis::SecuritycenterV1beta1::ExfilResource>
If there are multiple targets, each target would get a complete copy of the "
joined" source data.
Corresponds to the JSON property targets
2388 2389 2390 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2388 def targets @targets end |
#total_exfiltrated_bytes ⇒ Fixnum
Total exfiltrated bytes processed for the entire job.
Corresponds to the JSON property totalExfiltratedBytes
2393 2394 2395 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2393 def total_exfiltrated_bytes @total_exfiltrated_bytes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2400 2401 2402 2403 2404 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2400 def update!(**args) @sources = args[:sources] if args.key?(:sources) @targets = args[:targets] if args.key?(:targets) @total_exfiltrated_bytes = args[:total_exfiltrated_bytes] if args.key?(:total_exfiltrated_bytes) end |