Class: Google::Apis::SecuritycenterV1beta1::File
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::File
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
File information about the related binary/library used by an executable, or the script used by a script interpreter
Instance Attribute Summary collapse
-
#contents ⇒ String
Prefix of the file contents as a JSON-encoded string.
-
#disk_path ⇒ Google::Apis::SecuritycenterV1beta1::DiskPath
Path of the file in terms of underlying disk/partition identifiers.
-
#file_load_state ⇒ String
The load state of the file.
-
#hashed_size ⇒ Fixnum
The length in bytes of the file prefix that was hashed.
-
#operations ⇒ Array<Google::Apis::SecuritycenterV1beta1::FileOperation>
Operation(s) performed on a file.
-
#partially_hashed ⇒ Boolean
(also: #partially_hashed?)
True when the hash covers only a prefix of the file.
-
#path ⇒ String
Absolute path of the file as a JSON encoded string.
-
#sha256 ⇒ String
SHA256 hash of the first hashed_size bytes of the file encoded as a hex string.
-
#size ⇒ Fixnum
Size of the file in bytes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ File
constructor
A new instance of File.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ File
Returns a new instance of File.
2706 2707 2708 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2706 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents ⇒ String
Prefix of the file contents as a JSON-encoded string.
Corresponds to the JSON property contents
2661 2662 2663 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2661 def contents @contents end |
#disk_path ⇒ Google::Apis::SecuritycenterV1beta1::DiskPath
Path of the file in terms of underlying disk/partition identifiers.
Corresponds to the JSON property diskPath
2666 2667 2668 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2666 def disk_path @disk_path end |
#file_load_state ⇒ String
The load state of the file.
Corresponds to the JSON property fileLoadState
2671 2672 2673 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2671 def file_load_state @file_load_state end |
#hashed_size ⇒ Fixnum
The length in bytes of the file prefix that was hashed. If hashed_size == size,
any hashes reported represent the entire file.
Corresponds to the JSON property hashedSize
2677 2678 2679 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2677 def hashed_size @hashed_size end |
#operations ⇒ Array<Google::Apis::SecuritycenterV1beta1::FileOperation>
Operation(s) performed on a file.
Corresponds to the JSON property operations
2682 2683 2684 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2682 def operations @operations end |
#partially_hashed ⇒ Boolean Also known as: partially_hashed?
True when the hash covers only a prefix of the file.
Corresponds to the JSON property partiallyHashed
2687 2688 2689 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2687 def partially_hashed @partially_hashed end |
#path ⇒ String
Absolute path of the file as a JSON encoded string.
Corresponds to the JSON property path
2693 2694 2695 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2693 def path @path end |
#sha256 ⇒ String
SHA256 hash of the first hashed_size bytes of the file encoded as a hex string.
If hashed_size == size, sha256 represents the SHA256 hash of the entire file.
Corresponds to the JSON property sha256
2699 2700 2701 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2699 def sha256 @sha256 end |
#size ⇒ Fixnum
Size of the file in bytes.
Corresponds to the JSON property size
2704 2705 2706 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2704 def size @size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 2711 def update!(**args) @contents = args[:contents] if args.key?(:contents) @disk_path = args[:disk_path] if args.key?(:disk_path) @file_load_state = args[:file_load_state] if args.key?(:file_load_state) @hashed_size = args[:hashed_size] if args.key?(:hashed_size) @operations = args[:operations] if args.key?(:operations) @partially_hashed = args[:partially_hashed] if args.key?(:partially_hashed) @path = args[:path] if args.key?(:path) @sha256 = args[:sha256] if args.key?(:sha256) @size = args[:size] if args.key?(:size) end |