Class: Google::Apis::SecuritycenterV1beta1::Framework
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::Framework
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Compliance framework associated with the finding.
Instance Attribute Summary collapse
-
#category ⇒ Array<String>
Category of the framework associated with the finding.
-
#controls ⇒ Array<Google::Apis::SecuritycenterV1beta1::Control>
The controls associated with the framework.
-
#display_name ⇒ String
Display name of the framework.
-
#name ⇒ String
Name of the framework associated with the finding Corresponds to the JSON property
name. -
#type ⇒ String
Type of the framework associated with the finding, to specify whether the framework is built-in (pre-defined and immutable) or a custom framework defined by the customer (equivalent to security posture) Corresponds to the JSON property
type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Framework
constructor
A new instance of Framework.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Framework
Returns a new instance of Framework.
3130 3131 3132 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3130 def initialize(**args) update!(**args) end |
Instance Attribute Details
#category ⇒ Array<String>
Category of the framework associated with the finding. E.g. Security Benchmark,
or Assured Workloads
Corresponds to the JSON property category
3104 3105 3106 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3104 def category @category end |
#controls ⇒ Array<Google::Apis::SecuritycenterV1beta1::Control>
The controls associated with the framework.
Corresponds to the JSON property controls
3109 3110 3111 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3109 def controls @controls end |
#display_name ⇒ String
Display name of the framework. For a standard framework, this will look like e.
g. PCI DSS 3.2.1, whereas for a custom framework it can be a user defined
string like MyFramework
Corresponds to the JSON property displayName
3116 3117 3118 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3116 def display_name @display_name end |
#name ⇒ String
Name of the framework associated with the finding
Corresponds to the JSON property name
3121 3122 3123 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3121 def name @name end |
#type ⇒ String
Type of the framework associated with the finding, to specify whether the
framework is built-in (pre-defined and immutable) or a custom framework
defined by the customer (equivalent to security posture)
Corresponds to the JSON property type
3128 3129 3130 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3128 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3135 3136 3137 3138 3139 3140 3141 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3135 def update!(**args) @category = args[:category] if args.key?(:category) @controls = args[:controls] if args.key?(:controls) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @type = args[:type] if args.key?(:type) end |