Class: Google::Apis::SecuritycenterV1beta1::GcpMetadata
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GcpMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Google Cloud metadata associated with the resource. Only applicable if the finding's cloud provider is Google Cloud.
Instance Attribute Summary collapse
-
#folders ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Folder>
Output only.
-
#organization ⇒ String
The name of the organization that the resource belongs to.
-
#parent ⇒ String
The full resource name of resource's parent.
-
#parent_display_name ⇒ String
The human readable name of resource's parent.
-
#project ⇒ String
The full resource name of project that the resource belongs to.
-
#project_display_name ⇒ String
The project ID that the resource belongs to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GcpMetadata
constructor
A new instance of GcpMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GcpMetadata
Returns a new instance of GcpMetadata.
3359 3360 3361 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3359 def initialize(**args) update!(**args) end |
Instance Attribute Details
#folders ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Folder>
Output only. Contains a Folder message for each folder in the assets ancestry.
The first folder is the deepest nested folder, and the last folder is the
folder directly under the Organization.
Corresponds to the JSON property folders
3332 3333 3334 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3332 def folders @folders end |
#organization ⇒ String
The name of the organization that the resource belongs to.
Corresponds to the JSON property organization
3337 3338 3339 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3337 def organization @organization end |
#parent ⇒ String
The full resource name of resource's parent.
Corresponds to the JSON property parent
3342 3343 3344 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3342 def parent @parent end |
#parent_display_name ⇒ String
The human readable name of resource's parent.
Corresponds to the JSON property parentDisplayName
3347 3348 3349 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3347 def parent_display_name @parent_display_name end |
#project ⇒ String
The full resource name of project that the resource belongs to.
Corresponds to the JSON property project
3352 3353 3354 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3352 def project @project end |
#project_display_name ⇒ String
The project ID that the resource belongs to.
Corresponds to the JSON property projectDisplayName
3357 3358 3359 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3357 def project_display_name @project_display_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3364 3365 3366 3367 3368 3369 3370 3371 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3364 def update!(**args) @folders = args[:folders] if args.key?(:folders) @organization = args[:organization] if args.key?(:organization) @parent = args[:parent] if args.key?(:parent) @parent_display_name = args[:parent_display_name] if args.key?(:parent_display_name) @project = args[:project] if args.key?(:project) @project_display_name = args[:project_display_name] if args.key?(:project_display_name) end |