Class: Google::Apis::SecuritycenterV1beta1::GcpMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Google Cloud metadata associated with the resource. Only applicable if the finding's cloud provider is Google Cloud.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GcpMetadata

Returns a new instance of GcpMetadata.



3300
3301
3302
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3300

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#foldersArray<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Folder>

Output only. Contains a Folder message for each folder in the assets ancestry. The first folder is the deepest nested folder, and the last folder is the folder directly under the Organization. Corresponds to the JSON property folders



3273
3274
3275
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3273

def folders
  @folders
end

#organizationString

The name of the organization that the resource belongs to. Corresponds to the JSON property organization

Returns:

  • (String)


3278
3279
3280
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3278

def organization
  @organization
end

#parentString

The full resource name of resource's parent. Corresponds to the JSON property parent

Returns:

  • (String)


3283
3284
3285
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3283

def parent
  @parent
end

#parent_display_nameString

The human readable name of resource's parent. Corresponds to the JSON property parentDisplayName

Returns:

  • (String)


3288
3289
3290
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3288

def parent_display_name
  @parent_display_name
end

#projectString

The full resource name of project that the resource belongs to. Corresponds to the JSON property project

Returns:

  • (String)


3293
3294
3295
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3293

def project
  @project
end

#project_display_nameString

The project ID that the resource belongs to. Corresponds to the JSON property projectDisplayName

Returns:

  • (String)


3298
3299
3300
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3298

def project_display_name
  @project_display_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3305
3306
3307
3308
3309
3310
3311
3312
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3305

def update!(**args)
  @folders = args[:folders] if args.key?(:folders)
  @organization = args[:organization] if args.key?(:organization)
  @parent = args[:parent] if args.key?(:parent)
  @parent_display_name = args[:parent_display_name] if args.key?(:parent_display_name)
  @project = args[:project] if args.key?(:project)
  @project_display_name = args[:project_display_name] if args.key?(:project_display_name)
end