Class: Google::Apis::SecuritycenterV1beta1::GcpMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Google Cloud metadata associated with the resource. Only applicable if the finding's cloud provider is Google Cloud.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GcpMetadata

Returns a new instance of GcpMetadata.



3181
3182
3183
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3181

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#foldersArray<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Folder>

Output only. Contains a Folder message for each folder in the assets ancestry. The first folder is the deepest nested folder, and the last folder is the folder directly under the Organization. Corresponds to the JSON property folders



3154
3155
3156
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3154

def folders
  @folders
end

#organizationString

The name of the organization that the resource belongs to. Corresponds to the JSON property organization

Returns:

  • (String)


3159
3160
3161
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3159

def organization
  @organization
end

#parentString

The full resource name of resource's parent. Corresponds to the JSON property parent

Returns:

  • (String)


3164
3165
3166
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3164

def parent
  @parent
end

#parent_display_nameString

The human readable name of resource's parent. Corresponds to the JSON property parentDisplayName

Returns:

  • (String)


3169
3170
3171
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3169

def parent_display_name
  @parent_display_name
end

#projectString

The full resource name of project that the resource belongs to. Corresponds to the JSON property project

Returns:

  • (String)


3174
3175
3176
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3174

def project
  @project
end

#project_display_nameString

The project ID that the resource belongs to. Corresponds to the JSON property projectDisplayName

Returns:

  • (String)


3179
3180
3181
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3179

def project_display_name
  @project_display_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3186
3187
3188
3189
3190
3191
3192
3193
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3186

def update!(**args)
  @folders = args[:folders] if args.key?(:folders)
  @organization = args[:organization] if args.key?(:organization)
  @parent = args[:parent] if args.key?(:parent)
  @parent_display_name = args[:parent_display_name] if args.key?(:parent_display_name)
  @project = args[:project] if args.key?(:project)
  @project_display_name = args[:project_display_name] if args.key?(:project_display_name)
end