Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1CustomOutputSpec
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1CustomOutputSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
A set of optional name-value pairs that define custom source properties to
return with each finding that is generated by the custom module. The custom
source properties that are defined here are included in the finding JSON under
sourceProperties.
Instance Attribute Summary collapse
-
#properties ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1Property>
A list of custom output properties to add to the finding.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1CustomOutputSpec
constructor
A new instance of GoogleCloudSecuritycenterV1CustomOutputSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1CustomOutputSpec
Returns a new instance of GoogleCloudSecuritycenterV1CustomOutputSpec.
3600 3601 3602 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3600 def initialize(**args) update!(**args) end |
Instance Attribute Details
#properties ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1Property>
A list of custom output properties to add to the finding.
Corresponds to the JSON property properties
3598 3599 3600 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3598 def properties @properties end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3605 3606 3607 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3605 def update!(**args) @properties = args[:properties] if args.key?(:properties) end |