Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1ExternalSystem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Representation of third party SIEM/SOAR fields within SCC.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV1ExternalSystem

Returns a new instance of GoogleCloudSecuritycenterV1ExternalSystem.



3617
3618
3619
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3617

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigneesArray<String>

References primary/secondary etc assignees in the external system. Corresponds to the JSON property assignees

Returns:

  • (Array<String>)


3559
3560
3561
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3559

def assignees
  @assignees
end

#case_close_timeString

The time when the case was closed, as reported by the external system. Corresponds to the JSON property caseCloseTime

Returns:

  • (String)


3564
3565
3566
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3564

def case_close_time
  @case_close_time
end

#case_create_timeString

The time when the case was created, as reported by the external system. Corresponds to the JSON property caseCreateTime

Returns:

  • (String)


3569
3570
3571
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3569

def case_create_time
  @case_create_time
end

#case_priorityString

The priority of the finding's corresponding case in the external system. Corresponds to the JSON property casePriority

Returns:

  • (String)


3574
3575
3576
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3574

def case_priority
  @case_priority
end

#case_slaString

The SLA of the finding's corresponding case in the external system. Corresponds to the JSON property caseSla

Returns:

  • (String)


3579
3580
3581
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3579

def case_sla
  @case_sla
end

#case_uriString

The link to the finding's corresponding case in the external system. Corresponds to the JSON property caseUri

Returns:

  • (String)


3584
3585
3586
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3584

def case_uri
  @case_uri
end

#external_system_update_timeString

The time when the case was last updated, as reported by the external system. Corresponds to the JSON property externalSystemUpdateTime

Returns:

  • (String)


3589
3590
3591
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3589

def external_system_update_time
  @external_system_update_time
end

#external_uidString

The identifier that's used to track the finding's corresponding case in the external system. Corresponds to the JSON property externalUid

Returns:

  • (String)


3595
3596
3597
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3595

def external_uid
  @external_uid
end

#nameString

Full resource name of the external system, for example: "organizations/1234/ sources/5678/findings/123456/externalSystems/jira", "folders/1234/sources/5678/ findings/123456/externalSystems/jira", "projects/1234/sources/5678/findings/ 123456/externalSystems/jira" Corresponds to the JSON property name

Returns:

  • (String)


3603
3604
3605
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3603

def name
  @name
end

#statusString

The most recent status of the finding's corresponding case, as reported by the external system. Corresponds to the JSON property status

Returns:

  • (String)


3609
3610
3611
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3609

def status
  @status
end

#ticket_infoGoogle::Apis::SecuritycenterV1beta1::TicketInfo

Information about the ticket, if any, that is being used to track the resolution of the issue that is identified by this finding. Corresponds to the JSON property ticketInfo



3615
3616
3617
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3615

def ticket_info
  @ticket_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3622
3623
3624
3625
3626
3627
3628
3629
3630
3631
3632
3633
3634
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3622

def update!(**args)
  @assignees = args[:assignees] if args.key?(:assignees)
  @case_close_time = args[:case_close_time] if args.key?(:case_close_time)
  @case_create_time = args[:case_create_time] if args.key?(:case_create_time)
  @case_priority = args[:case_priority] if args.key?(:case_priority)
  @case_sla = args[:case_sla] if args.key?(:case_sla)
  @case_uri = args[:case_uri] if args.key?(:case_uri)
  @external_system_update_time = args[:external_system_update_time] if args.key?(:external_system_update_time)
  @external_uid = args[:external_uid] if args.key?(:external_uid)
  @name = args[:name] if args.key?(:name)
  @status = args[:status] if args.key?(:status)
  @ticket_info = args[:ticket_info] if args.key?(:ticket_info)
end