Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1MuteConfig
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1MuteConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
A mute config is a Cloud SCC resource that contains the configuration to mute create/update events of findings.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
A description of the mute config.
-
#display_name ⇒ String
The human readable name to be displayed for the mute config.
-
#expiry_time ⇒ String
Optional.
-
#filter ⇒ String
Required.
-
#most_recent_editor ⇒ String
Output only.
-
#name ⇒ String
This field will be ignored if provided on config creation.
-
#type ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1MuteConfig
constructor
A new instance of GoogleCloudSecuritycenterV1MuteConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1MuteConfig
Returns a new instance of GoogleCloudSecuritycenterV1MuteConfig.
3710 3711 3712 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3710 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which the mute config was created. This field is set
by the server and will be ignored if provided on config creation.
Corresponds to the JSON property createTime
3646 3647 3648 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3646 def create_time @create_time end |
#description ⇒ String
A description of the mute config.
Corresponds to the JSON property description
3651 3652 3653 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3651 def description @description end |
#display_name ⇒ String
The human readable name to be displayed for the mute config.
Corresponds to the JSON property displayName
3656 3657 3658 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3656 def display_name @display_name end |
#expiry_time ⇒ String
Optional. The expiry of the mute config. Only applicable for dynamic configs.
If the expiry is set, when the config expires, it is removed from all findings.
Corresponds to the JSON property expiryTime
3662 3663 3664 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3662 def expiry_time @expiry_time end |
#filter ⇒ String
Required. An expression that defines the filter to apply across create/update
events of findings. While creating a filter string, be mindful of the scope in
which the mute configuration is being created. E.g., If a filter contains
project = X but is created under the project = Y scope, it might not match any
findings. The following field and operator combinations are supported: *
severity: =, : * category: =, : * resource.name: =, : * resource.
project_name: =, : * resource.project_display_name: =, : * resource.
folders.resource_folder: =, : * resource.parent_name: =, : * resource.
parent_display_name: =, : * resource.type: =, : * finding_class: =,
: * indicator.ip_addresses: =, : * indicator.domains: =, :
Corresponds to the JSON property filter
3676 3677 3678 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3676 def filter @filter end |
#most_recent_editor ⇒ String
Output only. Email address of the user who last edited the mute config. This
field is set by the server and will be ignored if provided on config creation
or update.
Corresponds to the JSON property mostRecentEditor
3683 3684 3685 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3683 def most_recent_editor @most_recent_editor end |
#name ⇒ String
This field will be ignored if provided on config creation. Format
organizations/organization/muteConfigs/mute_config`folders/`folder`/
muteConfigs/`mute_config projects/project/muteConfigs/mute_config`
organizations/`organization`/locations/global/muteConfigs/`mute_config
folders/folder/locations/global/muteConfigs/mute_config`projects/`
project`/locations/global/muteConfigs/`mute_config
Corresponds to the JSON property name
3693 3694 3695 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3693 def name @name end |
#type ⇒ String
Optional. The type of the mute config, which determines what type of mute
state the config affects. The static mute state takes precedence over the
dynamic mute state. Immutable after creation. STATIC by default if not set
during creation.
Corresponds to the JSON property type
3701 3702 3703 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3701 def type @type end |
#update_time ⇒ String
Output only. The most recent time at which the mute config was updated. This
field is set by the server and will be ignored if provided on config creation
or update.
Corresponds to the JSON property updateTime
3708 3709 3710 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3708 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3715 3716 3717 3718 3719 3720 3721 3722 3723 3724 3725 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3715 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @expiry_time = args[:expiry_time] if args.key?(:expiry_time) @filter = args[:filter] if args.key?(:filter) @most_recent_editor = args[:most_recent_editor] if args.key?(:most_recent_editor) @name = args[:name] if args.key?(:name) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) end |