Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1Resource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Information related to the Google Cloud resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV1Resource

Returns a new instance of GoogleCloudSecuritycenterV1Resource.



4041
4042
4043
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4041

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adc_applicationGoogle::Apis::SecuritycenterV1beta1::AdcApplication

Represents an ADC application associated with the finding. Corresponds to the JSON property adcApplication



3928
3929
3930
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3928

def adc_application
  @adc_application
end

#adc_application_templateGoogle::Apis::SecuritycenterV1beta1::AdcApplicationTemplateRevision

Represents an ADC template associated with the finding. Corresponds to the JSON property adcApplicationTemplate



3933
3934
3935
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3933

def adc_application_template
  @adc_application_template
end

#adc_shared_templateGoogle::Apis::SecuritycenterV1beta1::AdcSharedTemplateRevision

Represents an ADC shared template associated with the finding. Corresponds to the JSON property adcSharedTemplate



3938
3939
3940
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3938

def adc_shared_template
  @adc_shared_template
end

#applicationGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1ResourceApplication

The App Hub Application associated with the finding's resource. Corresponds to the JSON property application



3943
3944
3945
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3943

def application
  @application
end

#aws_metadataGoogle::Apis::SecuritycenterV1beta1::AwsMetadata

AWS metadata associated with the resource, only applicable if the finding's cloud provider is Amazon Web Services. Corresponds to the JSON property awsMetadata



3949
3950
3951
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3949

def 
  @aws_metadata
end

#azure_metadataGoogle::Apis::SecuritycenterV1beta1::AzureMetadata

Azure metadata associated with the resource, only applicable if the finding's cloud provider is Microsoft Azure. Corresponds to the JSON property azureMetadata



3955
3956
3957
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3955

def 
  @azure_metadata
end

#cloud_providerString

Indicates which cloud provider the resource resides in. Corresponds to the JSON property cloudProvider

Returns:

  • (String)


3960
3961
3962
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3960

def cloud_provider
  @cloud_provider
end

#display_nameString

The human readable name of the resource. Corresponds to the JSON property displayName

Returns:

  • (String)


3965
3966
3967
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3965

def display_name
  @display_name
end

#foldersArray<Google::Apis::SecuritycenterV1beta1::Folder>

Output only. Contains a Folder message for each folder in the assets ancestry. The first folder is the deepest nested folder, and the last folder is the folder directly under the Organization. Corresponds to the JSON property folders



3972
3973
3974
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3972

def folders
  @folders
end

#locationString

The region or location of the service (if applicable). Corresponds to the JSON property location

Returns:

  • (String)


3977
3978
3979
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3977

def location
  @location
end

#nameString

The full resource name of the resource. See: https://cloud.google.com/apis/ design/resource_names#full_resource_name Corresponds to the JSON property name

Returns:

  • (String)


3983
3984
3985
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3983

def name
  @name
end

#organizationString

Indicates which organization or tenant in the cloud provider the finding applies to. Corresponds to the JSON property organization

Returns:

  • (String)


3989
3990
3991
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3989

def organization
  @organization
end

#parentString

The full resource name of resource's parent. Corresponds to the JSON property parent

Returns:

  • (String)


3994
3995
3996
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3994

def parent
  @parent
end

#parent_display_nameString

The human readable name of resource's parent. Corresponds to the JSON property parentDisplayName

Returns:

  • (String)


3999
4000
4001
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3999

def parent_display_name
  @parent_display_name
end

#projectString

The full resource name of project that the resource belongs to. Corresponds to the JSON property project

Returns:

  • (String)


4004
4005
4006
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4004

def project
  @project
end

#project_display_nameString

The project ID that the resource belongs to. Corresponds to the JSON property projectDisplayName

Returns:

  • (String)


4009
4010
4011
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4009

def project_display_name
  @project_display_name
end

#resource_pathGoogle::Apis::SecuritycenterV1beta1::ResourcePath

Represents the path of resources leading up to the resource this finding is about. Corresponds to the JSON property resourcePath



4015
4016
4017
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4015

def resource_path
  @resource_path
end

#resource_path_stringString

A string representation of the resource path. For Google Cloud, it has the format of organizations/organization_id/folders/folder_id/folders/ folder_id/projects/project_idwhere there can be any number of folders. For AWS, it has the format of `org/`organization_id`/ou/` organizational_unit_id`/ou/`organizational_unit_id`/account/`account_id where there can be any number of organizational units. For Azure, it has the format of mg/management_group_id/mg/management_group_id/subscription/ subscription_id/rg/resource_group_name`where there can be any number of management groups. Corresponds to the JSON propertyresourcePathString`

Returns:

  • (String)


4028
4029
4030
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4028

def resource_path_string
  @resource_path_string
end

#serviceString

The parent service or product from which the resource is provided, for example, GKE or SNS. Corresponds to the JSON property service

Returns:

  • (String)


4034
4035
4036
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4034

def service
  @service
end

#typeString

The full resource type of the resource. Corresponds to the JSON property type

Returns:

  • (String)


4039
4040
4041
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4039

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4046
4047
4048
4049
4050
4051
4052
4053
4054
4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4046

def update!(**args)
  @adc_application = args[:adc_application] if args.key?(:adc_application)
  @adc_application_template = args[:adc_application_template] if args.key?(:adc_application_template)
  @adc_shared_template = args[:adc_shared_template] if args.key?(:adc_shared_template)
  @application = args[:application] if args.key?(:application)
  @aws_metadata = args[:aws_metadata] if args.key?(:aws_metadata)
  @azure_metadata = args[:azure_metadata] if args.key?(:azure_metadata)
  @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider)
  @display_name = args[:display_name] if args.key?(:display_name)
  @folders = args[:folders] if args.key?(:folders)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @organization = args[:organization] if args.key?(:organization)
  @parent = args[:parent] if args.key?(:parent)
  @parent_display_name = args[:parent_display_name] if args.key?(:parent_display_name)
  @project = args[:project] if args.key?(:project)
  @project_display_name = args[:project_display_name] if args.key?(:project_display_name)
  @resource_path = args[:resource_path] if args.key?(:resource_path)
  @resource_path_string = args[:resource_path_string] if args.key?(:resource_path_string)
  @service = args[:service] if args.key?(:service)
  @type = args[:type] if args.key?(:type)
end