Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1Resource
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1Resource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Information related to the Google Cloud resource.
Instance Attribute Summary collapse
-
#adc_application ⇒ Google::Apis::SecuritycenterV1beta1::AdcApplication
Represents an ADC application associated with the finding.
-
#adc_application_template ⇒ Google::Apis::SecuritycenterV1beta1::AdcApplicationTemplateRevision
Represents an ADC template associated with the finding.
-
#adc_shared_template ⇒ Google::Apis::SecuritycenterV1beta1::AdcSharedTemplateRevision
Represents an ADC shared template associated with the finding.
-
#application ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1ResourceApplication
The App Hub Application associated with the finding's resource.
-
#aws_metadata ⇒ Google::Apis::SecuritycenterV1beta1::AwsMetadata
AWS metadata associated with the resource, only applicable if the finding's cloud provider is Amazon Web Services.
-
#azure_metadata ⇒ Google::Apis::SecuritycenterV1beta1::AzureMetadata
Azure metadata associated with the resource, only applicable if the finding's cloud provider is Microsoft Azure.
-
#cloud_provider ⇒ String
Indicates which cloud provider the resource resides in.
-
#display_name ⇒ String
The human readable name of the resource.
-
#folders ⇒ Array<Google::Apis::SecuritycenterV1beta1::Folder>
Output only.
-
#location ⇒ String
The region or location of the service (if applicable).
-
#name ⇒ String
The full resource name of the resource.
-
#organization ⇒ String
Indicates which organization or tenant in the cloud provider the finding applies to.
-
#parent ⇒ String
The full resource name of resource's parent.
-
#parent_display_name ⇒ String
The human readable name of resource's parent.
-
#project ⇒ String
The full resource name of project that the resource belongs to.
-
#project_display_name ⇒ String
The project ID that the resource belongs to.
-
#resource_path ⇒ Google::Apis::SecuritycenterV1beta1::ResourcePath
Represents the path of resources leading up to the resource this finding is about.
-
#resource_path_string ⇒ String
A string representation of the resource path.
-
#service ⇒ String
The parent service or product from which the resource is provided, for example, GKE or SNS.
-
#type ⇒ String
The full resource type of the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1Resource
constructor
A new instance of GoogleCloudSecuritycenterV1Resource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1Resource
Returns a new instance of GoogleCloudSecuritycenterV1Resource.
3922 3923 3924 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3922 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adc_application ⇒ Google::Apis::SecuritycenterV1beta1::AdcApplication
Represents an ADC application associated with the finding.
Corresponds to the JSON property adcApplication
3809 3810 3811 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3809 def adc_application @adc_application end |
#adc_application_template ⇒ Google::Apis::SecuritycenterV1beta1::AdcApplicationTemplateRevision
Represents an ADC template associated with the finding.
Corresponds to the JSON property adcApplicationTemplate
3814 3815 3816 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3814 def adc_application_template @adc_application_template end |
#adc_shared_template ⇒ Google::Apis::SecuritycenterV1beta1::AdcSharedTemplateRevision
Represents an ADC shared template associated with the finding.
Corresponds to the JSON property adcSharedTemplate
3819 3820 3821 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3819 def adc_shared_template @adc_shared_template end |
#application ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1ResourceApplication
The App Hub Application associated with the finding's resource.
Corresponds to the JSON property application
3824 3825 3826 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3824 def application @application end |
#aws_metadata ⇒ Google::Apis::SecuritycenterV1beta1::AwsMetadata
AWS metadata associated with the resource, only applicable if the finding's
cloud provider is Amazon Web Services.
Corresponds to the JSON property awsMetadata
3830 3831 3832 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3830 def @aws_metadata end |
#azure_metadata ⇒ Google::Apis::SecuritycenterV1beta1::AzureMetadata
Azure metadata associated with the resource, only applicable if the finding's
cloud provider is Microsoft Azure.
Corresponds to the JSON property azureMetadata
3836 3837 3838 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3836 def @azure_metadata end |
#cloud_provider ⇒ String
Indicates which cloud provider the resource resides in.
Corresponds to the JSON property cloudProvider
3841 3842 3843 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3841 def cloud_provider @cloud_provider end |
#display_name ⇒ String
The human readable name of the resource.
Corresponds to the JSON property displayName
3846 3847 3848 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3846 def display_name @display_name end |
#folders ⇒ Array<Google::Apis::SecuritycenterV1beta1::Folder>
Output only. Contains a Folder message for each folder in the assets ancestry.
The first folder is the deepest nested folder, and the last folder is the
folder directly under the Organization.
Corresponds to the JSON property folders
3853 3854 3855 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3853 def folders @folders end |
#location ⇒ String
The region or location of the service (if applicable).
Corresponds to the JSON property location
3858 3859 3860 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3858 def location @location end |
#name ⇒ String
The full resource name of the resource. See: https://cloud.google.com/apis/
design/resource_names#full_resource_name
Corresponds to the JSON property name
3864 3865 3866 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3864 def name @name end |
#organization ⇒ String
Indicates which organization or tenant in the cloud provider the finding
applies to.
Corresponds to the JSON property organization
3870 3871 3872 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3870 def organization @organization end |
#parent ⇒ String
The full resource name of resource's parent.
Corresponds to the JSON property parent
3875 3876 3877 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3875 def parent @parent end |
#parent_display_name ⇒ String
The human readable name of resource's parent.
Corresponds to the JSON property parentDisplayName
3880 3881 3882 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3880 def parent_display_name @parent_display_name end |
#project ⇒ String
The full resource name of project that the resource belongs to.
Corresponds to the JSON property project
3885 3886 3887 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3885 def project @project end |
#project_display_name ⇒ String
The project ID that the resource belongs to.
Corresponds to the JSON property projectDisplayName
3890 3891 3892 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3890 def project_display_name @project_display_name end |
#resource_path ⇒ Google::Apis::SecuritycenterV1beta1::ResourcePath
Represents the path of resources leading up to the resource this finding is
about.
Corresponds to the JSON property resourcePath
3896 3897 3898 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3896 def resource_path @resource_path end |
#resource_path_string ⇒ String
A string representation of the resource path. For Google Cloud, it has the
format of organizations/organization_id/folders/folder_id/folders/
folder_id/projects/project_idwhere there can be any number of folders.
For AWS, it has the format of `org/`organization_id`/ou/`
organizational_unit_id`/ou/`organizational_unit_id`/account/`account_id
where there can be any number of organizational units. For Azure, it has the
format of mg/management_group_id/mg/management_group_id/subscription/
subscription_id/rg/resource_group_name`where there can be any number of
management groups.
Corresponds to the JSON propertyresourcePathString`
3909 3910 3911 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3909 def resource_path_string @resource_path_string end |
#service ⇒ String
The parent service or product from which the resource is provided, for example,
GKE or SNS.
Corresponds to the JSON property service
3915 3916 3917 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3915 def service @service end |
#type ⇒ String
The full resource type of the resource.
Corresponds to the JSON property type
3920 3921 3922 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3920 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3927 3928 3929 3930 3931 3932 3933 3934 3935 3936 3937 3938 3939 3940 3941 3942 3943 3944 3945 3946 3947 3948 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3927 def update!(**args) @adc_application = args[:adc_application] if args.key?(:adc_application) @adc_application_template = args[:adc_application_template] if args.key?(:adc_application_template) @adc_shared_template = args[:adc_shared_template] if args.key?(:adc_shared_template) @application = args[:application] if args.key?(:application) @aws_metadata = args[:aws_metadata] if args.key?(:aws_metadata) @azure_metadata = args[:azure_metadata] if args.key?(:azure_metadata) @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider) @display_name = args[:display_name] if args.key?(:display_name) @folders = args[:folders] if args.key?(:folders) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @organization = args[:organization] if args.key?(:organization) @parent = args[:parent] if args.key?(:parent) @parent_display_name = args[:parent_display_name] if args.key?(:parent_display_name) @project = args[:project] if args.key?(:project) @project_display_name = args[:project_display_name] if args.key?(:project_display_name) @resource_path = args[:resource_path] if args.key?(:resource_path) @resource_path_string = args[:resource_path_string] if args.key?(:resource_path_string) @service = args[:service] if args.key?(:service) @type = args[:type] if args.key?(:type) end |