Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1ResourceApplicationAttributes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Consumer provided attributes for the application

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV1ResourceApplicationAttributes

Returns a new instance of GoogleCloudSecuritycenterV1ResourceApplicationAttributes.



4006
4007
4008
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4006

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#business_ownersArray<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1ResourceApplicationAttributesContactInfo>

Business team that ensures user needs are met and value is delivered Corresponds to the JSON property businessOwners



3984
3985
3986
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3984

def business_owners
  @business_owners
end

#criticalityGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1ResourceApplicationAttributesCriticality

Criticality of the Application, Service, or Workload Corresponds to the JSON property criticality



3989
3990
3991
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3989

def criticality
  @criticality
end

#developer_ownersArray<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1ResourceApplicationAttributesContactInfo>

Developer team that owns development and coding. Corresponds to the JSON property developerOwners



3994
3995
3996
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3994

def developer_owners
  @developer_owners
end

#environmentGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1ResourceApplicationAttributesEnvironment

Environment of the Application, Service, or Workload Corresponds to the JSON property environment



3999
4000
4001
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 3999

def environment
  @environment
end

#operator_ownersArray<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1ResourceApplicationAttributesContactInfo>

Operator team that ensures runtime and operations. Corresponds to the JSON property operatorOwners



4004
4005
4006
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4004

def operator_owners
  @operator_owners
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4011
4012
4013
4014
4015
4016
4017
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4011

def update!(**args)
  @business_owners = args[:business_owners] if args.key?(:business_owners)
  @criticality = args[:criticality] if args.key?(:criticality)
  @developer_owners = args[:developer_owners] if args.key?(:developer_owners)
  @environment = args[:environment] if args.key?(:environment)
  @operator_owners = args[:operator_owners] if args.key?(:operator_owners)
end