Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1beta1Finding
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1beta1Finding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Security Command Center finding. A finding is a record of assessment data ( security, risk, health or privacy) ingested into Security Command Center for presentation, notification, analysis, policy testing, and enforcement. For example, an XSS vulnerability in an App Engine application is a finding.
Instance Attribute Summary collapse
-
#category ⇒ String
The additional taxonomy group within findings from a given source.
-
#create_time ⇒ String
The time at which the finding was created in Security Command Center.
-
#event_time ⇒ String
The time at which the event took place, or when an update to the finding occurred.
-
#external_uri ⇒ String
The URI that, if available, points to a web page outside of Security Command Center where additional information about the finding can be found.
-
#name ⇒ String
The relative resource name of this finding.
-
#parent ⇒ String
Immutable.
-
#resource_name ⇒ String
For findings on Google Cloud resources, the full resource name of the Google Cloud resource this finding is for.
-
#security_marks ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1beta1SecurityMarks
User specified security marks that are attached to the parent Security Command Center resource.
-
#source_properties ⇒ Hash<String,Object>
Source specific properties.
-
#state ⇒ String
The state of the finding.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1beta1Finding
constructor
A new instance of GoogleCloudSecuritycenterV1beta1Finding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1beta1Finding
Returns a new instance of GoogleCloudSecuritycenterV1beta1Finding.
4579 4580 4581 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4579 def initialize(**args) update!(**args) end |
Instance Attribute Details
#category ⇒ String
The additional taxonomy group within findings from a given source. This field
is immutable after creation time. Example: "XSS_FLASH_INJECTION"
Corresponds to the JSON property category
4511 4512 4513 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4511 def category @category end |
#create_time ⇒ String
The time at which the finding was created in Security Command Center.
Corresponds to the JSON property createTime
4516 4517 4518 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4516 def create_time @create_time end |
#event_time ⇒ String
The time at which the event took place, or when an update to the finding
occurred. For example, if the finding represents an open firewall it would
capture the time the detector believes the firewall became open. The accuracy
is determined by the detector. If the finding were to be resolved afterward,
this time would reflect when the finding was resolved.
Corresponds to the JSON property eventTime
4525 4526 4527 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4525 def event_time @event_time end |
#external_uri ⇒ String
The URI that, if available, points to a web page outside of Security Command
Center where additional information about the finding can be found. This field
is guaranteed to be either empty or a well formed URL.
Corresponds to the JSON property externalUri
4532 4533 4534 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4532 def external_uri @external_uri end |
#name ⇒ String
The relative resource name of this finding. See: https://cloud.google.com/apis/
design/resource_names#relative_resource_name Example: "organizations/
organization_id/sources/source_id/findings/finding_id"
Corresponds to the JSON property name
4539 4540 4541 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4539 def name @name end |
#parent ⇒ String
Immutable. The relative resource name of the source the finding belongs to.
See: https://cloud.google.com/apis/design/resource_names#
relative_resource_name This field is immutable after creation time. For
example: "organizations/organization_id/sources/source_id"
Corresponds to the JSON property parent
4547 4548 4549 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4547 def parent @parent end |
#resource_name ⇒ String
For findings on Google Cloud resources, the full resource name of the Google
Cloud resource this finding is for. See: https://cloud.google.com/apis/design/
resource_names#full_resource_name When the finding is for a non-Google Cloud
resource, the resourceName can be a customer or partner defined string. This
field is immutable after creation time.
Corresponds to the JSON property resourceName
4556 4557 4558 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4556 def resource_name @resource_name end |
#security_marks ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1beta1SecurityMarks
User specified security marks that are attached to the parent Security Command
Center resource. Security marks are scoped within a Security Command Center
organization -- they can be modified and viewed by all users who have proper
permissions on the organization.
Corresponds to the JSON property securityMarks
4564 4565 4566 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4564 def security_marks @security_marks end |
#source_properties ⇒ Hash<String,Object>
Source specific properties. These properties are managed by the source that
writes the finding. The key names in the source_properties map must be between
1 and 255 characters, and must start with a letter and contain alphanumeric
characters or underscores only.
Corresponds to the JSON property sourceProperties
4572 4573 4574 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4572 def source_properties @source_properties end |
#state ⇒ String
The state of the finding.
Corresponds to the JSON property state
4577 4578 4579 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4577 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4584 def update!(**args) @category = args[:category] if args.key?(:category) @create_time = args[:create_time] if args.key?(:create_time) @event_time = args[:event_time] if args.key?(:event_time) @external_uri = args[:external_uri] if args.key?(:external_uri) @name = args[:name] if args.key?(:name) @parent = args[:parent] if args.key?(:parent) @resource_name = args[:resource_name] if args.key?(:resource_name) @security_marks = args[:security_marks] if args.key?(:security_marks) @source_properties = args[:source_properties] if args.key?(:source_properties) @state = args[:state] if args.key?(:state) end |