Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1beta1RunAssetDiscoveryResponse
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1beta1RunAssetDiscoveryResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Response of asset discovery run
Instance Attribute Summary collapse
-
#duration ⇒ String
The duration between asset discovery run start and end Corresponds to the JSON property
duration. -
#state ⇒ String
The state of an asset discovery run.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1beta1RunAssetDiscoveryResponse
constructor
A new instance of GoogleCloudSecuritycenterV1beta1RunAssetDiscoveryResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1beta1RunAssetDiscoveryResponse
Returns a new instance of GoogleCloudSecuritycenterV1beta1RunAssetDiscoveryResponse.
4553 4554 4555 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4553 def initialize(**args) update!(**args) end |
Instance Attribute Details
#duration ⇒ String
The duration between asset discovery run start and end
Corresponds to the JSON property duration
4546 4547 4548 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4546 def duration @duration end |
#state ⇒ String
The state of an asset discovery run.
Corresponds to the JSON property state
4551 4552 4553 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4551 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4558 4559 4560 4561 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4558 def update!(**args) @duration = args[:duration] if args.key?(:duration) @state = args[:state] if args.key?(:state) end |