Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1p1beta1Finding
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1p1beta1Finding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Security Command Center finding. A finding is a record of assessment data ( security, risk, health or privacy) ingested into Security Command Center for presentation, notification, analysis, policy testing, and enforcement. For example, an XSS vulnerability in an App Engine application is a finding.
Instance Attribute Summary collapse
-
#canonical_name ⇒ String
The canonical name of the finding.
-
#category ⇒ String
The additional taxonomy group within findings from a given source.
-
#create_time ⇒ String
The time at which the finding was created in Security Command Center.
-
#event_time ⇒ String
The time at which the event took place, or when an update to the finding occurred.
-
#external_uri ⇒ String
The URI that, if available, points to a web page outside of Security Command Center where additional information about the finding can be found.
-
#name ⇒ String
The relative resource name of this finding.
-
#parent ⇒ String
The relative resource name of the source the finding belongs to.
-
#resource_name ⇒ String
For findings on Google Cloud resources, the full resource name of the Google Cloud resource this finding is for.
-
#security_marks ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1p1beta1SecurityMarks
User specified security marks that are attached to the parent Security Command Center resource.
-
#severity ⇒ String
The severity of the finding.
-
#source_properties ⇒ Hash<String,Object>
Source specific properties.
-
#state ⇒ String
The state of the finding.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1p1beta1Finding
constructor
A new instance of GoogleCloudSecuritycenterV1p1beta1Finding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1p1beta1Finding
Returns a new instance of GoogleCloudSecuritycenterV1p1beta1Finding.
4575 4576 4577 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4575 def initialize(**args) update!(**args) end |
Instance Attribute Details
#canonical_name ⇒ String
The canonical name of the finding. It's either "organizations/organization_id
/sources/source_id/findings/finding_id", "folders/folder_id/sources/
source_id/findings/finding_id" or "projects/project_number/sources/
source_id/findings/finding_id", depending on the closest CRM ancestor of
the resource associated with the finding.
Corresponds to the JSON property canonicalName
4494 4495 4496 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4494 def canonical_name @canonical_name end |
#category ⇒ String
The additional taxonomy group within findings from a given source. This field
is immutable after creation time. Example: "XSS_FLASH_INJECTION"
Corresponds to the JSON property category
4500 4501 4502 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4500 def category @category end |
#create_time ⇒ String
The time at which the finding was created in Security Command Center.
Corresponds to the JSON property createTime
4505 4506 4507 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4505 def create_time @create_time end |
#event_time ⇒ String
The time at which the event took place, or when an update to the finding
occurred. For example, if the finding represents an open firewall it would
capture the time the detector believes the firewall became open. The accuracy
is determined by the detector. If the finding were to be resolved afterward,
this time would reflect when the finding was resolved. Must not be set to a
value greater than the current timestamp.
Corresponds to the JSON property eventTime
4515 4516 4517 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4515 def event_time @event_time end |
#external_uri ⇒ String
The URI that, if available, points to a web page outside of Security Command
Center where additional information about the finding can be found. This field
is guaranteed to be either empty or a well formed URL.
Corresponds to the JSON property externalUri
4522 4523 4524 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4522 def external_uri @external_uri end |
#name ⇒ String
The relative resource name of this finding. See: https://cloud.google.com/apis/
design/resource_names#relative_resource_name Example: "organizations/
organization_id/sources/source_id/findings/finding_id"
Corresponds to the JSON property name
4529 4530 4531 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4529 def name @name end |
#parent ⇒ String
The relative resource name of the source the finding belongs to. See: https://
cloud.google.com/apis/design/resource_names#relative_resource_name This field
is immutable after creation time. For example: "organizations/organization_id
/sources/source_id"
Corresponds to the JSON property parent
4537 4538 4539 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4537 def parent @parent end |
#resource_name ⇒ String
For findings on Google Cloud resources, the full resource name of the Google
Cloud resource this finding is for. See: https://cloud.google.com/apis/design/
resource_names#full_resource_name When the finding is for a non-Google Cloud
resource, the resourceName can be a customer or partner defined string. This
field is immutable after creation time.
Corresponds to the JSON property resourceName
4546 4547 4548 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4546 def resource_name @resource_name end |
#security_marks ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1p1beta1SecurityMarks
User specified security marks that are attached to the parent Security Command
Center resource. Security marks are scoped within a Security Command Center
organization -- they can be modified and viewed by all users who have proper
permissions on the organization.
Corresponds to the JSON property securityMarks
4554 4555 4556 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4554 def security_marks @security_marks end |
#severity ⇒ String
The severity of the finding. This field is managed by the source that writes
the finding.
Corresponds to the JSON property severity
4560 4561 4562 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4560 def severity @severity end |
#source_properties ⇒ Hash<String,Object>
Source specific properties. These properties are managed by the source that
writes the finding. The key names in the source_properties map must be between
1 and 255 characters, and must start with a letter and contain alphanumeric
characters or underscores only.
Corresponds to the JSON property sourceProperties
4568 4569 4570 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4568 def source_properties @source_properties end |
#state ⇒ String
The state of the finding.
Corresponds to the JSON property state
4573 4574 4575 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4573 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4580 4581 4582 4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4580 def update!(**args) @canonical_name = args[:canonical_name] if args.key?(:canonical_name) @category = args[:category] if args.key?(:category) @create_time = args[:create_time] if args.key?(:create_time) @event_time = args[:event_time] if args.key?(:event_time) @external_uri = args[:external_uri] if args.key?(:external_uri) @name = args[:name] if args.key?(:name) @parent = args[:parent] if args.key?(:parent) @resource_name = args[:resource_name] if args.key?(:resource_name) @security_marks = args[:security_marks] if args.key?(:security_marks) @severity = args[:severity] if args.key?(:severity) @source_properties = args[:source_properties] if args.key?(:source_properties) @state = args[:state] if args.key?(:state) end |