Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1p1beta1Resource
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1p1beta1Resource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Information related to the Google Cloud resource.
Instance Attribute Summary collapse
-
#folders ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1p1beta1Folder>
Output only.
-
#name ⇒ String
The full resource name of the resource.
-
#parent ⇒ String
The full resource name of resource's parent.
-
#parent_display_name ⇒ String
The human readable name of resource's parent.
-
#project ⇒ String
The full resource name of project that the resource belongs to.
-
#project_display_name ⇒ String
The project id that the resource belongs to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1p1beta1Resource
constructor
A new instance of GoogleCloudSecuritycenterV1p1beta1Resource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1p1beta1Resource
Returns a new instance of GoogleCloudSecuritycenterV1p1beta1Resource.
4871 4872 4873 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4871 def initialize(**args) update!(**args) end |
Instance Attribute Details
#folders ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1p1beta1Folder>
Output only. Contains a Folder message for each folder in the assets ancestry.
The first folder is the deepest nested folder, and the last folder is the
folder directly under the Organization.
Corresponds to the JSON property folders
4843 4844 4845 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4843 def folders @folders end |
#name ⇒ String
The full resource name of the resource. See: https://cloud.google.com/apis/
design/resource_names#full_resource_name
Corresponds to the JSON property name
4849 4850 4851 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4849 def name @name end |
#parent ⇒ String
The full resource name of resource's parent.
Corresponds to the JSON property parent
4854 4855 4856 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4854 def parent @parent end |
#parent_display_name ⇒ String
The human readable name of resource's parent.
Corresponds to the JSON property parentDisplayName
4859 4860 4861 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4859 def parent_display_name @parent_display_name end |
#project ⇒ String
The full resource name of project that the resource belongs to.
Corresponds to the JSON property project
4864 4865 4866 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4864 def project @project end |
#project_display_name ⇒ String
The project id that the resource belongs to.
Corresponds to the JSON property projectDisplayName
4869 4870 4871 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4869 def project_display_name @project_display_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4876 4877 4878 4879 4880 4881 4882 4883 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4876 def update!(**args) @folders = args[:folders] if args.key?(:folders) @name = args[:name] if args.key?(:name) @parent = args[:parent] if args.key?(:parent) @parent_display_name = args[:parent_display_name] if args.key?(:parent_display_name) @project = args[:project] if args.key?(:project) @project_display_name = args[:project_display_name] if args.key?(:project_display_name) end |