Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1p1beta1Resource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Information related to the Google Cloud resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV1p1beta1Resource

Returns a new instance of GoogleCloudSecuritycenterV1p1beta1Resource.



4812
4813
4814
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4812

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#foldersArray<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1p1beta1Folder>

Output only. Contains a Folder message for each folder in the assets ancestry. The first folder is the deepest nested folder, and the last folder is the folder directly under the Organization. Corresponds to the JSON property folders



4784
4785
4786
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4784

def folders
  @folders
end

#nameString

The full resource name of the resource. See: https://cloud.google.com/apis/ design/resource_names#full_resource_name Corresponds to the JSON property name

Returns:

  • (String)


4790
4791
4792
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4790

def name
  @name
end

#parentString

The full resource name of resource's parent. Corresponds to the JSON property parent

Returns:

  • (String)


4795
4796
4797
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4795

def parent
  @parent
end

#parent_display_nameString

The human readable name of resource's parent. Corresponds to the JSON property parentDisplayName

Returns:

  • (String)


4800
4801
4802
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4800

def parent_display_name
  @parent_display_name
end

#projectString

The full resource name of project that the resource belongs to. Corresponds to the JSON property project

Returns:

  • (String)


4805
4806
4807
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4805

def project
  @project
end

#project_display_nameString

The project id that the resource belongs to. Corresponds to the JSON property projectDisplayName

Returns:

  • (String)


4810
4811
4812
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4810

def project_display_name
  @project_display_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4817
4818
4819
4820
4821
4822
4823
4824
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4817

def update!(**args)
  @folders = args[:folders] if args.key?(:folders)
  @name = args[:name] if args.key?(:name)
  @parent = args[:parent] if args.key?(:parent)
  @parent_display_name = args[:parent_display_name] if args.key?(:parent_display_name)
  @project = args[:project] if args.key?(:project)
  @project_display_name = args[:project_display_name] if args.key?(:project_display_name)
end