Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1p1beta1Resource
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1p1beta1Resource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Information related to the Google Cloud resource.
Instance Attribute Summary collapse
-
#folders ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1p1beta1Folder>
Output only.
-
#name ⇒ String
The full resource name of the resource.
-
#parent ⇒ String
The full resource name of resource's parent.
-
#parent_display_name ⇒ String
The human readable name of resource's parent.
-
#project ⇒ String
The full resource name of project that the resource belongs to.
-
#project_display_name ⇒ String
The project id that the resource belongs to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1p1beta1Resource
constructor
A new instance of GoogleCloudSecuritycenterV1p1beta1Resource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV1p1beta1Resource
Returns a new instance of GoogleCloudSecuritycenterV1p1beta1Resource.
4693 4694 4695 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4693 def initialize(**args) update!(**args) end |
Instance Attribute Details
#folders ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1p1beta1Folder>
Output only. Contains a Folder message for each folder in the assets ancestry.
The first folder is the deepest nested folder, and the last folder is the
folder directly under the Organization.
Corresponds to the JSON property folders
4665 4666 4667 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4665 def folders @folders end |
#name ⇒ String
The full resource name of the resource. See: https://cloud.google.com/apis/
design/resource_names#full_resource_name
Corresponds to the JSON property name
4671 4672 4673 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4671 def name @name end |
#parent ⇒ String
The full resource name of resource's parent.
Corresponds to the JSON property parent
4676 4677 4678 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4676 def parent @parent end |
#parent_display_name ⇒ String
The human readable name of resource's parent.
Corresponds to the JSON property parentDisplayName
4681 4682 4683 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4681 def parent_display_name @parent_display_name end |
#project ⇒ String
The full resource name of project that the resource belongs to.
Corresponds to the JSON property project
4686 4687 4688 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4686 def project @project end |
#project_display_name ⇒ String
The project id that the resource belongs to.
Corresponds to the JSON property projectDisplayName
4691 4692 4693 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4691 def project_display_name @project_display_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4698 4699 4700 4701 4702 4703 4704 4705 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4698 def update!(**args) @folders = args[:folders] if args.key?(:folders) @name = args[:name] if args.key?(:name) @parent = args[:parent] if args.key?(:parent) @parent_display_name = args[:parent_display_name] if args.key?(:parent_display_name) @project = args[:project] if args.key?(:project) @project_display_name = args[:project_display_name] if args.key?(:project_display_name) end |