Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2AccessReview

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Conveys information about a Kubernetes access review (such as one returned by a kubectl auth can-i command) that was involved in a finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AccessReview

Returns a new instance of GoogleCloudSecuritycenterV2AccessReview.



5047
5048
5049
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5047

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#groupString

The API group of the resource. "*" means all. Corresponds to the JSON property group

Returns:

  • (String)


5013
5014
5015
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5013

def group
  @group
end

#nameString

The name of the resource being requested. Empty means all. Corresponds to the JSON property name

Returns:

  • (String)


5018
5019
5020
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5018

def name
  @name
end

#nsString

Namespace of the action being requested. Currently, there is no distinction between no namespace and all namespaces. Both are represented by "" (empty). Corresponds to the JSON property ns

Returns:

  • (String)


5024
5025
5026
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5024

def ns
  @ns
end

#resourceString

The optional resource type requested. "*" means all. Corresponds to the JSON property resource

Returns:

  • (String)


5029
5030
5031
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5029

def resource
  @resource
end

#subresourceString

The optional subresource type. Corresponds to the JSON property subresource

Returns:

  • (String)


5034
5035
5036
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5034

def subresource
  @subresource
end

#verbString

A Kubernetes resource API verb, like get, list, watch, create, update, delete, proxy. "*" means all. Corresponds to the JSON property verb

Returns:

  • (String)


5040
5041
5042
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5040

def verb
  @verb
end

#versionString

The API version of the resource. "*" means all. Corresponds to the JSON property version

Returns:

  • (String)


5045
5046
5047
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5045

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5052
5053
5054
5055
5056
5057
5058
5059
5060
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5052

def update!(**args)
  @group = args[:group] if args.key?(:group)
  @name = args[:name] if args.key?(:name)
  @ns = args[:ns] if args.key?(:ns)
  @resource = args[:resource] if args.key?(:resource)
  @subresource = args[:subresource] if args.key?(:subresource)
  @verb = args[:verb] if args.key?(:verb)
  @version = args[:version] if args.key?(:version)
end