Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2AccessReview
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2AccessReview
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Conveys information about a Kubernetes access review (such as one returned by
a kubectl auth can-i command) that was involved in a
finding.
Instance Attribute Summary collapse
-
#group ⇒ String
The API group of the resource.
-
#name ⇒ String
The name of the resource being requested.
-
#ns ⇒ String
Namespace of the action being requested.
-
#resource ⇒ String
The optional resource type requested.
-
#subresource ⇒ String
The optional subresource type.
-
#verb ⇒ String
A Kubernetes resource API verb, like get, list, watch, create, update, delete, proxy.
-
#version ⇒ String
The API version of the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AccessReview
constructor
A new instance of GoogleCloudSecuritycenterV2AccessReview.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AccessReview
Returns a new instance of GoogleCloudSecuritycenterV2AccessReview.
5047 5048 5049 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5047 def initialize(**args) update!(**args) end |
Instance Attribute Details
#group ⇒ String
The API group of the resource. "*" means all.
Corresponds to the JSON property group
5013 5014 5015 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5013 def group @group end |
#name ⇒ String
The name of the resource being requested. Empty means all.
Corresponds to the JSON property name
5018 5019 5020 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5018 def name @name end |
#ns ⇒ String
Namespace of the action being requested. Currently, there is no distinction
between no namespace and all namespaces. Both are represented by "" (empty).
Corresponds to the JSON property ns
5024 5025 5026 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5024 def ns @ns end |
#resource ⇒ String
The optional resource type requested. "*" means all.
Corresponds to the JSON property resource
5029 5030 5031 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5029 def resource @resource end |
#subresource ⇒ String
The optional subresource type.
Corresponds to the JSON property subresource
5034 5035 5036 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5034 def subresource @subresource end |
#verb ⇒ String
A Kubernetes resource API verb, like get, list, watch, create, update, delete,
proxy. "*" means all.
Corresponds to the JSON property verb
5040 5041 5042 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5040 def verb @verb end |
#version ⇒ String
The API version of the resource. "*" means all.
Corresponds to the JSON property version
5045 5046 5047 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5045 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5052 5053 5054 5055 5056 5057 5058 5059 5060 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5052 def update!(**args) @group = args[:group] if args.key?(:group) @name = args[:name] if args.key?(:name) @ns = args[:ns] if args.key?(:ns) @resource = args[:resource] if args.key?(:resource) @subresource = args[:subresource] if args.key?(:subresource) @verb = args[:verb] if args.key?(:verb) @version = args[:version] if args.key?(:version) end |