Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2AccessReview

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Conveys information about a Kubernetes access review (such as one returned by a kubectl auth can-i command) that was involved in a finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AccessReview

Returns a new instance of GoogleCloudSecuritycenterV2AccessReview.



4928
4929
4930
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4928

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#groupString

The API group of the resource. "*" means all. Corresponds to the JSON property group

Returns:

  • (String)


4894
4895
4896
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4894

def group
  @group
end

#nameString

The name of the resource being requested. Empty means all. Corresponds to the JSON property name

Returns:

  • (String)


4899
4900
4901
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4899

def name
  @name
end

#nsString

Namespace of the action being requested. Currently, there is no distinction between no namespace and all namespaces. Both are represented by "" (empty). Corresponds to the JSON property ns

Returns:

  • (String)


4905
4906
4907
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4905

def ns
  @ns
end

#resourceString

The optional resource type requested. "*" means all. Corresponds to the JSON property resource

Returns:

  • (String)


4910
4911
4912
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4910

def resource
  @resource
end

#subresourceString

The optional subresource type. Corresponds to the JSON property subresource

Returns:

  • (String)


4915
4916
4917
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4915

def subresource
  @subresource
end

#verbString

A Kubernetes resource API verb, like get, list, watch, create, update, delete, proxy. "*" means all. Corresponds to the JSON property verb

Returns:

  • (String)


4921
4922
4923
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4921

def verb
  @verb
end

#versionString

The API version of the resource. "*" means all. Corresponds to the JSON property version

Returns:

  • (String)


4926
4927
4928
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4926

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4933
4934
4935
4936
4937
4938
4939
4940
4941
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 4933

def update!(**args)
  @group = args[:group] if args.key?(:group)
  @name = args[:name] if args.key?(:name)
  @ns = args[:ns] if args.key?(:ns)
  @resource = args[:resource] if args.key?(:resource)
  @subresource = args[:subresource] if args.key?(:subresource)
  @verb = args[:verb] if args.key?(:verb)
  @version = args[:version] if args.key?(:version)
end