Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2AiModel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Contains information about the AI model associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AiModel

Returns a new instance of GoogleCloudSecuritycenterV2AiModel.



5257
5258
5259
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5257

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deployment_platformString

The platform on which the model is deployed. Corresponds to the JSON property deploymentPlatform

Returns:

  • (String)


5220
5221
5222
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5220

def deployment_platform
  @deployment_platform
end

#display_nameString

The user defined display name of model. Ex. baseline-classification-model Corresponds to the JSON property displayName

Returns:

  • (String)


5225
5226
5227
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5225

def display_name
  @display_name
end

#domainString

The domain of the model, for example, “image-classification”. Corresponds to the JSON property domain

Returns:

  • (String)


5230
5231
5232
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5230

def domain
  @domain
end

#libraryString

The name of the model library, for example, “transformers”. Corresponds to the JSON property library

Returns:

  • (String)


5235
5236
5237
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5235

def library
  @library
end

#locationString

The region in which the model is used, for example, “us-central1”. Corresponds to the JSON property location

Returns:

  • (String)


5240
5241
5242
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5240

def location
  @location
end

#nameString

The name of the AI model, for example, "gemini:1.0.0". Corresponds to the JSON property name

Returns:

  • (String)


5245
5246
5247
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5245

def name
  @name
end

#publisherString

The publisher of the model, for example, “google” or “nvidia”. Corresponds to the JSON property publisher

Returns:

  • (String)


5250
5251
5252
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5250

def publisher
  @publisher
end

#usage_categoryString

The purpose of the model, for example, "Inteference" or "Training". Corresponds to the JSON property usageCategory

Returns:

  • (String)


5255
5256
5257
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5255

def usage_category
  @usage_category
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5262
5263
5264
5265
5266
5267
5268
5269
5270
5271
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5262

def update!(**args)
  @deployment_platform = args[:deployment_platform] if args.key?(:deployment_platform)
  @display_name = args[:display_name] if args.key?(:display_name)
  @domain = args[:domain] if args.key?(:domain)
  @library = args[:library] if args.key?(:library)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @publisher = args[:publisher] if args.key?(:publisher)
  @usage_category = args[:usage_category] if args.key?(:usage_category)
end