Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2AttackExposure

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

An attack exposure contains the results of an attack path simulation run.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2AttackExposure

Returns a new instance of GoogleCloudSecuritycenterV2AttackExposure.



5313
5314
5315
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5313

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attack_exposure_resultString

The resource name of the attack path simulation result that contains the details regarding this attack exposure score. Example: organizations/123/ simulations/456/attackExposureResults/789 Corresponds to the JSON property attackExposureResult

Returns:

  • (String)


5275
5276
5277
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5275

def attack_exposure_result
  @attack_exposure_result
end

#exposed_high_value_resources_countFixnum

The number of high value resources that are exposed as a result of this finding. Corresponds to the JSON property exposedHighValueResourcesCount

Returns:

  • (Fixnum)


5281
5282
5283
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5281

def exposed_high_value_resources_count
  @exposed_high_value_resources_count
end

#exposed_low_value_resources_countFixnum

The number of high value resources that are exposed as a result of this finding. Corresponds to the JSON property exposedLowValueResourcesCount

Returns:

  • (Fixnum)


5287
5288
5289
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5287

def exposed_low_value_resources_count
  @exposed_low_value_resources_count
end

#exposed_medium_value_resources_countFixnum

The number of medium value resources that are exposed as a result of this finding. Corresponds to the JSON property exposedMediumValueResourcesCount

Returns:

  • (Fixnum)


5293
5294
5295
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5293

def exposed_medium_value_resources_count
  @exposed_medium_value_resources_count
end

#latest_calculation_timeString

The most recent time the attack exposure was updated on this finding. Corresponds to the JSON property latestCalculationTime

Returns:

  • (String)


5298
5299
5300
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5298

def latest_calculation_time
  @latest_calculation_time
end

#scoreFloat

A number between 0 (inclusive) and infinity that represents how important this finding is to remediate. The higher the score, the more important it is to remediate. Corresponds to the JSON property score

Returns:

  • (Float)


5305
5306
5307
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5305

def score
  @score
end

#stateString

Output only. What state this AttackExposure is in. This captures whether or not an attack exposure has been calculated or not. Corresponds to the JSON property state

Returns:

  • (String)


5311
5312
5313
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5311

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5318
5319
5320
5321
5322
5323
5324
5325
5326
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5318

def update!(**args)
  @attack_exposure_result = args[:attack_exposure_result] if args.key?(:attack_exposure_result)
  @exposed_high_value_resources_count = args[:exposed_high_value_resources_count] if args.key?(:exposed_high_value_resources_count)
  @exposed_low_value_resources_count = args[:exposed_low_value_resources_count] if args.key?(:exposed_low_value_resources_count)
  @exposed_medium_value_resources_count = args[:exposed_medium_value_resources_count] if args.key?(:exposed_medium_value_resources_count)
  @latest_calculation_time = args[:latest_calculation_time] if args.key?(:latest_calculation_time)
  @score = args[:score] if args.key?(:score)
  @state = args[:state] if args.key?(:state)
end