Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2BackupDisasterRecovery
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2BackupDisasterRecovery
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Information related to Google Cloud Backup and DR Service findings.
Instance Attribute Summary collapse
-
#appliance ⇒ String
The name of the Backup and DR appliance that captures, moves, and manages the lifecycle of backup data.
-
#applications ⇒ Array<String>
The names of Backup and DR applications.
-
#backup_create_time ⇒ String
The timestamp at which the Backup and DR backup was created.
-
#backup_template ⇒ String
The name of a Backup and DR template which comprises one or more backup policies.
-
#backup_type ⇒ String
The backup type of the Backup and DR image.
-
#host ⇒ String
The name of a Backup and DR host, which is managed by the backup and recovery appliance and known to the management console.
-
#policies ⇒ Array<String>
The names of Backup and DR policies that are associated with a template and that define when to run a backup, how frequently to run a backup, and how long to retain the backup image.
-
#policy_options ⇒ Array<String>
The names of Backup and DR advanced policy options of a policy applying to an application.
-
#profile ⇒ String
The name of the Backup and DR resource profile that specifies the storage media for backups of application and VM data.
-
#storage_pool ⇒ String
The name of the Backup and DR storage pool that the backup and recovery appliance is storing data in.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2BackupDisasterRecovery
constructor
A new instance of GoogleCloudSecuritycenterV2BackupDisasterRecovery.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2BackupDisasterRecovery
Returns a new instance of GoogleCloudSecuritycenterV2BackupDisasterRecovery.
5879 5880 5881 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5879 def initialize(**args) update!(**args) end |
Instance Attribute Details
#appliance ⇒ String
The name of the Backup and DR appliance that captures, moves, and manages the
lifecycle of backup data. For example, backup-server-57137.
Corresponds to the JSON property appliance
5809 5810 5811 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5809 def appliance @appliance end |
#applications ⇒ Array<String>
The names of Backup and DR applications. An application is a VM, database, or
file system on a managed host monitored by a backup and recovery appliance.
For example, centos7-01-vol00, centos7-01-vol01, centos7-01-vol02.
Corresponds to the JSON property applications
5816 5817 5818 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5816 def applications @applications end |
#backup_create_time ⇒ String
The timestamp at which the Backup and DR backup was created.
Corresponds to the JSON property backupCreateTime
5821 5822 5823 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5821 def backup_create_time @backup_create_time end |
#backup_template ⇒ String
The name of a Backup and DR template which comprises one or more backup
policies. See the Backup and DR documentation for more information.
For example, snap-ov.
Corresponds to the JSON property backupTemplate
5829 5830 5831 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5829 def backup_template @backup_template end |
#backup_type ⇒ String
The backup type of the Backup and DR image. For example, Snapshot, Remote
Snapshot, OnVault.
Corresponds to the JSON property backupType
5835 5836 5837 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5835 def backup_type @backup_type end |
#host ⇒ String
The name of a Backup and DR host, which is managed by the backup and recovery
appliance and known to the management console. The host can be of type Generic
(for example, Compute Engine, SQL Server, Oracle DB, SMB file system, etc.),
vCenter, or an ESX server. See the Backup and DR documentation on hosts for more information. For example, centos7-01.
Corresponds to the JSON property host
5845 5846 5847 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5845 def host @host end |
#policies ⇒ Array<String>
The names of Backup and DR policies that are associated with a template and
that define when to run a backup, how frequently to run a backup, and how long
to retain the backup image. For example, onvaults.
Corresponds to the JSON property policies
5852 5853 5854 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5852 def policies @policies end |
#policy_options ⇒ Array<String>
The names of Backup and DR advanced policy options of a policy applying to an
application. See the Backup and DR documentation on policy options.
For example, skipofflineappsincongrp, nounmap.
Corresponds to the JSON property policyOptions
5860 5861 5862 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5860 def @policy_options end |
#profile ⇒ String
The name of the Backup and DR resource profile that specifies the storage
media for backups of application and VM data. See the Backup and DR
documentation on profiles. For example, GCP.
Corresponds to the JSON property profile
5868 5869 5870 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5868 def profile @profile end |
#storage_pool ⇒ String
The name of the Backup and DR storage pool that the backup and recovery
appliance is storing data in. The storage pool could be of type Cloud, Primary,
Snapshot, or OnVault. See the Backup and DR documentation on storage pools.
For example, DiskPoolOne.
Corresponds to the JSON property storagePool
5877 5878 5879 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5877 def storage_pool @storage_pool end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5884 5885 5886 5887 5888 5889 5890 5891 5892 5893 5894 5895 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5884 def update!(**args) @appliance = args[:appliance] if args.key?(:appliance) @applications = args[:applications] if args.key?(:applications) @backup_create_time = args[:backup_create_time] if args.key?(:backup_create_time) @backup_template = args[:backup_template] if args.key?(:backup_template) @backup_type = args[:backup_type] if args.key?(:backup_type) @host = args[:host] if args.key?(:host) @policies = args[:policies] if args.key?(:policies) @policy_options = args[:policy_options] if args.key?(:policy_options) @profile = args[:profile] if args.key?(:profile) @storage_pool = args[:storage_pool] if args.key?(:storage_pool) end |