Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2BigQueryExport

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Configures how to deliver Findings to BigQuery Instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2BigQueryExport

Returns a new instance of GoogleCloudSecuritycenterV2BigQueryExport.



5756
5757
5758
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5756

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time at which the BigQuery export was created. This field is set by the server and will be ignored if provided on export on creation. Corresponds to the JSON property createTime

Returns:

  • (String)


5690
5691
5692
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5690

def create_time
  @create_time
end

#crypto_key_nameString

Output only. The resource name of the Cloud KMS CryptoKey used to protect this configuration's data, if configured during Security Command Center activation. Corresponds to the JSON property cryptoKeyName

Returns:

  • (String)


5697
5698
5699
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5697

def crypto_key_name
  @crypto_key_name
end

#datasetString

The dataset to write findings' updates to. Its format is "projects/[project_id] /datasets/[bigquery_dataset_id]". BigQuery dataset unique ID must contain only letters (a-z, A-Z), numbers (0-9), or underscores (_). Corresponds to the JSON property dataset

Returns:

  • (String)


5704
5705
5706
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5704

def dataset
  @dataset
end

#descriptionString

The description of the export (max of 1024 characters). Corresponds to the JSON property description

Returns:

  • (String)


5709
5710
5711
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5709

def description
  @description
end

#filterString

Expression that defines the filter to apply across create/update events of findings. The expression is a list of zero or more restrictions combined via logical operators AND and OR. Parentheses are supported, and OR has higher precedence than AND. Restrictions have the form and may have a - character in front of them to indicate negation. The fields map to those defined in the corresponding resource. The supported operators are: * = for all value types. * >, <, >=, <= for integer values. * :, meaning substring matching, for strings. The supported value types are: * string literals in quotes. * integer literals without quotes. * boolean literals true and false without quotes. Corresponds to the JSON property filter

Returns:

  • (String)


5723
5724
5725
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5723

def filter
  @filter
end

#most_recent_editorString

Output only. Email address of the user who last edited the BigQuery export. This field is set by the server and will be ignored if provided on export creation or update. Corresponds to the JSON property mostRecentEditor

Returns:

  • (String)


5730
5731
5732
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5730

def most_recent_editor
  @most_recent_editor
end

#nameString

Identifier. The relative resource name of this export. See: https://cloud. google.com/apis/design/resource_names#relative_resource_name. The following list shows some examples: + organizations/organization_id/locations/ location_id/bigQueryExports/export_id+ `folders/`folder_id`/locations/` location_id`/bigQueryExports/`export_id + projects/project_id/locations/ location_id/bigQueryExports/export_id`This field is provided in responses, and is ignored when provided in create requests. Corresponds to the JSON propertyname`

Returns:

  • (String)


5741
5742
5743
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5741

def name
  @name
end

#principalString

Output only. The service account that needs permission to create table and upload data to the BigQuery dataset. Corresponds to the JSON property principal

Returns:

  • (String)


5747
5748
5749
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5747

def principal
  @principal
end

#update_timeString

Output only. The most recent time at which the BigQuery export was updated. This field is set by the server and will be ignored if provided on export creation or update. Corresponds to the JSON property updateTime

Returns:

  • (String)


5754
5755
5756
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5754

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5761
5762
5763
5764
5765
5766
5767
5768
5769
5770
5771
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 5761

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @crypto_key_name = args[:crypto_key_name] if args.key?(:crypto_key_name)
  @dataset = args[:dataset] if args.key?(:dataset)
  @description = args[:description] if args.key?(:description)
  @filter = args[:filter] if args.key?(:filter)
  @most_recent_editor = args[:most_recent_editor] if args.key?(:most_recent_editor)
  @name = args[:name] if args.key?(:name)
  @principal = args[:principal] if args.key?(:principal)
  @update_time = args[:update_time] if args.key?(:update_time)
end