Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Cve

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

CVE stands for Common Vulnerabilities and Exposures. Information from the CVE record that describes this vulnerability.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Cve

Returns a new instance of GoogleCloudSecuritycenterV2Cve.



6336
6337
6338
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6336

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cvssv3Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Cvssv3

Common Vulnerability Scoring System version 3. Corresponds to the JSON property cvssv3



6285
6286
6287
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6285

def cvssv3
  @cvssv3
end

#exploit_release_dateString

Date the first publicly available exploit or PoC was released. Corresponds to the JSON property exploitReleaseDate

Returns:

  • (String)


6290
6291
6292
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6290

def exploit_release_date
  @exploit_release_date
end

#exploitation_activityString

The exploitation activity of the vulnerability in the wild. Corresponds to the JSON property exploitationActivity

Returns:

  • (String)


6295
6296
6297
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6295

def exploitation_activity
  @exploitation_activity
end

#first_exploitation_dateString

Date of the earliest known exploitation. Corresponds to the JSON property firstExploitationDate

Returns:

  • (String)


6300
6301
6302
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6300

def first_exploitation_date
  @first_exploitation_date
end

#idString

The unique identifier for the vulnerability. e.g. CVE-2021-34527 Corresponds to the JSON property id

Returns:

  • (String)


6305
6306
6307
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6305

def id
  @id
end

#impactString

The potential impact of the vulnerability if it was to be exploited. Corresponds to the JSON property impact

Returns:

  • (String)


6310
6311
6312
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6310

def impact
  @impact
end

#observed_in_the_wildBoolean Also known as: observed_in_the_wild?

Whether or not the vulnerability has been observed in the wild. Corresponds to the JSON property observedInTheWild

Returns:

  • (Boolean)


6315
6316
6317
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6315

def observed_in_the_wild
  @observed_in_the_wild
end

#referencesArray<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Reference>

Additional information about the CVE. e.g. https://cve.mitre.org/cgi-bin/ cvename.cgi?name=CVE-2021-34527 Corresponds to the JSON property references



6322
6323
6324
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6322

def references
  @references
end

#upstream_fix_availableBoolean Also known as: upstream_fix_available?

Whether upstream fix is available for the CVE. Corresponds to the JSON property upstreamFixAvailable

Returns:

  • (Boolean)


6327
6328
6329
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6327

def upstream_fix_available
  @upstream_fix_available
end

#zero_dayBoolean Also known as: zero_day?

Whether or not the vulnerability was zero day when the finding was published. Corresponds to the JSON property zeroDay

Returns:

  • (Boolean)


6333
6334
6335
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6333

def zero_day
  @zero_day
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6341
6342
6343
6344
6345
6346
6347
6348
6349
6350
6351
6352
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6341

def update!(**args)
  @cvssv3 = args[:cvssv3] if args.key?(:cvssv3)
  @exploit_release_date = args[:exploit_release_date] if args.key?(:exploit_release_date)
  @exploitation_activity = args[:exploitation_activity] if args.key?(:exploitation_activity)
  @first_exploitation_date = args[:first_exploitation_date] if args.key?(:first_exploitation_date)
  @id = args[:id] if args.key?(:id)
  @impact = args[:impact] if args.key?(:impact)
  @observed_in_the_wild = args[:observed_in_the_wild] if args.key?(:observed_in_the_wild)
  @references = args[:references] if args.key?(:references)
  @upstream_fix_available = args[:upstream_fix_available] if args.key?(:upstream_fix_available)
  @zero_day = args[:zero_day] if args.key?(:zero_day)
end