Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2DataRetentionDeletionEvent
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2DataRetentionDeletionEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Details about data retention deletion violations, in which the data is non- compliant based on their retention or deletion time, as defined in the applicable data security policy. The Data Retention Deletion (DRD) control is a control of the DSPM (Data Security Posture Management) suite that enables organizations to manage data retention and deletion policies in compliance with regulations, such as GDPR and CRPA. DRD supports two primary policy types: maximum storage length (max TTL) and minimum storage length (min TTL). Both are aimed at helping organizations meet regulatory and data management commitments.
Instance Attribute Summary collapse
-
#data_object_count ⇒ Fixnum
Number of objects that violated the policy for this resource.
-
#event_detection_time ⇒ String
Timestamp indicating when the event was detected.
-
#event_type ⇒ String
Type of the DRD event.
-
#max_retention_allowed ⇒ String
Maximum duration of retention allowed from the DRD control.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2DataRetentionDeletionEvent
constructor
A new instance of GoogleCloudSecuritycenterV2DataRetentionDeletionEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2DataRetentionDeletionEvent
Returns a new instance of GoogleCloudSecuritycenterV2DataRetentionDeletionEvent.
6584 6585 6586 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6584 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_object_count ⇒ Fixnum
Number of objects that violated the policy for this resource. If the number is
less than 1,000, then the value of this field is the exact number. If the
number of objects that violated the policy is greater than or equal to 1,000,
then the value of this field is 1000.
Corresponds to the JSON property dataObjectCount
6562 6563 6564 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6562 def data_object_count @data_object_count end |
#event_detection_time ⇒ String
Timestamp indicating when the event was detected.
Corresponds to the JSON property eventDetectionTime
6567 6568 6569 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6567 def event_detection_time @event_detection_time end |
#event_type ⇒ String
Type of the DRD event.
Corresponds to the JSON property eventType
6572 6573 6574 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6572 def event_type @event_type end |
#max_retention_allowed ⇒ String
Maximum duration of retention allowed from the DRD control. This comes from
the DRD control where users set a max TTL for their data. For example, suppose
that a user sets the max TTL for a Cloud Storage bucket to 90 days. However,
an object in that bucket is 100 days old. In this case, a
DataRetentionDeletionEvent will be generated for that Cloud Storage bucket,
and the max_retention_allowed is 90 days.
Corresponds to the JSON property maxRetentionAllowed
6582 6583 6584 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6582 def max_retention_allowed @max_retention_allowed end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6589 6590 6591 6592 6593 6594 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6589 def update!(**args) @data_object_count = args[:data_object_count] if args.key?(:data_object_count) @event_detection_time = args[:event_detection_time] if args.key?(:event_detection_time) @event_type = args[:event_type] if args.key?(:event_type) @max_retention_allowed = args[:max_retention_allowed] if args.key?(:max_retention_allowed) end |