Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Database

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Represents database access information, such as queries. A database may be a sub-resource of an instance (as in the case of Cloud SQL instances or Cloud Spanner instances), or the database instance itself. Some database resources might not have the full resource name populated because these resource types, such as Cloud SQL databases, are not yet supported by Cloud Asset Inventory. In these cases only the display name is provided.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Database

Returns a new instance of GoogleCloudSecuritycenterV2Database.



6809
6810
6811
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6809

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

The human-readable name of the database that the user connected to. Corresponds to the JSON property displayName

Returns:

  • (String)


6774
6775
6776
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6774

def display_name
  @display_name
end

#granteesArray<String>

The target usernames, roles, or groups of an SQL privilege grant, which is not an IAM policy change. Corresponds to the JSON property grantees

Returns:

  • (Array<String>)


6780
6781
6782
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6780

def grantees
  @grantees
end

#nameString

Some database resources may not have the full resource name populated because these resource types are not yet supported by Cloud Asset Inventory (e.g. Cloud SQL databases). In these cases only the display name will be provided. The full resource name of the database that the user connected to, if it is supported by Cloud Asset Inventory. Corresponds to the JSON property name

Returns:

  • (String)


6790
6791
6792
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6790

def name
  @name
end

#queryString

The SQL statement that is associated with the database access. Corresponds to the JSON property query

Returns:

  • (String)


6795
6796
6797
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6795

def query
  @query
end

#user_nameString

The username used to connect to the database. The username might not be an IAM principal and does not have a set format. Corresponds to the JSON property userName

Returns:

  • (String)


6801
6802
6803
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6801

def user_name
  @user_name
end

#versionString

The version of the database, for example, POSTGRES_14. See the complete list. Corresponds to the JSON property version

Returns:

  • (String)


6807
6808
6809
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6807

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6814
6815
6816
6817
6818
6819
6820
6821
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 6814

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @grantees = args[:grantees] if args.key?(:grantees)
  @name = args[:name] if args.key?(:name)
  @query = args[:query] if args.key?(:query)
  @user_name = args[:user_name] if args.key?(:user_name)
  @version = args[:version] if args.key?(:version)
end