Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2ExfilResource
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2ExfilResource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Resource where data was exfiltrated from or exfiltrated to.
Instance Attribute Summary collapse
-
#components ⇒ Array<String>
Subcomponents of the asset that was exfiltrated, like URIs used during exfiltration, table names, databases, and filenames.
-
#name ⇒ String
The resource's full resource name.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ExfilResource
constructor
A new instance of GoogleCloudSecuritycenterV2ExfilResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ExfilResource
Returns a new instance of GoogleCloudSecuritycenterV2ExfilResource.
7128 7129 7130 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7128 def initialize(**args) update!(**args) end |
Instance Attribute Details
#components ⇒ Array<String>
Subcomponents of the asset that was exfiltrated, like URIs used during
exfiltration, table names, databases, and filenames. For example, multiple
tables might have been exfiltrated from the same Cloud SQL instance, or
multiple files might have been exfiltrated from the same Cloud Storage bucket.
Corresponds to the JSON property components
7120 7121 7122 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7120 def components @components end |
#name ⇒ String
The resource's full resource name.
Corresponds to the JSON property name
7126 7127 7128 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7126 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7133 7134 7135 7136 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7133 def update!(**args) @components = args[:components] if args.key?(:components) @name = args[:name] if args.key?(:name) end |