Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Exfiltration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Exfiltration represents a data exfiltration attempt from one or more sources to one or more targets. The sources attribute lists the sources of the exfiltrated data. The targets attribute lists the destinations the data was copied to.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Exfiltration

Returns a new instance of GoogleCloudSecuritycenterV2Exfiltration.



7105
7106
7107
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7105

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#sourcesArray<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2ExfilResource>

If there are multiple sources, then the data is considered "joined" between them. For instance, BigQuery can join multiple tables, and each table would be considered a source. Corresponds to the JSON property sources



7092
7093
7094
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7092

def sources
  @sources
end

#targetsArray<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2ExfilResource>

If there are multiple targets, each target would get a complete copy of the " joined" source data. Corresponds to the JSON property targets



7098
7099
7100
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7098

def targets
  @targets
end

#total_exfiltrated_bytesFixnum

Total exfiltrated bytes processed for the entire job. Corresponds to the JSON property totalExfiltratedBytes

Returns:

  • (Fixnum)


7103
7104
7105
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7103

def total_exfiltrated_bytes
  @total_exfiltrated_bytes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7110
7111
7112
7113
7114
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7110

def update!(**args)
  @sources = args[:sources] if args.key?(:sources)
  @targets = args[:targets] if args.key?(:targets)
  @total_exfiltrated_bytes = args[:total_exfiltrated_bytes] if args.key?(:total_exfiltrated_bytes)
end