Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2ExternalSystem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Representation of third party SIEM/SOAR fields within SCC.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ExternalSystem

Returns a new instance of GoogleCloudSecuritycenterV2ExternalSystem.



7281
7282
7283
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7281

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigneesArray<String>

References primary/secondary etc assignees in the external system. Corresponds to the JSON property assignees

Returns:

  • (Array<String>)


7219
7220
7221
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7219

def assignees
  @assignees
end

#case_close_timeString

The time when the case was closed, as reported by the external system. Corresponds to the JSON property caseCloseTime

Returns:

  • (String)


7224
7225
7226
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7224

def case_close_time
  @case_close_time
end

#case_create_timeString

The time when the case was created, as reported by the external system. Corresponds to the JSON property caseCreateTime

Returns:

  • (String)


7229
7230
7231
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7229

def case_create_time
  @case_create_time
end

#case_priorityString

The priority of the finding's corresponding case in the external system. Corresponds to the JSON property casePriority

Returns:

  • (String)


7234
7235
7236
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7234

def case_priority
  @case_priority
end

#case_slaString

The SLA of the finding's corresponding case in the external system. Corresponds to the JSON property caseSla

Returns:

  • (String)


7239
7240
7241
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7239

def case_sla
  @case_sla
end

#case_uriString

The link to the finding's corresponding case in the external system. Corresponds to the JSON property caseUri

Returns:

  • (String)


7244
7245
7246
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7244

def case_uri
  @case_uri
end

#external_system_update_timeString

The time when the case was last updated, as reported by the external system. Corresponds to the JSON property externalSystemUpdateTime

Returns:

  • (String)


7249
7250
7251
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7249

def external_system_update_time
  @external_system_update_time
end

#external_uidString

The identifier that's used to track the finding's corresponding case in the external system. Corresponds to the JSON property externalUid

Returns:

  • (String)


7255
7256
7257
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7255

def external_uid
  @external_uid
end

#nameString

Full resource name of the external system. The following list shows some examples: + organizations/1234/sources/5678/findings/123456/externalSystems/ jira + organizations/1234/sources/5678/locations/us/findings/123456/ externalSystems/jira + folders/1234/sources/5678/findings/123456/ externalSystems/jira + folders/1234/sources/5678/locations/us/findings/ 123456/externalSystems/jira + projects/1234/sources/5678/findings/123456/ externalSystems/jira + projects/1234/sources/5678/locations/us/findings/ 123456/externalSystems/jira Corresponds to the JSON property name

Returns:

  • (String)


7267
7268
7269
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7267

def name
  @name
end

#statusString

The most recent status of the finding's corresponding case, as reported by the external system. Corresponds to the JSON property status

Returns:

  • (String)


7273
7274
7275
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7273

def status
  @status
end

#ticket_infoGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2TicketInfo

Information about the ticket, if any, that is being used to track the resolution of the issue that is identified by this finding. Corresponds to the JSON property ticketInfo



7279
7280
7281
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7279

def ticket_info
  @ticket_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7286
7287
7288
7289
7290
7291
7292
7293
7294
7295
7296
7297
7298
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7286

def update!(**args)
  @assignees = args[:assignees] if args.key?(:assignees)
  @case_close_time = args[:case_close_time] if args.key?(:case_close_time)
  @case_create_time = args[:case_create_time] if args.key?(:case_create_time)
  @case_priority = args[:case_priority] if args.key?(:case_priority)
  @case_sla = args[:case_sla] if args.key?(:case_sla)
  @case_uri = args[:case_uri] if args.key?(:case_uri)
  @external_system_update_time = args[:external_system_update_time] if args.key?(:external_system_update_time)
  @external_uid = args[:external_uid] if args.key?(:external_uid)
  @name = args[:name] if args.key?(:name)
  @status = args[:status] if args.key?(:status)
  @ticket_info = args[:ticket_info] if args.key?(:ticket_info)
end