Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2GroupMembership

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Contains details about groups of which this finding is a member. A group is a collection of findings that are related in some way.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2GroupMembership

Returns a new instance of GoogleCloudSecuritycenterV2GroupMembership.



8022
8023
8024
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8022

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#group_idString

ID of the group. Corresponds to the JSON property groupId

Returns:

  • (String)


8015
8016
8017
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8015

def group_id
  @group_id
end

#group_typeString

Type of group. Corresponds to the JSON property groupType

Returns:

  • (String)


8020
8021
8022
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8020

def group_type
  @group_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8027
8028
8029
8030
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8027

def update!(**args)
  @group_id = args[:group_id] if args.key?(:group_id)
  @group_type = args[:group_type] if args.key?(:group_type)
end