Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Issue
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Issue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Security Command Center Issue.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
The description of the issue in Markdown format.
-
#detection ⇒ String
The finding category or rule name that generated the issue.
-
#domains ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueDomain>
The domains of the issue.
-
#exposure_score ⇒ Float
The exposure score of the issue.
-
#issue_type ⇒ String
The type of the issue.
-
#last_observation_time ⇒ String
The time the issue was last observed.
-
#mute ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueMute
The mute information of the issue.
-
#name ⇒ String
Identifier.
-
#primary_resource ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResource
A resource associated with the an issue.
-
#related_findings ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueFinding>
The findings related to the issue.
-
#remediations ⇒ Array<String>
Approaches to remediate the issue in Markdown format.
-
#secondary_resources ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResource>
Additional resources associated with the issue.
-
#security_contexts ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueSecurityContext>
The security context of the issue.
-
#severity ⇒ String
The severity of the issue.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Issue
constructor
A new instance of GoogleCloudSecuritycenterV2Issue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Issue
Returns a new instance of GoogleCloudSecuritycenterV2Issue.
8081 8082 8083 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8081 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time the issue was created.
Corresponds to the JSON property createTime
7998 7999 8000 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 7998 def create_time @create_time end |
#description ⇒ String
The description of the issue in Markdown format.
Corresponds to the JSON property description
8003 8004 8005 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8003 def description @description end |
#detection ⇒ String
The finding category or rule name that generated the issue.
Corresponds to the JSON property detection
8008 8009 8010 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8008 def detection @detection end |
#domains ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueDomain>
The domains of the issue.
Corresponds to the JSON property domains
8013 8014 8015 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8013 def domains @domains end |
#exposure_score ⇒ Float
The exposure score of the issue.
Corresponds to the JSON property exposureScore
8018 8019 8020 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8018 def exposure_score @exposure_score end |
#issue_type ⇒ String
The type of the issue.
Corresponds to the JSON property issueType
8023 8024 8025 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8023 def issue_type @issue_type end |
#last_observation_time ⇒ String
The time the issue was last observed.
Corresponds to the JSON property lastObservationTime
8028 8029 8030 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8028 def last_observation_time @last_observation_time end |
#mute ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueMute
The mute information of the issue.
Corresponds to the JSON property mute
8033 8034 8035 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8033 def mute @mute end |
#name ⇒ String
Identifier. The name of the issue. Format: organizations/organization/
locations/location/issues/issue
Corresponds to the JSON property name
8039 8040 8041 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8039 def name @name end |
#primary_resource ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResource
A resource associated with the an issue.
Corresponds to the JSON property primaryResource
8044 8045 8046 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8044 def primary_resource @primary_resource end |
#related_findings ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueFinding>
The findings related to the issue.
Corresponds to the JSON property relatedFindings
8049 8050 8051 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8049 def @related_findings end |
#remediations ⇒ Array<String>
Approaches to remediate the issue in Markdown format.
Corresponds to the JSON property remediations
8054 8055 8056 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8054 def remediations @remediations end |
#secondary_resources ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResource>
Additional resources associated with the issue.
Corresponds to the JSON property secondaryResources
8059 8060 8061 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8059 def secondary_resources @secondary_resources end |
#security_contexts ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueSecurityContext>
The security context of the issue.
Corresponds to the JSON property securityContexts
8064 8065 8066 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8064 def security_contexts @security_contexts end |
#severity ⇒ String
The severity of the issue.
Corresponds to the JSON property severity
8069 8070 8071 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8069 def severity @severity end |
#state ⇒ String
Output only. The state of the issue.
Corresponds to the JSON property state
8074 8075 8076 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8074 def state @state end |
#update_time ⇒ String
Output only. The time the issue was last updated.
Corresponds to the JSON property updateTime
8079 8080 8081 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8079 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8086 8087 8088 8089 8090 8091 8092 8093 8094 8095 8096 8097 8098 8099 8100 8101 8102 8103 8104 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8086 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @detection = args[:detection] if args.key?(:detection) @domains = args[:domains] if args.key?(:domains) @exposure_score = args[:exposure_score] if args.key?(:exposure_score) @issue_type = args[:issue_type] if args.key?(:issue_type) @last_observation_time = args[:last_observation_time] if args.key?(:last_observation_time) @mute = args[:mute] if args.key?(:mute) @name = args[:name] if args.key?(:name) @primary_resource = args[:primary_resource] if args.key?(:primary_resource) @related_findings = args[:related_findings] if args.key?(:related_findings) @remediations = args[:remediations] if args.key?(:remediations) @secondary_resources = args[:secondary_resources] if args.key?(:secondary_resources) @security_contexts = args[:security_contexts] if args.key?(:security_contexts) @severity = args[:severity] if args.key?(:severity) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |