Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

A resource associated with the an issue.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResource

Returns a new instance of GoogleCloudSecuritycenterV2IssueResource.



8530
8531
8532
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8530

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adc_applicationGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceAdcApplication

Represents an ADC application associated with the finding. Corresponds to the JSON property adcApplication



8477
8478
8479
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8477

def adc_application
  @adc_application
end

#adc_application_templateGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceAdcApplicationTemplateRevision

Represents an ADC template associated with the finding. Corresponds to the JSON property adcApplicationTemplate



8482
8483
8484
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8482

def adc_application_template
  @adc_application_template
end

#adc_shared_templateGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceAdcSharedTemplateRevision

Represents an ADC shared template associated with the finding. Corresponds to the JSON property adcSharedTemplate



8487
8488
8489
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8487

def adc_shared_template
  @adc_shared_template
end

#applicationGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceApplication

The AppHub application associated with the resource, if any. Corresponds to the JSON property application



8492
8493
8494
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8492

def application
  @application
end

#aws_metadataGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceAwsMetadata

The AWS metadata of a resource associated with an issue. Corresponds to the JSON property awsMetadata



8497
8498
8499
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8497

def 
  @aws_metadata
end

#azure_metadataGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceAzureMetadata

The Azure metadata of a resource associated with an issue. Corresponds to the JSON property azureMetadata



8502
8503
8504
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8502

def 
  @azure_metadata
end

#cloud_providerString

The cloud provider of the resource associated with the issue. Corresponds to the JSON property cloudProvider

Returns:

  • (String)


8507
8508
8509
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8507

def cloud_provider
  @cloud_provider
end

#display_nameString

The resource-type specific display name of the resource associated with the issue. Corresponds to the JSON property displayName

Returns:

  • (String)


8513
8514
8515
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8513

def display_name
  @display_name
end

#google_cloud_metadataGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceGoogleCloudMetadata

Google Cloud metadata of a resource associated with an issue. Corresponds to the JSON property googleCloudMetadata



8518
8519
8520
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8518

def 
  @google_cloud_metadata
end

#nameString

The full resource name of the resource associated with the issue. Corresponds to the JSON property name

Returns:

  • (String)


8523
8524
8525
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8523

def name
  @name
end

#typeString

The type of the resource associated with the issue. Corresponds to the JSON property type

Returns:

  • (String)


8528
8529
8530
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8528

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
8545
8546
8547
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8535

def update!(**args)
  @adc_application = args[:adc_application] if args.key?(:adc_application)
  @adc_application_template = args[:adc_application_template] if args.key?(:adc_application_template)
  @adc_shared_template = args[:adc_shared_template] if args.key?(:adc_shared_template)
  @application = args[:application] if args.key?(:application)
  @aws_metadata = args[:aws_metadata] if args.key?(:aws_metadata)
  @azure_metadata = args[:azure_metadata] if args.key?(:azure_metadata)
  @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider)
  @display_name = args[:display_name] if args.key?(:display_name)
  @google_cloud_metadata = args[:google_cloud_metadata] if args.key?(:google_cloud_metadata)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
end