Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResource
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
A resource associated with the an issue.
Instance Attribute Summary collapse
-
#adc_application ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceAdcApplication
Represents an ADC application associated with the finding.
-
#adc_application_template ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceAdcApplicationTemplateRevision
Represents an ADC template associated with the finding.
-
#adc_shared_template ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceAdcSharedTemplateRevision
Represents an ADC shared template associated with the finding.
-
#application ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceApplication
The AppHub application associated with the resource, if any.
-
#aws_metadata ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceAwsMetadata
The AWS metadata of a resource associated with an issue.
-
#azure_metadata ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceAzureMetadata
The Azure metadata of a resource associated with an issue.
-
#cloud_provider ⇒ String
The cloud provider of the resource associated with the issue.
-
#display_name ⇒ String
The resource-type specific display name of the resource associated with the issue.
-
#google_cloud_metadata ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceGoogleCloudMetadata
Google Cloud metadata of a resource associated with an issue.
-
#name ⇒ String
The full resource name of the resource associated with the issue.
-
#type ⇒ String
The type of the resource associated with the issue.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResource
constructor
A new instance of GoogleCloudSecuritycenterV2IssueResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResource
Returns a new instance of GoogleCloudSecuritycenterV2IssueResource.
8292 8293 8294 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8292 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adc_application ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceAdcApplication
Represents an ADC application associated with the finding.
Corresponds to the JSON property adcApplication
8239 8240 8241 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8239 def adc_application @adc_application end |
#adc_application_template ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceAdcApplicationTemplateRevision
Represents an ADC template associated with the finding.
Corresponds to the JSON property adcApplicationTemplate
8244 8245 8246 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8244 def adc_application_template @adc_application_template end |
#adc_shared_template ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceAdcSharedTemplateRevision
Represents an ADC shared template associated with the finding.
Corresponds to the JSON property adcSharedTemplate
8249 8250 8251 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8249 def adc_shared_template @adc_shared_template end |
#application ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceApplication
The AppHub application associated with the resource, if any.
Corresponds to the JSON property application
8254 8255 8256 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8254 def application @application end |
#aws_metadata ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceAwsMetadata
The AWS metadata of a resource associated with an issue.
Corresponds to the JSON property awsMetadata
8259 8260 8261 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8259 def @aws_metadata end |
#azure_metadata ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceAzureMetadata
The Azure metadata of a resource associated with an issue.
Corresponds to the JSON property azureMetadata
8264 8265 8266 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8264 def @azure_metadata end |
#cloud_provider ⇒ String
The cloud provider of the resource associated with the issue.
Corresponds to the JSON property cloudProvider
8269 8270 8271 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8269 def cloud_provider @cloud_provider end |
#display_name ⇒ String
The resource-type specific display name of the resource associated with the
issue.
Corresponds to the JSON property displayName
8275 8276 8277 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8275 def display_name @display_name end |
#google_cloud_metadata ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceGoogleCloudMetadata
Google Cloud metadata of a resource associated with an issue.
Corresponds to the JSON property googleCloudMetadata
8280 8281 8282 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8280 def @google_cloud_metadata end |
#name ⇒ String
The full resource name of the resource associated with the issue.
Corresponds to the JSON property name
8285 8286 8287 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8285 def name @name end |
#type ⇒ String
The type of the resource associated with the issue.
Corresponds to the JSON property type
8290 8291 8292 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8290 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8297 8298 8299 8300 8301 8302 8303 8304 8305 8306 8307 8308 8309 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8297 def update!(**args) @adc_application = args[:adc_application] if args.key?(:adc_application) @adc_application_template = args[:adc_application_template] if args.key?(:adc_application_template) @adc_shared_template = args[:adc_shared_template] if args.key?(:adc_shared_template) @application = args[:application] if args.key?(:application) @aws_metadata = args[:aws_metadata] if args.key?(:aws_metadata) @azure_metadata = args[:azure_metadata] if args.key?(:azure_metadata) @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider) @display_name = args[:display_name] if args.key?(:display_name) @google_cloud_metadata = args[:google_cloud_metadata] if args.key?(:google_cloud_metadata) @name = args[:name] if args.key?(:name) @type = args[:type] if args.key?(:type) end |