Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Consumer provided attributes for the application

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResourceApplicationAttributes

Returns a new instance of GoogleCloudSecuritycenterV2IssueResourceApplicationAttributes.



8435
8436
8437
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8435

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#business_ownersArray<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesContactInfo>

Business team that ensures user needs are met and value is delivered Corresponds to the JSON property businessOwners



8413
8414
8415
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8413

def business_owners
  @business_owners
end

#criticalityGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesCriticality

Criticality of the Application, Service, or Workload Corresponds to the JSON property criticality



8418
8419
8420
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8418

def criticality
  @criticality
end

#developer_ownersArray<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesContactInfo>

Developer team that owns development and coding. Corresponds to the JSON property developerOwners



8423
8424
8425
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8423

def developer_owners
  @developer_owners
end

#environmentGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesEnvironment

Environment of the Application, Service, or Workload Corresponds to the JSON property environment



8428
8429
8430
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8428

def environment
  @environment
end

#operator_ownersArray<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceApplicationAttributesContactInfo>

Operator team that ensures runtime and operations. Corresponds to the JSON property operatorOwners



8433
8434
8435
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8433

def operator_owners
  @operator_owners
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8440
8441
8442
8443
8444
8445
8446
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8440

def update!(**args)
  @business_owners = args[:business_owners] if args.key?(:business_owners)
  @criticality = args[:criticality] if args.key?(:criticality)
  @developer_owners = args[:developer_owners] if args.key?(:developer_owners)
  @environment = args[:environment] if args.key?(:environment)
  @operator_owners = args[:operator_owners] if args.key?(:operator_owners)
end