Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceAwsMetadataAwsAccount

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

The AWS account of the resource associated with the issue.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResourceAwsMetadataAwsAccount

Returns a new instance of GoogleCloudSecuritycenterV2IssueResourceAwsMetadataAwsAccount.



8539
8540
8541
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8539

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

The AWS account ID of the resource associated with the issue. Corresponds to the JSON property id

Returns:

  • (String)


8532
8533
8534
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8532

def id
  @id
end

#nameString

The AWS account name of the resource associated with the issue. Corresponds to the JSON property name

Returns:

  • (String)


8537
8538
8539
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8537

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8544
8545
8546
8547
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8544

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
end