Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2IssueResourceAzureMetadataAzureSubscription

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

The Azure subscription of the resource associated with the issue.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2IssueResourceAzureMetadataAzureSubscription

Returns a new instance of GoogleCloudSecuritycenterV2IssueResourceAzureMetadataAzureSubscription.



8583
8584
8585
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8583

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

The Azure subscription display name of the resource associated with the issue. Corresponds to the JSON property displayName

Returns:

  • (String)


8576
8577
8578
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8576

def display_name
  @display_name
end

#idString

The Azure subscription ID of the resource associated with the issue. Corresponds to the JSON property id

Returns:

  • (String)


8581
8582
8583
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8581

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8588
8589
8590
8591
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8588

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @id = args[:id] if args.key?(:id)
end