Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Job
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Job
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Describes a job
Instance Attribute Summary collapse
-
#error_code ⇒ Fixnum
Optional.
-
#location ⇒ String
Optional.
-
#name ⇒ String
The fully-qualified name for a job.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Job
constructor
A new instance of GoogleCloudSecuritycenterV2Job.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Job
Returns a new instance of GoogleCloudSecuritycenterV2Job.
8950 8951 8952 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8950 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_code ⇒ Fixnum
Optional. If the job did not complete successfully, this field describes why.
Corresponds to the JSON property errorCode
8933 8934 8935 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8933 def error_code @error_code end |
#location ⇒ String
Optional. Gives the location where the job ran, such as US or europe-west1
Corresponds to the JSON property location
8938 8939 8940 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8938 def location @location end |
#name ⇒ String
The fully-qualified name for a job. e.g. projects//jobs/
Corresponds to the JSON property name
8943 8944 8945 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8943 def name @name end |
#state ⇒ String
Output only. State of the job, such as RUNNING or PENDING.
Corresponds to the JSON property state
8948 8949 8950 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8948 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8955 8956 8957 8958 8959 8960 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8955 def update!(**args) @error_code = args[:error_code] if args.key?(:error_code) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) end |