Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Job
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Job
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Describes a job
Instance Attribute Summary collapse
-
#error_code ⇒ Fixnum
Optional.
-
#location ⇒ String
Optional.
-
#name ⇒ String
The fully-qualified name for a job.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Job
constructor
A new instance of GoogleCloudSecuritycenterV2Job.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Job
Returns a new instance of GoogleCloudSecuritycenterV2Job.
8712 8713 8714 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8712 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_code ⇒ Fixnum
Optional. If the job did not complete successfully, this field describes why.
Corresponds to the JSON property errorCode
8695 8696 8697 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8695 def error_code @error_code end |
#location ⇒ String
Optional. Gives the location where the job ran, such as US or europe-west1
Corresponds to the JSON property location
8700 8701 8702 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8700 def location @location end |
#name ⇒ String
The fully-qualified name for a job. e.g. projects//jobs/
Corresponds to the JSON property name
8705 8706 8707 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8705 def name @name end |
#state ⇒ String
Output only. State of the job, such as RUNNING or PENDING.
Corresponds to the JSON property state
8710 8711 8712 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8710 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8717 8718 8719 8720 8721 8722 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8717 def update!(**args) @error_code = args[:error_code] if args.key?(:error_code) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) end |