Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2KernelRootkit

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Kernel mode rootkit signatures.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2KernelRootkit

Returns a new instance of GoogleCloudSecuritycenterV2KernelRootkit.



9026
9027
9028
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9026

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Rootkit name, when available. Corresponds to the JSON property name

Returns:

  • (String)


8970
8971
8972
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8970

def name
  @name
end

#unexpected_code_modificationBoolean Also known as: unexpected_code_modification?

True if unexpected modifications of kernel code memory are present. Corresponds to the JSON property unexpectedCodeModification

Returns:

  • (Boolean)


8975
8976
8977
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8975

def unexpected_code_modification
  @unexpected_code_modification
end

#unexpected_ftrace_handlerBoolean Also known as: unexpected_ftrace_handler?

True if ftrace points are present with callbacks pointing to regions that are not in the expected kernel or module code range. Corresponds to the JSON property unexpectedFtraceHandler

Returns:

  • (Boolean)


8982
8983
8984
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8982

def unexpected_ftrace_handler
  @unexpected_ftrace_handler
end

#unexpected_interrupt_handlerBoolean Also known as: unexpected_interrupt_handler?

True if interrupt handlers that are are not in the expected kernel or module code regions are present. Corresponds to the JSON property unexpectedInterruptHandler

Returns:

  • (Boolean)


8989
8990
8991
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8989

def unexpected_interrupt_handler
  @unexpected_interrupt_handler
end

#unexpected_kernel_code_pagesBoolean Also known as: unexpected_kernel_code_pages?

True if kernel code pages that are not in the expected kernel or module code regions are present. Corresponds to the JSON property unexpectedKernelCodePages

Returns:

  • (Boolean)


8996
8997
8998
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8996

def unexpected_kernel_code_pages
  @unexpected_kernel_code_pages
end

#unexpected_kprobe_handlerBoolean Also known as: unexpected_kprobe_handler?

True if kprobe points are present with callbacks pointing to regions that are not in the expected kernel or module code range. Corresponds to the JSON property unexpectedKprobeHandler

Returns:

  • (Boolean)


9003
9004
9005
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9003

def unexpected_kprobe_handler
  @unexpected_kprobe_handler
end

#unexpected_processes_in_runqueueBoolean Also known as: unexpected_processes_in_runqueue?

True if unexpected processes in the scheduler run queue are present. Such processes are in the run queue, but not in the process task list. Corresponds to the JSON property unexpectedProcessesInRunqueue

Returns:

  • (Boolean)


9010
9011
9012
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9010

def unexpected_processes_in_runqueue
  @unexpected_processes_in_runqueue
end

#unexpected_read_only_data_modificationBoolean Also known as: unexpected_read_only_data_modification?

True if unexpected modifications of kernel read-only data memory are present. Corresponds to the JSON property unexpectedReadOnlyDataModification

Returns:

  • (Boolean)


9016
9017
9018
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9016

def unexpected_read_only_data_modification
  @unexpected_read_only_data_modification
end

#unexpected_system_call_handlerBoolean Also known as: unexpected_system_call_handler?

True if system call handlers that are are not in the expected kernel or module code regions are present. Corresponds to the JSON property unexpectedSystemCallHandler

Returns:

  • (Boolean)


9023
9024
9025
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9023

def unexpected_system_call_handler
  @unexpected_system_call_handler
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9031
9032
9033
9034
9035
9036
9037
9038
9039
9040
9041
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9031

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @unexpected_code_modification = args[:unexpected_code_modification] if args.key?(:unexpected_code_modification)
  @unexpected_ftrace_handler = args[:unexpected_ftrace_handler] if args.key?(:unexpected_ftrace_handler)
  @unexpected_interrupt_handler = args[:unexpected_interrupt_handler] if args.key?(:unexpected_interrupt_handler)
  @unexpected_kernel_code_pages = args[:unexpected_kernel_code_pages] if args.key?(:unexpected_kernel_code_pages)
  @unexpected_kprobe_handler = args[:unexpected_kprobe_handler] if args.key?(:unexpected_kprobe_handler)
  @unexpected_processes_in_runqueue = args[:unexpected_processes_in_runqueue] if args.key?(:unexpected_processes_in_runqueue)
  @unexpected_read_only_data_modification = args[:unexpected_read_only_data_modification] if args.key?(:unexpected_read_only_data_modification)
  @unexpected_system_call_handler = args[:unexpected_system_call_handler] if args.key?(:unexpected_system_call_handler)
end