Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2KernelRootkit

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Kernel mode rootkit signatures.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2KernelRootkit

Returns a new instance of GoogleCloudSecuritycenterV2KernelRootkit.



8788
8789
8790
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8788

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Rootkit name, when available. Corresponds to the JSON property name

Returns:

  • (String)


8732
8733
8734
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8732

def name
  @name
end

#unexpected_code_modificationBoolean Also known as: unexpected_code_modification?

True if unexpected modifications of kernel code memory are present. Corresponds to the JSON property unexpectedCodeModification

Returns:

  • (Boolean)


8737
8738
8739
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8737

def unexpected_code_modification
  @unexpected_code_modification
end

#unexpected_ftrace_handlerBoolean Also known as: unexpected_ftrace_handler?

True if ftrace points are present with callbacks pointing to regions that are not in the expected kernel or module code range. Corresponds to the JSON property unexpectedFtraceHandler

Returns:

  • (Boolean)


8744
8745
8746
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8744

def unexpected_ftrace_handler
  @unexpected_ftrace_handler
end

#unexpected_interrupt_handlerBoolean Also known as: unexpected_interrupt_handler?

True if interrupt handlers that are are not in the expected kernel or module code regions are present. Corresponds to the JSON property unexpectedInterruptHandler

Returns:

  • (Boolean)


8751
8752
8753
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8751

def unexpected_interrupt_handler
  @unexpected_interrupt_handler
end

#unexpected_kernel_code_pagesBoolean Also known as: unexpected_kernel_code_pages?

True if kernel code pages that are not in the expected kernel or module code regions are present. Corresponds to the JSON property unexpectedKernelCodePages

Returns:

  • (Boolean)


8758
8759
8760
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8758

def unexpected_kernel_code_pages
  @unexpected_kernel_code_pages
end

#unexpected_kprobe_handlerBoolean Also known as: unexpected_kprobe_handler?

True if kprobe points are present with callbacks pointing to regions that are not in the expected kernel or module code range. Corresponds to the JSON property unexpectedKprobeHandler

Returns:

  • (Boolean)


8765
8766
8767
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8765

def unexpected_kprobe_handler
  @unexpected_kprobe_handler
end

#unexpected_processes_in_runqueueBoolean Also known as: unexpected_processes_in_runqueue?

True if unexpected processes in the scheduler run queue are present. Such processes are in the run queue, but not in the process task list. Corresponds to the JSON property unexpectedProcessesInRunqueue

Returns:

  • (Boolean)


8772
8773
8774
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8772

def unexpected_processes_in_runqueue
  @unexpected_processes_in_runqueue
end

#unexpected_read_only_data_modificationBoolean Also known as: unexpected_read_only_data_modification?

True if unexpected modifications of kernel read-only data memory are present. Corresponds to the JSON property unexpectedReadOnlyDataModification

Returns:

  • (Boolean)


8778
8779
8780
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8778

def unexpected_read_only_data_modification
  @unexpected_read_only_data_modification
end

#unexpected_system_call_handlerBoolean Also known as: unexpected_system_call_handler?

True if system call handlers that are are not in the expected kernel or module code regions are present. Corresponds to the JSON property unexpectedSystemCallHandler

Returns:

  • (Boolean)


8785
8786
8787
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8785

def unexpected_system_call_handler
  @unexpected_system_call_handler
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8793
8794
8795
8796
8797
8798
8799
8800
8801
8802
8803
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 8793

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @unexpected_code_modification = args[:unexpected_code_modification] if args.key?(:unexpected_code_modification)
  @unexpected_ftrace_handler = args[:unexpected_ftrace_handler] if args.key?(:unexpected_ftrace_handler)
  @unexpected_interrupt_handler = args[:unexpected_interrupt_handler] if args.key?(:unexpected_interrupt_handler)
  @unexpected_kernel_code_pages = args[:unexpected_kernel_code_pages] if args.key?(:unexpected_kernel_code_pages)
  @unexpected_kprobe_handler = args[:unexpected_kprobe_handler] if args.key?(:unexpected_kprobe_handler)
  @unexpected_processes_in_runqueue = args[:unexpected_processes_in_runqueue] if args.key?(:unexpected_processes_in_runqueue)
  @unexpected_read_only_data_modification = args[:unexpected_read_only_data_modification] if args.key?(:unexpected_read_only_data_modification)
  @unexpected_system_call_handler = args[:unexpected_system_call_handler] if args.key?(:unexpected_system_call_handler)
end