Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2MuteConfig
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2MuteConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
A mute config is a Cloud SCC resource that contains the configuration to mute create/update events of findings.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#crypto_key_name ⇒ String
Output only.
-
#description ⇒ String
A description of the mute config.
-
#expiry_time ⇒ String
Optional.
-
#filter ⇒ String
Required.
-
#most_recent_editor ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#type ⇒ String
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2MuteConfig
constructor
A new instance of GoogleCloudSecuritycenterV2MuteConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2MuteConfig
Returns a new instance of GoogleCloudSecuritycenterV2MuteConfig.
9326 9327 9328 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9326 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which the mute config was created. This field is set
by the server and will be ignored if provided on config creation.
Corresponds to the JSON property createTime
9261 9262 9263 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9261 def create_time @create_time end |
#crypto_key_name ⇒ String
Output only. The resource name of the Cloud KMS CryptoKey used to encrypt
this configuration data, if CMEK was enabled during Security Command Center
activation.
Corresponds to the JSON property cryptoKeyName
9268 9269 9270 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9268 def crypto_key_name @crypto_key_name end |
#description ⇒ String
A description of the mute config.
Corresponds to the JSON property description
9273 9274 9275 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9273 def description @description end |
#expiry_time ⇒ String
Optional. The expiry of the mute config. Only applicable for dynamic configs.
If the expiry is set, when the config expires, it is removed from all findings.
Corresponds to the JSON property expiryTime
9279 9280 9281 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9279 def expiry_time @expiry_time end |
#filter ⇒ String
Required. An expression that defines the filter to apply across create/update
events of findings. While creating a filter string, be mindful of the scope in
which the mute configuration is being created. E.g., If a filter contains
project = X but is created under the project = Y scope, it might not match any
findings. The following field and operator combinations are supported: *
severity: =, : * category: =, : * resource.name: =, : * resource.
project_name: =, : * resource.project_display_name: =, : * resource.
folders.resource_folder: =, : * resource.parent_name: =, : * resource.
parent_display_name: =, : * resource.type: =, : * finding_class: =,
: * indicator.ip_addresses: =, : * indicator.domains: =, :
Corresponds to the JSON property filter
9293 9294 9295 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9293 def filter @filter end |
#most_recent_editor ⇒ String
Output only. Email address of the user who last edited the mute config. This
field is set by the server and will be ignored if provided on config creation
or update.
Corresponds to the JSON property mostRecentEditor
9300 9301 9302 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9300 def most_recent_editor @most_recent_editor end |
#name ⇒ String
Identifier. This field will be ignored if provided on config creation. The
following list shows some examples of the format: + organizations/
organization/muteConfigs/mute_config+ `organizations/`organization`
locations/`location`//muteConfigs/`mute_config + folders/folder/
muteConfigs/mute_config+ `folders/`folder`/locations/`location`/
muteConfigs/`mute_config + projects/project/muteConfigs/mute_config+ `
projects/`project`/locations/`location`/muteConfigs/`mute_config
Corresponds to the JSON property name
9311 9312 9313 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9311 def name @name end |
#type ⇒ String
Required. The type of the mute config, which determines what type of mute
state the config affects. Immutable after creation.
Corresponds to the JSON property type
9317 9318 9319 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9317 def type @type end |
#update_time ⇒ String
Output only. The most recent time at which the mute config was updated. This
field is set by the server and will be ignored if provided on config creation
or update.
Corresponds to the JSON property updateTime
9324 9325 9326 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9324 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9331 9332 9333 9334 9335 9336 9337 9338 9339 9340 9341 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9331 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @crypto_key_name = args[:crypto_key_name] if args.key?(:crypto_key_name) @description = args[:description] if args.key?(:description) @expiry_time = args[:expiry_time] if args.key?(:expiry_time) @filter = args[:filter] if args.key?(:filter) @most_recent_editor = args[:most_recent_editor] if args.key?(:most_recent_editor) @name = args[:name] if args.key?(:name) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) end |