Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Notebook
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Notebook
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Represents a Jupyter notebook IPYNB file, such as a Colab Enterprise notebook file, that is associated with a finding.
Instance Attribute Summary collapse
-
#last_author ⇒ String
The user ID of the latest author to modify the notebook.
-
#name ⇒ String
The name of the notebook.
-
#notebook_update_time ⇒ String
The most recent time the notebook was updated.
-
#service ⇒ String
The source notebook service, for example, "Colab Enterprise".
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Notebook
constructor
A new instance of GoogleCloudSecuritycenterV2Notebook.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Notebook
Returns a new instance of GoogleCloudSecuritycenterV2Notebook.
9225 9226 9227 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9225 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_author ⇒ String
The user ID of the latest author to modify the notebook.
Corresponds to the JSON property lastAuthor
9208 9209 9210 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9208 def @last_author end |
#name ⇒ String
The name of the notebook.
Corresponds to the JSON property name
9213 9214 9215 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9213 def name @name end |
#notebook_update_time ⇒ String
The most recent time the notebook was updated.
Corresponds to the JSON property notebookUpdateTime
9218 9219 9220 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9218 def notebook_update_time @notebook_update_time end |
#service ⇒ String
The source notebook service, for example, "Colab Enterprise".
Corresponds to the JSON property service
9223 9224 9225 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9223 def service @service end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9230 9231 9232 9233 9234 9235 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9230 def update!(**args) @last_author = args[:last_author] if args.key?(:last_author) @name = args[:name] if args.key?(:name) @notebook_update_time = args[:notebook_update_time] if args.key?(:notebook_update_time) @service = args[:service] if args.key?(:service) end |