Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Object
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Object
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Kubernetes object related to the finding, uniquely identified by GKNN. Used if the object Kind is not one of Pod, Node, NodePool, Binding, or AccessReview.
Instance Attribute Summary collapse
-
#containers ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Container>
Pod containers associated with this finding, if any.
-
#group ⇒ String
Kubernetes object group, such as "policy.k8s.io/v1".
-
#kind ⇒ String
Kubernetes object kind, such as "Namespace".
-
#name ⇒ String
Kubernetes object name.
-
#ns ⇒ String
Kubernetes object namespace.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Object
constructor
A new instance of GoogleCloudSecuritycenterV2Object.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Object
Returns a new instance of GoogleCloudSecuritycenterV2Object.
9544 9545 9546 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9544 def initialize(**args) update!(**args) end |
Instance Attribute Details
#containers ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Container>
Pod containers associated with this finding, if any.
Corresponds to the JSON property containers
9519 9520 9521 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9519 def containers @containers end |
#group ⇒ String
Kubernetes object group, such as "policy.k8s.io/v1".
Corresponds to the JSON property group
9524 9525 9526 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9524 def group @group end |
#kind ⇒ String
Kubernetes object kind, such as "Namespace".
Corresponds to the JSON property kind
9529 9530 9531 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9529 def kind @kind end |
#name ⇒ String
Kubernetes object name. For details see https://kubernetes.io/docs/concepts/
overview/working-with-objects/names/.
Corresponds to the JSON property name
9535 9536 9537 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9535 def name @name end |
#ns ⇒ String
Kubernetes object namespace. Must be a valid DNS label. Named "ns" to avoid
collision with C++ namespace keyword. For details see https://kubernetes.io/
docs/tasks/administer-cluster/namespaces/.
Corresponds to the JSON property ns
9542 9543 9544 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9542 def ns @ns end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9549 9550 9551 9552 9553 9554 9555 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9549 def update!(**args) @containers = args[:containers] if args.key?(:containers) @group = args[:group] if args.key?(:group) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @ns = args[:ns] if args.key?(:ns) end |