Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Object

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Kubernetes object related to the finding, uniquely identified by GKNN. Used if the object Kind is not one of Pod, Node, NodePool, Binding, or AccessReview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Object

Returns a new instance of GoogleCloudSecuritycenterV2Object.



9306
9307
9308
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9306

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#containersArray<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Container>

Pod containers associated with this finding, if any. Corresponds to the JSON property containers



9281
9282
9283
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9281

def containers
  @containers
end

#groupString

Kubernetes object group, such as "policy.k8s.io/v1". Corresponds to the JSON property group

Returns:

  • (String)


9286
9287
9288
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9286

def group
  @group
end

#kindString

Kubernetes object kind, such as "Namespace". Corresponds to the JSON property kind

Returns:

  • (String)


9291
9292
9293
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9291

def kind
  @kind
end

#nameString

Kubernetes object name. For details see https://kubernetes.io/docs/concepts/ overview/working-with-objects/names/. Corresponds to the JSON property name

Returns:

  • (String)


9297
9298
9299
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9297

def name
  @name
end

#nsString

Kubernetes object namespace. Must be a valid DNS label. Named "ns" to avoid collision with C++ namespace keyword. For details see https://kubernetes.io/ docs/tasks/administer-cluster/namespaces/. Corresponds to the JSON property ns

Returns:

  • (String)


9304
9305
9306
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9304

def ns
  @ns
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9311
9312
9313
9314
9315
9316
9317
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9311

def update!(**args)
  @containers = args[:containers] if args.key?(:containers)
  @group = args[:group] if args.key?(:group)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @ns = args[:ns] if args.key?(:ns)
end