Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Process
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Process
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Represents an operating system process.
Instance Attribute Summary collapse
-
#args ⇒ Array<String>
Process arguments as JSON encoded strings.
-
#arguments_truncated ⇒ Boolean
(also: #arguments_truncated?)
True if
argsis incomplete. -
#binary ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2File
File information about the related binary/library used by an executable, or the script used by a script interpreter Corresponds to the JSON property
binary. -
#env_variables ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2EnvironmentVariable>
Process environment variables.
-
#env_variables_truncated ⇒ Boolean
(also: #env_variables_truncated?)
True if
env_variablesis incomplete. -
#libraries ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2File>
File information for libraries loaded by the process.
-
#name ⇒ String
The process name, as displayed in utilities like
topandps. -
#parent_pid ⇒ Fixnum
The parent process ID.
-
#pid ⇒ Fixnum
The process ID.
-
#script ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2File
File information about the related binary/library used by an executable, or the script used by a script interpreter Corresponds to the JSON property
script. -
#user_id ⇒ Fixnum
The ID of the user that executed the process.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Process
constructor
A new instance of GoogleCloudSecuritycenterV2Process.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Process
Returns a new instance of GoogleCloudSecuritycenterV2Process.
9848 9849 9850 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9848 def initialize(**args) update!(**args) end |
Instance Attribute Details
#args ⇒ Array<String>
Process arguments as JSON encoded strings.
Corresponds to the JSON property args
9790 9791 9792 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9790 def args @args end |
#arguments_truncated ⇒ Boolean Also known as: arguments_truncated?
True if args is incomplete.
Corresponds to the JSON property argumentsTruncated
9795 9796 9797 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9795 def arguments_truncated @arguments_truncated end |
#binary ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2File
File information about the related binary/library used by an executable, or
the script used by a script interpreter
Corresponds to the JSON property binary
9802 9803 9804 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9802 def binary @binary end |
#env_variables ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2EnvironmentVariable>
Process environment variables.
Corresponds to the JSON property envVariables
9807 9808 9809 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9807 def env_variables @env_variables end |
#env_variables_truncated ⇒ Boolean Also known as: env_variables_truncated?
True if env_variables is incomplete.
Corresponds to the JSON property envVariablesTruncated
9812 9813 9814 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9812 def env_variables_truncated @env_variables_truncated end |
#libraries ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2File>
File information for libraries loaded by the process.
Corresponds to the JSON property libraries
9818 9819 9820 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9818 def libraries @libraries end |
#name ⇒ String
The process name, as displayed in utilities like top and ps. This name can
be accessed through /proc/[pid]/comm and changed with prctl(PR_SET_NAME).
Corresponds to the JSON property name
9824 9825 9826 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9824 def name @name end |
#parent_pid ⇒ Fixnum
The parent process ID.
Corresponds to the JSON property parentPid
9829 9830 9831 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9829 def parent_pid @parent_pid end |
#pid ⇒ Fixnum
The process ID.
Corresponds to the JSON property pid
9834 9835 9836 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9834 def pid @pid end |
#script ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2File
File information about the related binary/library used by an executable, or
the script used by a script interpreter
Corresponds to the JSON property script
9840 9841 9842 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9840 def script @script end |
#user_id ⇒ Fixnum
The ID of the user that executed the process. E.g. If this is the root user
this will always be 0.
Corresponds to the JSON property userId
9846 9847 9848 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9846 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9853 9854 9855 9856 9857 9858 9859 9860 9861 9862 9863 9864 9865 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9853 def update!(**args) @args = args[:args] if args.key?(:args) @arguments_truncated = args[:arguments_truncated] if args.key?(:arguments_truncated) @binary = args[:binary] if args.key?(:binary) @env_variables = args[:env_variables] if args.key?(:env_variables) @env_variables_truncated = args[:env_variables_truncated] if args.key?(:env_variables_truncated) @libraries = args[:libraries] if args.key?(:libraries) @name = args[:name] if args.key?(:name) @parent_pid = args[:parent_pid] if args.key?(:parent_pid) @pid = args[:pid] if args.key?(:pid) @script = args[:script] if args.key?(:script) @user_id = args[:user_id] if args.key?(:user_id) end |