Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Requests

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Information about the requests relevant to the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Requests

Returns a new instance of GoogleCloudSecuritycenterV2Requests.



9951
9952
9953
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9951

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#long_term_allowedFixnum

Allowed RPS (requests per second) over the long term. Corresponds to the JSON property longTermAllowed

Returns:

  • (Fixnum)


9932
9933
9934
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9932

def long_term_allowed
  @long_term_allowed
end

#long_term_deniedFixnum

Denied RPS (requests per second) over the long term. Corresponds to the JSON property longTermDenied

Returns:

  • (Fixnum)


9937
9938
9939
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9937

def long_term_denied
  @long_term_denied
end

#ratioFloat

For 'Increasing deny ratio', the ratio is the denied traffic divided by the allowed traffic. For 'Allowed traffic spike', the ratio is the allowed traffic in the short term divided by allowed traffic in the long term. Corresponds to the JSON property ratio

Returns:

  • (Float)


9944
9945
9946
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9944

def ratio
  @ratio
end

#short_term_allowedFixnum

Allowed RPS (requests per second) in the short term. Corresponds to the JSON property shortTermAllowed

Returns:

  • (Fixnum)


9949
9950
9951
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9949

def short_term_allowed
  @short_term_allowed
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9956
9957
9958
9959
9960
9961
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9956

def update!(**args)
  @long_term_allowed = args[:long_term_allowed] if args.key?(:long_term_allowed)
  @long_term_denied = args[:long_term_denied] if args.key?(:long_term_denied)
  @ratio = args[:ratio] if args.key?(:ratio)
  @short_term_allowed = args[:short_term_allowed] if args.key?(:short_term_allowed)
end