Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Requests
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Requests
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Information about the requests relevant to the finding.
Instance Attribute Summary collapse
-
#long_term_allowed ⇒ Fixnum
Allowed RPS (requests per second) over the long term.
-
#long_term_denied ⇒ Fixnum
Denied RPS (requests per second) over the long term.
-
#ratio ⇒ Float
For 'Increasing deny ratio', the ratio is the denied traffic divided by the allowed traffic.
-
#short_term_allowed ⇒ Fixnum
Allowed RPS (requests per second) in the short term.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Requests
constructor
A new instance of GoogleCloudSecuritycenterV2Requests.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Requests
Returns a new instance of GoogleCloudSecuritycenterV2Requests.
9670 9671 9672 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9670 def initialize(**args) update!(**args) end |
Instance Attribute Details
#long_term_allowed ⇒ Fixnum
Allowed RPS (requests per second) over the long term.
Corresponds to the JSON property longTermAllowed
9651 9652 9653 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9651 def long_term_allowed @long_term_allowed end |
#long_term_denied ⇒ Fixnum
Denied RPS (requests per second) over the long term.
Corresponds to the JSON property longTermDenied
9656 9657 9658 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9656 def long_term_denied @long_term_denied end |
#ratio ⇒ Float
For 'Increasing deny ratio', the ratio is the denied traffic divided by the
allowed traffic. For 'Allowed traffic spike', the ratio is the allowed traffic
in the short term divided by allowed traffic in the long term.
Corresponds to the JSON property ratio
9663 9664 9665 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9663 def ratio @ratio end |
#short_term_allowed ⇒ Fixnum
Allowed RPS (requests per second) in the short term.
Corresponds to the JSON property shortTermAllowed
9668 9669 9670 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9668 def short_term_allowed @short_term_allowed end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9675 9676 9677 9678 9679 9680 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9675 def update!(**args) @long_term_allowed = args[:long_term_allowed] if args.key?(:long_term_allowed) @long_term_denied = args[:long_term_denied] if args.key?(:long_term_denied) @ratio = args[:ratio] if args.key?(:ratio) @short_term_allowed = args[:short_term_allowed] if args.key?(:short_term_allowed) end |