Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Resource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Information related to the Google Cloud resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Resource

Returns a new instance of GoogleCloudSecuritycenterV2Resource.



10056
10057
10058
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10056

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adc_applicationGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2AdcApplication

Represents an ADC application associated with the finding. Corresponds to the JSON property adcApplication



9971
9972
9973
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9971

def adc_application
  @adc_application
end

#adc_application_templateGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2AdcApplicationTemplateRevision

Represents an ADC template associated with the finding. Corresponds to the JSON property adcApplicationTemplate



9976
9977
9978
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9976

def adc_application_template
  @adc_application_template
end

#adc_shared_templateGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2AdcSharedTemplateRevision

Represents an ADC shared template associated with the finding. Corresponds to the JSON property adcSharedTemplate



9981
9982
9983
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9981

def adc_shared_template
  @adc_shared_template
end

#applicationGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2ResourceApplication

The App Hub Application associated with the finding's resource. Corresponds to the JSON property application



9986
9987
9988
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9986

def application
  @application
end

#aws_metadataGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2AwsMetadata

AWS metadata associated with the resource, only applicable if the finding's cloud provider is Amazon Web Services. Corresponds to the JSON property awsMetadata



9992
9993
9994
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9992

def 
  @aws_metadata
end

#azure_metadataGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2AzureMetadata

Azure metadata associated with the resource, only applicable if the finding's cloud provider is Microsoft Azure. Corresponds to the JSON property azureMetadata



9998
9999
10000
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9998

def 
  @azure_metadata
end

#cloud_providerString

Indicates which cloud provider the finding is from. Corresponds to the JSON property cloudProvider

Returns:

  • (String)


10003
10004
10005
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10003

def cloud_provider
  @cloud_provider
end

#display_nameString

The human readable name of the resource. Corresponds to the JSON property displayName

Returns:

  • (String)


10008
10009
10010
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10008

def display_name
  @display_name
end

#gcp_metadataGoogle::Apis::SecuritycenterV1beta1::GcpMetadata

Google Cloud metadata associated with the resource. Only applicable if the finding's cloud provider is Google Cloud. Corresponds to the JSON property gcpMetadata



10014
10015
10016
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10014

def 
  @gcp_metadata
end

#locationString

The region or location of the service (if applicable). Corresponds to the JSON property location

Returns:

  • (String)


10019
10020
10021
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10019

def location
  @location
end

#nameString

The full resource name of the resource. See: https://cloud.google.com/apis/ design/resource_names#full_resource_name Corresponds to the JSON property name

Returns:

  • (String)


10025
10026
10027
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10025

def name
  @name
end

#resource_pathGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2ResourcePath

Represents the path of resources leading up to the resource this finding is about. Corresponds to the JSON property resourcePath



10031
10032
10033
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10031

def resource_path
  @resource_path
end

#resource_path_stringString

A string representation of the resource path. For Google Cloud, it has the format of organizations/organization_id/folders/folder_id/folders/ folder_id/projects/project_idwhere there can be any number of folders. For AWS, it has the format of `org/`organization_id`/ou/` organizational_unit_id`/ou/`organizational_unit_id`/account/`account_id where there can be any number of organizational units. For Azure, it has the format of mg/management_group_id/mg/management_group_id/subscription/ subscription_id/rg/resource_group_name`where there can be any number of management groups. Corresponds to the JSON propertyresourcePathString`

Returns:

  • (String)


10044
10045
10046
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10044

def resource_path_string
  @resource_path_string
end

#serviceString

The service or resource provider associated with the resource. Corresponds to the JSON property service

Returns:

  • (String)


10049
10050
10051
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10049

def service
  @service
end

#typeString

The full resource type of the resource. Corresponds to the JSON property type

Returns:

  • (String)


10054
10055
10056
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10054

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10061
10062
10063
10064
10065
10066
10067
10068
10069
10070
10071
10072
10073
10074
10075
10076
10077
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10061

def update!(**args)
  @adc_application = args[:adc_application] if args.key?(:adc_application)
  @adc_application_template = args[:adc_application_template] if args.key?(:adc_application_template)
  @adc_shared_template = args[:adc_shared_template] if args.key?(:adc_shared_template)
  @application = args[:application] if args.key?(:application)
  @aws_metadata = args[:aws_metadata] if args.key?(:aws_metadata)
  @azure_metadata = args[:azure_metadata] if args.key?(:azure_metadata)
  @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider)
  @display_name = args[:display_name] if args.key?(:display_name)
  @gcp_metadata = args[:gcp_metadata] if args.key?(:gcp_metadata)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @resource_path = args[:resource_path] if args.key?(:resource_path)
  @resource_path_string = args[:resource_path_string] if args.key?(:resource_path_string)
  @service = args[:service] if args.key?(:service)
  @type = args[:type] if args.key?(:type)
end