Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2Resource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Information related to the Google Cloud resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2Resource

Returns a new instance of GoogleCloudSecuritycenterV2Resource.



9775
9776
9777
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9775

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adc_applicationGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2AdcApplication

Represents an ADC application associated with the finding. Corresponds to the JSON property adcApplication



9690
9691
9692
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9690

def adc_application
  @adc_application
end

#adc_application_templateGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2AdcApplicationTemplateRevision

Represents an ADC template associated with the finding. Corresponds to the JSON property adcApplicationTemplate



9695
9696
9697
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9695

def adc_application_template
  @adc_application_template
end

#adc_shared_templateGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2AdcSharedTemplateRevision

Represents an ADC shared template associated with the finding. Corresponds to the JSON property adcSharedTemplate



9700
9701
9702
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9700

def adc_shared_template
  @adc_shared_template
end

#applicationGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2ResourceApplication

The App Hub Application associated with the finding's resource. Corresponds to the JSON property application



9705
9706
9707
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9705

def application
  @application
end

#aws_metadataGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2AwsMetadata

AWS metadata associated with the resource, only applicable if the finding's cloud provider is Amazon Web Services. Corresponds to the JSON property awsMetadata



9711
9712
9713
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9711

def 
  @aws_metadata
end

#azure_metadataGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2AzureMetadata

Azure metadata associated with the resource, only applicable if the finding's cloud provider is Microsoft Azure. Corresponds to the JSON property azureMetadata



9717
9718
9719
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9717

def 
  @azure_metadata
end

#cloud_providerString

Indicates which cloud provider the finding is from. Corresponds to the JSON property cloudProvider

Returns:

  • (String)


9722
9723
9724
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9722

def cloud_provider
  @cloud_provider
end

#display_nameString

The human readable name of the resource. Corresponds to the JSON property displayName

Returns:

  • (String)


9727
9728
9729
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9727

def display_name
  @display_name
end

#gcp_metadataGoogle::Apis::SecuritycenterV1beta1::GcpMetadata

Google Cloud metadata associated with the resource. Only applicable if the finding's cloud provider is Google Cloud. Corresponds to the JSON property gcpMetadata



9733
9734
9735
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9733

def 
  @gcp_metadata
end

#locationString

The region or location of the service (if applicable). Corresponds to the JSON property location

Returns:

  • (String)


9738
9739
9740
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9738

def location
  @location
end

#nameString

The full resource name of the resource. See: https://cloud.google.com/apis/ design/resource_names#full_resource_name Corresponds to the JSON property name

Returns:

  • (String)


9744
9745
9746
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9744

def name
  @name
end

#resource_pathGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2ResourcePath

Represents the path of resources leading up to the resource this finding is about. Corresponds to the JSON property resourcePath



9750
9751
9752
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9750

def resource_path
  @resource_path
end

#resource_path_stringString

A string representation of the resource path. For Google Cloud, it has the format of organizations/organization_id/folders/folder_id/folders/ folder_id/projects/project_idwhere there can be any number of folders. For AWS, it has the format of `org/`organization_id`/ou/` organizational_unit_id`/ou/`organizational_unit_id`/account/`account_id where there can be any number of organizational units. For Azure, it has the format of mg/management_group_id/mg/management_group_id/subscription/ subscription_id/rg/resource_group_name`where there can be any number of management groups. Corresponds to the JSON propertyresourcePathString`

Returns:

  • (String)


9763
9764
9765
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9763

def resource_path_string
  @resource_path_string
end

#serviceString

The service or resource provider associated with the resource. Corresponds to the JSON property service

Returns:

  • (String)


9768
9769
9770
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9768

def service
  @service
end

#typeString

The full resource type of the resource. Corresponds to the JSON property type

Returns:

  • (String)


9773
9774
9775
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9773

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9780
9781
9782
9783
9784
9785
9786
9787
9788
9789
9790
9791
9792
9793
9794
9795
9796
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9780

def update!(**args)
  @adc_application = args[:adc_application] if args.key?(:adc_application)
  @adc_application_template = args[:adc_application_template] if args.key?(:adc_application_template)
  @adc_shared_template = args[:adc_shared_template] if args.key?(:adc_shared_template)
  @application = args[:application] if args.key?(:application)
  @aws_metadata = args[:aws_metadata] if args.key?(:aws_metadata)
  @azure_metadata = args[:azure_metadata] if args.key?(:azure_metadata)
  @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider)
  @display_name = args[:display_name] if args.key?(:display_name)
  @gcp_metadata = args[:gcp_metadata] if args.key?(:gcp_metadata)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @resource_path = args[:resource_path] if args.key?(:resource_path)
  @resource_path_string = args[:resource_path_string] if args.key?(:resource_path_string)
  @service = args[:service] if args.key?(:service)
  @type = args[:type] if args.key?(:type)
end