Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2ResourceApplicationAttributes
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2ResourceApplicationAttributes
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Consumer provided attributes for the application
Instance Attribute Summary collapse
-
#business_owners ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesContactInfo>
Business team that ensures user needs are met and value is delivered Corresponds to the JSON property
businessOwners. -
#criticality ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesCriticality
Criticality of the Application, Service, or Workload Corresponds to the JSON property
criticality. -
#developer_owners ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesContactInfo>
Developer team that owns development and coding.
-
#environment ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesEnvironment
Environment of the Application, Service, or Workload Corresponds to the JSON property
environment. -
#operator_owners ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesContactInfo>
Operator team that ensures runtime and operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ResourceApplicationAttributes
constructor
A new instance of GoogleCloudSecuritycenterV2ResourceApplicationAttributes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ResourceApplicationAttributes
Returns a new instance of GoogleCloudSecuritycenterV2ResourceApplicationAttributes.
10279 10280 10281 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10279 def initialize(**args) update!(**args) end |
Instance Attribute Details
#business_owners ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesContactInfo>
Business team that ensures user needs are met and value is delivered
Corresponds to the JSON property businessOwners
10257 10258 10259 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10257 def business_owners @business_owners end |
#criticality ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesCriticality
Criticality of the Application, Service, or Workload
Corresponds to the JSON property criticality
10262 10263 10264 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10262 def criticality @criticality end |
#developer_owners ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesContactInfo>
Developer team that owns development and coding.
Corresponds to the JSON property developerOwners
10267 10268 10269 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10267 def developer_owners @developer_owners end |
#environment ⇒ Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesEnvironment
Environment of the Application, Service, or Workload
Corresponds to the JSON property environment
10272 10273 10274 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10272 def environment @environment end |
#operator_owners ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesContactInfo>
Operator team that ensures runtime and operations.
Corresponds to the JSON property operatorOwners
10277 10278 10279 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10277 def operator_owners @operator_owners end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10284 10285 10286 10287 10288 10289 10290 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10284 def update!(**args) @business_owners = args[:business_owners] if args.key?(:business_owners) @criticality = args[:criticality] if args.key?(:criticality) @developer_owners = args[:developer_owners] if args.key?(:developer_owners) @environment = args[:environment] if args.key?(:environment) @operator_owners = args[:operator_owners] if args.key?(:operator_owners) end |