Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2ResourceApplicationAttributes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Consumer provided attributes for the application

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2ResourceApplicationAttributes

Returns a new instance of GoogleCloudSecuritycenterV2ResourceApplicationAttributes.



9854
9855
9856
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9854

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#business_ownersArray<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesContactInfo>

Business team that ensures user needs are met and value is delivered Corresponds to the JSON property businessOwners



9832
9833
9834
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9832

def business_owners
  @business_owners
end

#criticalityGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesCriticality

Criticality of the Application, Service, or Workload Corresponds to the JSON property criticality



9837
9838
9839
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9837

def criticality
  @criticality
end

#developer_ownersArray<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesContactInfo>

Developer team that owns development and coding. Corresponds to the JSON property developerOwners



9842
9843
9844
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9842

def developer_owners
  @developer_owners
end

#environmentGoogle::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesEnvironment

Environment of the Application, Service, or Workload Corresponds to the JSON property environment



9847
9848
9849
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9847

def environment
  @environment
end

#operator_ownersArray<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2ResourceApplicationAttributesContactInfo>

Operator team that ensures runtime and operations. Corresponds to the JSON property operatorOwners



9852
9853
9854
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9852

def operator_owners
  @operator_owners
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9859
9860
9861
9862
9863
9864
9865
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 9859

def update!(**args)
  @business_owners = args[:business_owners] if args.key?(:business_owners)
  @criticality = args[:criticality] if args.key?(:criticality)
  @developer_owners = args[:developer_owners] if args.key?(:developer_owners)
  @environment = args[:environment] if args.key?(:environment)
  @operator_owners = args[:operator_owners] if args.key?(:operator_owners)
end