Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2SensitiveDataProtectionMapping
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2SensitiveDataProtectionMapping
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Resource value mapping for Sensitive Data Protection findings If any of these mappings have a resource value that is not unspecified, the resource_value field will be ignored when reading this configuration.
Instance Attribute Summary collapse
-
#high_sensitivity_mapping ⇒ String
Resource value mapping for high-sensitivity Sensitive Data Protection findings Corresponds to the JSON property
highSensitivityMapping. -
#medium_sensitivity_mapping ⇒ String
Resource value mapping for medium-sensitivity Sensitive Data Protection findings Corresponds to the JSON property
mediumSensitivityMapping.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2SensitiveDataProtectionMapping
constructor
A new instance of GoogleCloudSecuritycenterV2SensitiveDataProtectionMapping.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSecuritycenterV2SensitiveDataProtectionMapping
Returns a new instance of GoogleCloudSecuritycenterV2SensitiveDataProtectionMapping.
10837 10838 10839 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10837 def initialize(**args) update!(**args) end |
Instance Attribute Details
#high_sensitivity_mapping ⇒ String
Resource value mapping for high-sensitivity Sensitive Data Protection findings
Corresponds to the JSON property highSensitivityMapping
10829 10830 10831 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10829 def high_sensitivity_mapping @high_sensitivity_mapping end |
#medium_sensitivity_mapping ⇒ String
Resource value mapping for medium-sensitivity Sensitive Data Protection
findings
Corresponds to the JSON property mediumSensitivityMapping
10835 10836 10837 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10835 def medium_sensitivity_mapping @medium_sensitivity_mapping end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10842 10843 10844 10845 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10842 def update!(**args) @high_sensitivity_mapping = args[:high_sensitivity_mapping] if args.key?(:high_sensitivity_mapping) @medium_sensitivity_mapping = args[:medium_sensitivity_mapping] if args.key?(:medium_sensitivity_mapping) end |