Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2SensitivityScore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2SensitivityScore

Returns a new instance of GoogleCloudSecuritycenterV2SensitivityScore.



10433
10434
10435
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10433

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#scoreString

The sensitivity score applied to the resource. Corresponds to the JSON property score

Returns:

  • (String)


10431
10432
10433
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10431

def score
  @score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10438
10439
10440
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10438

def update!(**args)
  @score = args[:score] if args.key?(:score)
end