Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2TicketInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Information about the ticket, if any, that is being used to track the resolution of the issue that is identified by this finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2TicketInfo

Returns a new instance of GoogleCloudSecuritycenterV2TicketInfo.



10849
10850
10851
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10849

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigneeString

The assignee of the ticket in the ticket system. Corresponds to the JSON property assignee

Returns:

  • (String)


10822
10823
10824
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10822

def assignee
  @assignee
end

#descriptionString

The description of the ticket in the ticket system. Corresponds to the JSON property description

Returns:

  • (String)


10827
10828
10829
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10827

def description
  @description
end

#idString

The identifier of the ticket in the ticket system. Corresponds to the JSON property id

Returns:

  • (String)


10832
10833
10834
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10832

def id
  @id
end

#statusString

The latest status of the ticket, as reported by the ticket system. Corresponds to the JSON property status

Returns:

  • (String)


10837
10838
10839
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10837

def status
  @status
end

#update_timeString

The time when the ticket was last updated, as reported by the ticket system. Corresponds to the JSON property updateTime

Returns:

  • (String)


10842
10843
10844
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10842

def update_time
  @update_time
end

#uriString

The link to the ticket in the ticket system. Corresponds to the JSON property uri

Returns:

  • (String)


10847
10848
10849
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10847

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10854
10855
10856
10857
10858
10859
10860
10861
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10854

def update!(**args)
  @assignee = args[:assignee] if args.key?(:assignee)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @status = args[:status] if args.key?(:status)
  @update_time = args[:update_time] if args.key?(:update_time)
  @uri = args[:uri] if args.key?(:uri)
end