Class: Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV2TicketInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Information about the ticket, if any, that is being used to track the resolution of the issue that is identified by this finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSecuritycenterV2TicketInfo

Returns a new instance of GoogleCloudSecuritycenterV2TicketInfo.



10568
10569
10570
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10568

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigneeString

The assignee of the ticket in the ticket system. Corresponds to the JSON property assignee

Returns:

  • (String)


10541
10542
10543
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10541

def assignee
  @assignee
end

#descriptionString

The description of the ticket in the ticket system. Corresponds to the JSON property description

Returns:

  • (String)


10546
10547
10548
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10546

def description
  @description
end

#idString

The identifier of the ticket in the ticket system. Corresponds to the JSON property id

Returns:

  • (String)


10551
10552
10553
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10551

def id
  @id
end

#statusString

The latest status of the ticket, as reported by the ticket system. Corresponds to the JSON property status

Returns:

  • (String)


10556
10557
10558
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10556

def status
  @status
end

#update_timeString

The time when the ticket was last updated, as reported by the ticket system. Corresponds to the JSON property updateTime

Returns:

  • (String)


10561
10562
10563
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10561

def update_time
  @update_time
end

#uriString

The link to the ticket in the ticket system. Corresponds to the JSON property uri

Returns:

  • (String)


10566
10567
10568
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10566

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10573
10574
10575
10576
10577
10578
10579
10580
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 10573

def update!(**args)
  @assignee = args[:assignee] if args.key?(:assignee)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @status = args[:status] if args.key?(:status)
  @update_time = args[:update_time] if args.key?(:update_time)
  @uri = args[:uri] if args.key?(:uri)
end