Class: Google::Apis::SecuritycenterV1beta1::InfoType
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::InfoType
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Type of information detected by the API.
Instance Attribute Summary collapse
-
#name ⇒ String
Name of the information type.
-
#sensitivity_score ⇒ Google::Apis::SecuritycenterV1beta1::SensitivityScore
Score is calculated from of all elements in the data profile.
-
#version ⇒ String
Optional version name for this InfoType.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InfoType
constructor
A new instance of InfoType.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InfoType
Returns a new instance of InfoType.
11084 11085 11086 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11084 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Name of the information type. Either a name of your choosing when creating a
CustomInfoType, or one of the names listed at https://cloud.google.com/
sensitive-data-protection/docs/infotypes-reference when specifying a built-in
type. When sending Cloud DLP results to Data Catalog, infoType names should
conform to the pattern [A-Za-z0-9$_-]1,64`.
Corresponds to the JSON propertyname`
11071 11072 11073 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11071 def name @name end |
#sensitivity_score ⇒ Google::Apis::SecuritycenterV1beta1::SensitivityScore
Score is calculated from of all elements in the data profile. A higher level
means the data is more sensitive.
Corresponds to the JSON property sensitivityScore
11077 11078 11079 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11077 def sensitivity_score @sensitivity_score end |
#version ⇒ String
Optional version name for this InfoType.
Corresponds to the JSON property version
11082 11083 11084 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11082 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11089 11090 11091 11092 11093 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11089 def update!(**args) @name = args[:name] if args.key?(:name) @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score) @version = args[:version] if args.key?(:version) end |