Class: Google::Apis::SecuritycenterV1beta1::IpRules

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

IP rules associated with the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IpRules

Returns a new instance of IpRules.



11165
11166
11167
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11165

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowedGoogle::Apis::SecuritycenterV1beta1::Allowed

Allowed IP rule. Corresponds to the JSON property allowed



11132
11133
11134
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11132

def allowed
  @allowed
end

#deniedGoogle::Apis::SecuritycenterV1beta1::Denied

Denied IP rule. Corresponds to the JSON property denied



11137
11138
11139
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11137

def denied
  @denied
end

#destination_ip_rangesArray<String>

If destination IP ranges are specified, the firewall rule applies only to traffic that has a destination IP address in these ranges. These ranges must be expressed in CIDR format. Only supports IPv4. Corresponds to the JSON property destinationIpRanges

Returns:

  • (Array<String>)


11144
11145
11146
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11144

def destination_ip_ranges
  @destination_ip_ranges
end

#directionString

The direction that the rule is applicable to, one of ingress or egress. Corresponds to the JSON property direction

Returns:

  • (String)


11149
11150
11151
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11149

def direction
  @direction
end

#exposed_servicesArray<String>

Name of the network protocol service, such as FTP, that is exposed by the open port. Follows the naming convention available at: https://www.iana.org/ assignments/service-names-port-numbers/service-names-port-numbers.xhtml. Corresponds to the JSON property exposedServices

Returns:

  • (Array<String>)


11156
11157
11158
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11156

def exposed_services
  @exposed_services
end

#source_ip_rangesArray<String>

If source IP ranges are specified, the firewall rule applies only to traffic that has a source IP address in these ranges. These ranges must be expressed in CIDR format. Only supports IPv4. Corresponds to the JSON property sourceIpRanges

Returns:

  • (Array<String>)


11163
11164
11165
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11163

def source_ip_ranges
  @source_ip_ranges
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11170
11171
11172
11173
11174
11175
11176
11177
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11170

def update!(**args)
  @allowed = args[:allowed] if args.key?(:allowed)
  @denied = args[:denied] if args.key?(:denied)
  @destination_ip_ranges = args[:destination_ip_ranges] if args.key?(:destination_ip_ranges)
  @direction = args[:direction] if args.key?(:direction)
  @exposed_services = args[:exposed_services] if args.key?(:exposed_services)
  @source_ip_ranges = args[:source_ip_ranges] if args.key?(:source_ip_ranges)
end