Class: Google::Apis::SecuritycenterV1beta1::Job

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Describes a job

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Job

Returns a new instance of Job.



11204
11205
11206
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11204

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_codeFixnum

Optional. If the job did not complete successfully, this field describes why. Corresponds to the JSON property errorCode

Returns:

  • (Fixnum)


11187
11188
11189
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11187

def error_code
  @error_code
end

#locationString

Optional. Gives the location where the job ran, such as US or europe-west1 Corresponds to the JSON property location

Returns:

  • (String)


11192
11193
11194
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11192

def location
  @location
end

#nameString

The fully-qualified name for a job. e.g. projects//jobs/ Corresponds to the JSON property name

Returns:

  • (String)


11197
11198
11199
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11197

def name
  @name
end

#stateString

Output only. State of the job, such as RUNNING or PENDING. Corresponds to the JSON property state

Returns:

  • (String)


11202
11203
11204
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11202

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11209
11210
11211
11212
11213
11214
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11209

def update!(**args)
  @error_code = args[:error_code] if args.key?(:error_code)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
end