Class: Google::Apis::SecuritycenterV1beta1::Kubernetes
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::Kubernetes
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Kubernetes-related attributes.
Instance Attribute Summary collapse
-
#access_reviews ⇒ Array<Google::Apis::SecuritycenterV1beta1::AccessReview>
Provides information on any Kubernetes access reviews (privilege checks) relevant to the finding.
-
#bindings ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1Binding>
Provides Kubernetes role binding information for findings that involve RoleBindings or ClusterRoleBindings.
-
#node_pools ⇒ Array<Google::Apis::SecuritycenterV1beta1::NodePool>
GKE node pools associated with the finding.
-
#nodes ⇒ Array<Google::Apis::SecuritycenterV1beta1::Node>
Provides Kubernetes node information.
-
#objects ⇒ Array<Google::Apis::SecuritycenterV1beta1::Object>
Kubernetes objects related to the finding.
-
#pods ⇒ Array<Google::Apis::SecuritycenterV1beta1::Pod>
Kubernetes Pods associated with the finding.
-
#roles ⇒ Array<Google::Apis::SecuritycenterV1beta1::Role>
Provides Kubernetes role information for findings that involve Roles or ClusterRoles.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Kubernetes
constructor
A new instance of Kubernetes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Kubernetes
Returns a new instance of Kubernetes.
11628 11629 11630 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11628 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_reviews ⇒ Array<Google::Apis::SecuritycenterV1beta1::AccessReview>
Provides information on any Kubernetes access reviews (privilege checks)
relevant to the finding.
Corresponds to the JSON property accessReviews
11587 11588 11589 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11587 def access_reviews @access_reviews end |
#bindings ⇒ Array<Google::Apis::SecuritycenterV1beta1::GoogleCloudSecuritycenterV1Binding>
Provides Kubernetes role binding information for findings that involve
RoleBindings or ClusterRoleBindings.
Corresponds to the JSON property bindings
11594 11595 11596 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11594 def bindings @bindings end |
#node_pools ⇒ Array<Google::Apis::SecuritycenterV1beta1::NodePool>
GKE node pools associated with the finding. This field contains node pool information
for each node, when it is available.
Corresponds to the JSON property nodePools
11601 11602 11603 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11601 def node_pools @node_pools end |
#nodes ⇒ Array<Google::Apis::SecuritycenterV1beta1::Node>
Provides Kubernetes node information.
Corresponds to the JSON property nodes
11607 11608 11609 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11607 def nodes @nodes end |
#objects ⇒ Array<Google::Apis::SecuritycenterV1beta1::Object>
Kubernetes objects related to the finding.
Corresponds to the JSON property objects
11612 11613 11614 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11612 def objects @objects end |
#pods ⇒ Array<Google::Apis::SecuritycenterV1beta1::Pod>
Kubernetes Pods
associated with the finding. This field contains Pod records for each
container that is owned by a Pod.
Corresponds to the JSON property pods
11619 11620 11621 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11619 def pods @pods end |
#roles ⇒ Array<Google::Apis::SecuritycenterV1beta1::Role>
Provides Kubernetes role information for findings that involve Roles or
ClusterRoles.
Corresponds to the JSON property roles
11626 11627 11628 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11626 def roles @roles end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11633 11634 11635 11636 11637 11638 11639 11640 11641 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11633 def update!(**args) @access_reviews = args[:access_reviews] if args.key?(:access_reviews) @bindings = args[:bindings] if args.key?(:bindings) @node_pools = args[:node_pools] if args.key?(:node_pools) @nodes = args[:nodes] if args.key?(:nodes) @objects = args[:objects] if args.key?(:objects) @pods = args[:pods] if args.key?(:pods) @roles = args[:roles] if args.key?(:roles) end |