Class: Google::Apis::SecuritycenterV1beta1::Notebook
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::Notebook
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Represents a Jupyter notebook IPYNB file, such as a Colab Enterprise notebook file, that is associated with a finding.
Instance Attribute Summary collapse
-
#last_author ⇒ String
The user ID of the latest author to modify the notebook.
-
#name ⇒ String
The name of the notebook.
-
#notebook_update_time ⇒ String
The most recent time the notebook was updated.
-
#service ⇒ String
The source notebook service, for example, "Colab Enterprise".
Instance Method Summary collapse
-
#initialize(**args) ⇒ Notebook
constructor
A new instance of Notebook.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Notebook
Returns a new instance of Notebook.
11790 11791 11792 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11790 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_author ⇒ String
The user ID of the latest author to modify the notebook.
Corresponds to the JSON property lastAuthor
11773 11774 11775 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11773 def @last_author end |
#name ⇒ String
The name of the notebook.
Corresponds to the JSON property name
11778 11779 11780 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11778 def name @name end |
#notebook_update_time ⇒ String
The most recent time the notebook was updated.
Corresponds to the JSON property notebookUpdateTime
11783 11784 11785 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11783 def notebook_update_time @notebook_update_time end |
#service ⇒ String
The source notebook service, for example, "Colab Enterprise".
Corresponds to the JSON property service
11788 11789 11790 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11788 def service @service end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11795 11796 11797 11798 11799 11800 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 11795 def update!(**args) @last_author = args[:last_author] if args.key?(:last_author) @name = args[:name] if args.key?(:name) @notebook_update_time = args[:notebook_update_time] if args.key?(:notebook_update_time) @service = args[:service] if args.key?(:service) end |