Class: Google::Apis::SecuritycenterV1beta1::Object

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Kubernetes object related to the finding, uniquely identified by GKNN. Used if the object Kind is not one of Pod, Node, NodePool, Binding, or AccessReview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Object

Returns a new instance of Object.



12117
12118
12119
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12117

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#containersArray<Google::Apis::SecuritycenterV1beta1::Container>

Pod containers associated with this finding, if any. Corresponds to the JSON property containers



12092
12093
12094
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12092

def containers
  @containers
end

#groupString

Kubernetes object group, such as "policy.k8s.io/v1". Corresponds to the JSON property group

Returns:

  • (String)


12097
12098
12099
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12097

def group
  @group
end

#kindString

Kubernetes object kind, such as "Namespace". Corresponds to the JSON property kind

Returns:

  • (String)


12102
12103
12104
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12102

def kind
  @kind
end

#nameString

Kubernetes object name. For details see https://kubernetes.io/docs/concepts/ overview/working-with-objects/names/. Corresponds to the JSON property name

Returns:

  • (String)


12108
12109
12110
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12108

def name
  @name
end

#nsString

Kubernetes object namespace. Must be a valid DNS label. Named "ns" to avoid collision with C++ namespace keyword. For details see https://kubernetes.io/ docs/tasks/administer-cluster/namespaces/. Corresponds to the JSON property ns

Returns:

  • (String)


12115
12116
12117
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12115

def ns
  @ns
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12122
12123
12124
12125
12126
12127
12128
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12122

def update!(**args)
  @containers = args[:containers] if args.key?(:containers)
  @group = args[:group] if args.key?(:group)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @ns = args[:ns] if args.key?(:ns)
end