Class: Google::Apis::SecuritycenterV1beta1::Process
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::Process
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Represents an operating system process.
Instance Attribute Summary collapse
-
#args ⇒ Array<String>
Process arguments as JSON encoded strings.
-
#arguments_truncated ⇒ Boolean
(also: #arguments_truncated?)
True if
argsis incomplete. -
#binary ⇒ Google::Apis::SecuritycenterV1beta1::File
File information about the related binary/library used by an executable, or the script used by a script interpreter Corresponds to the JSON property
binary. -
#env_variables ⇒ Array<Google::Apis::SecuritycenterV1beta1::EnvironmentVariable>
Process environment variables.
-
#env_variables_truncated ⇒ Boolean
(also: #env_variables_truncated?)
True if
env_variablesis incomplete. -
#libraries ⇒ Array<Google::Apis::SecuritycenterV1beta1::File>
File information for libraries loaded by the process.
-
#name ⇒ String
The process name, as displayed in utilities like
topandps. -
#parent_pid ⇒ Fixnum
The parent process ID.
-
#pid ⇒ Fixnum
The process ID.
-
#script ⇒ Google::Apis::SecuritycenterV1beta1::File
File information about the related binary/library used by an executable, or the script used by a script interpreter Corresponds to the JSON property
script. -
#user_id ⇒ Fixnum
The ID of the user that executed the process.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Process
constructor
A new instance of Process.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Process
Returns a new instance of Process.
12291 12292 12293 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12291 def initialize(**args) update!(**args) end |
Instance Attribute Details
#args ⇒ Array<String>
Process arguments as JSON encoded strings.
Corresponds to the JSON property args
12233 12234 12235 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12233 def args @args end |
#arguments_truncated ⇒ Boolean Also known as: arguments_truncated?
True if args is incomplete.
Corresponds to the JSON property argumentsTruncated
12238 12239 12240 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12238 def arguments_truncated @arguments_truncated end |
#binary ⇒ Google::Apis::SecuritycenterV1beta1::File
File information about the related binary/library used by an executable, or
the script used by a script interpreter
Corresponds to the JSON property binary
12245 12246 12247 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12245 def binary @binary end |
#env_variables ⇒ Array<Google::Apis::SecuritycenterV1beta1::EnvironmentVariable>
Process environment variables.
Corresponds to the JSON property envVariables
12250 12251 12252 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12250 def env_variables @env_variables end |
#env_variables_truncated ⇒ Boolean Also known as: env_variables_truncated?
True if env_variables is incomplete.
Corresponds to the JSON property envVariablesTruncated
12255 12256 12257 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12255 def env_variables_truncated @env_variables_truncated end |
#libraries ⇒ Array<Google::Apis::SecuritycenterV1beta1::File>
File information for libraries loaded by the process.
Corresponds to the JSON property libraries
12261 12262 12263 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12261 def libraries @libraries end |
#name ⇒ String
The process name, as displayed in utilities like top and ps. This name can
be accessed through /proc/[pid]/comm and changed with prctl(PR_SET_NAME).
Corresponds to the JSON property name
12267 12268 12269 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12267 def name @name end |
#parent_pid ⇒ Fixnum
The parent process ID.
Corresponds to the JSON property parentPid
12272 12273 12274 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12272 def parent_pid @parent_pid end |
#pid ⇒ Fixnum
The process ID.
Corresponds to the JSON property pid
12277 12278 12279 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12277 def pid @pid end |
#script ⇒ Google::Apis::SecuritycenterV1beta1::File
File information about the related binary/library used by an executable, or
the script used by a script interpreter
Corresponds to the JSON property script
12283 12284 12285 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12283 def script @script end |
#user_id ⇒ Fixnum
The ID of the user that executed the process. E.g. If this is the root user
this will always be 0.
Corresponds to the JSON property userId
12289 12290 12291 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12289 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12296 12297 12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12296 def update!(**args) @args = args[:args] if args.key?(:args) @arguments_truncated = args[:arguments_truncated] if args.key?(:arguments_truncated) @binary = args[:binary] if args.key?(:binary) @env_variables = args[:env_variables] if args.key?(:env_variables) @env_variables_truncated = args[:env_variables_truncated] if args.key?(:env_variables_truncated) @libraries = args[:libraries] if args.key?(:libraries) @name = args[:name] if args.key?(:name) @parent_pid = args[:parent_pid] if args.key?(:parent_pid) @pid = args[:pid] if args.key?(:pid) @script = args[:script] if args.key?(:script) @user_id = args[:user_id] if args.key?(:user_id) end |