Class: Google::Apis::SecuritycenterV1beta1::Requests
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::Requests
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Information about the requests relevant to the finding.
Instance Attribute Summary collapse
-
#long_term_allowed ⇒ Fixnum
Allowed RPS (requests per second) over the long term.
-
#long_term_denied ⇒ Fixnum
Denied RPS (requests per second) over the long term.
-
#ratio ⇒ Float
For 'Increasing deny ratio', the ratio is the denied traffic divided by the allowed traffic.
-
#short_term_allowed ⇒ Fixnum
Allowed RPS (requests per second) in the short term.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Requests
constructor
A new instance of Requests.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Requests
Returns a new instance of Requests.
12718 12719 12720 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12718 def initialize(**args) update!(**args) end |
Instance Attribute Details
#long_term_allowed ⇒ Fixnum
Allowed RPS (requests per second) over the long term.
Corresponds to the JSON property longTermAllowed
12699 12700 12701 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12699 def long_term_allowed @long_term_allowed end |
#long_term_denied ⇒ Fixnum
Denied RPS (requests per second) over the long term.
Corresponds to the JSON property longTermDenied
12704 12705 12706 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12704 def long_term_denied @long_term_denied end |
#ratio ⇒ Float
For 'Increasing deny ratio', the ratio is the denied traffic divided by the
allowed traffic. For 'Allowed traffic spike', the ratio is the allowed traffic
in the short term divided by allowed traffic in the long term.
Corresponds to the JSON property ratio
12711 12712 12713 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12711 def ratio @ratio end |
#short_term_allowed ⇒ Fixnum
Allowed RPS (requests per second) in the short term.
Corresponds to the JSON property shortTermAllowed
12716 12717 12718 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12716 def short_term_allowed @short_term_allowed end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12723 12724 12725 12726 12727 12728 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12723 def update!(**args) @long_term_allowed = args[:long_term_allowed] if args.key?(:long_term_allowed) @long_term_denied = args[:long_term_denied] if args.key?(:long_term_denied) @ratio = args[:ratio] if args.key?(:ratio) @short_term_allowed = args[:short_term_allowed] if args.key?(:short_term_allowed) end |