Class: Google::Apis::SecuritycenterV1beta1::SecretEnvironmentVariable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Environment variable containing the secret.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecretEnvironmentVariable

Returns a new instance of SecretEnvironmentVariable.



12552
12553
12554
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12552

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

Environment variable name as a JSON encoded string. Note that value is not included since the value contains the secret data, which is sensitive core content. Corresponds to the JSON property key

Returns:

  • (String)


12550
12551
12552
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12550

def key
  @key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12557
12558
12559
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12557

def update!(**args)
  @key = args[:key] if args.key?(:key)
end