Class: Google::Apis::SecuritycenterV1beta1::SecurityCenterProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb

Overview

Security Command Center managed properties. These properties are managed by Security Command Center and cannot be modified by the user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityCenterProperties

Returns a new instance of SecurityCenterProperties.



12674
12675
12676
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12674

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_nameString

Immutable. The full resource name of the Google Cloud resource this asset represents. This field is immutable after create time. See: https://cloud. google.com/apis/design/resource_names#full_resource_name Corresponds to the JSON property resourceName

Returns:

  • (String)


12648
12649
12650
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12648

def resource_name
  @resource_name
end

#resource_ownersArray<String>

Owners of the Google Cloud resource. Corresponds to the JSON property resourceOwners

Returns:

  • (Array<String>)


12653
12654
12655
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12653

def resource_owners
  @resource_owners
end

#resource_parentString

The full resource name of the immediate parent of the resource. See: https:// cloud.google.com/apis/design/resource_names#full_resource_name Corresponds to the JSON property resourceParent

Returns:

  • (String)


12659
12660
12661
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12659

def resource_parent
  @resource_parent
end

#resource_projectString

The full resource name of the project the resource belongs to. See: https:// cloud.google.com/apis/design/resource_names#full_resource_name Corresponds to the JSON property resourceProject

Returns:

  • (String)


12665
12666
12667
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12665

def resource_project
  @resource_project
end

#resource_typeString

The type of the Google Cloud resource. Examples include: APPLICATION, PROJECT, and ORGANIZATION. This is a case insensitive field defined by Security Command Center and/or the producer of the resource and is immutable after create time. Corresponds to the JSON property resourceType

Returns:

  • (String)


12672
12673
12674
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12672

def resource_type
  @resource_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12679
12680
12681
12682
12683
12684
12685
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 12679

def update!(**args)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @resource_owners = args[:resource_owners] if args.key?(:resource_owners)
  @resource_parent = args[:resource_parent] if args.key?(:resource_parent)
  @resource_project = args[:resource_project] if args.key?(:resource_project)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
end