Class: Google::Apis::SecuritycenterV1beta1::TicketInfo
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::TicketInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Information about the ticket, if any, that is being used to track the resolution of the issue that is identified by this finding.
Instance Attribute Summary collapse
-
#assignee ⇒ String
The assignee of the ticket in the ticket system.
-
#description ⇒ String
The description of the ticket in the ticket system.
-
#id ⇒ String
The identifier of the ticket in the ticket system.
-
#status ⇒ String
The latest status of the ticket, as reported by the ticket system.
-
#update_time ⇒ String
The time when the ticket was last updated, as reported by the ticket system.
-
#uri ⇒ String
The link to the ticket in the ticket system.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TicketInfo
constructor
A new instance of TicketInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TicketInfo
Returns a new instance of TicketInfo.
13508 13509 13510 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13508 def initialize(**args) update!(**args) end |
Instance Attribute Details
#assignee ⇒ String
The assignee of the ticket in the ticket system.
Corresponds to the JSON property assignee
13481 13482 13483 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13481 def assignee @assignee end |
#description ⇒ String
The description of the ticket in the ticket system.
Corresponds to the JSON property description
13486 13487 13488 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13486 def description @description end |
#id ⇒ String
The identifier of the ticket in the ticket system.
Corresponds to the JSON property id
13491 13492 13493 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13491 def id @id end |
#status ⇒ String
The latest status of the ticket, as reported by the ticket system.
Corresponds to the JSON property status
13496 13497 13498 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13496 def status @status end |
#update_time ⇒ String
The time when the ticket was last updated, as reported by the ticket system.
Corresponds to the JSON property updateTime
13501 13502 13503 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13501 def update_time @update_time end |
#uri ⇒ String
The link to the ticket in the ticket system.
Corresponds to the JSON property uri
13506 13507 13508 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13506 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13513 13514 13515 13516 13517 13518 13519 13520 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13513 def update!(**args) @assignee = args[:assignee] if args.key?(:assignee) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @status = args[:status] if args.key?(:status) @update_time = args[:update_time] if args.key?(:update_time) @uri = args[:uri] if args.key?(:uri) end |