Class: Google::Apis::SecuritycenterV1beta1::TicketInfo
- Inherits:
-
Object
- Object
- Google::Apis::SecuritycenterV1beta1::TicketInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/securitycenter_v1beta1/classes.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb,
lib/google/apis/securitycenter_v1beta1/representations.rb
Overview
Information about the ticket, if any, that is being used to track the resolution of the issue that is identified by this finding.
Instance Attribute Summary collapse
-
#assignee ⇒ String
The assignee of the ticket in the ticket system.
-
#description ⇒ String
The description of the ticket in the ticket system.
-
#id ⇒ String
The identifier of the ticket in the ticket system.
-
#status ⇒ String
The latest status of the ticket, as reported by the ticket system.
-
#update_time ⇒ String
The time when the ticket was last updated, as reported by the ticket system.
-
#uri ⇒ String
The link to the ticket in the ticket system.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TicketInfo
constructor
A new instance of TicketInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TicketInfo
Returns a new instance of TicketInfo.
13184 13185 13186 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13184 def initialize(**args) update!(**args) end |
Instance Attribute Details
#assignee ⇒ String
The assignee of the ticket in the ticket system.
Corresponds to the JSON property assignee
13157 13158 13159 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13157 def assignee @assignee end |
#description ⇒ String
The description of the ticket in the ticket system.
Corresponds to the JSON property description
13162 13163 13164 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13162 def description @description end |
#id ⇒ String
The identifier of the ticket in the ticket system.
Corresponds to the JSON property id
13167 13168 13169 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13167 def id @id end |
#status ⇒ String
The latest status of the ticket, as reported by the ticket system.
Corresponds to the JSON property status
13172 13173 13174 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13172 def status @status end |
#update_time ⇒ String
The time when the ticket was last updated, as reported by the ticket system.
Corresponds to the JSON property updateTime
13177 13178 13179 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13177 def update_time @update_time end |
#uri ⇒ String
The link to the ticket in the ticket system.
Corresponds to the JSON property uri
13182 13183 13184 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13182 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13189 13190 13191 13192 13193 13194 13195 13196 |
# File 'lib/google/apis/securitycenter_v1beta1/classes.rb', line 13189 def update!(**args) @assignee = args[:assignee] if args.key?(:assignee) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @status = args[:status] if args.key?(:status) @update_time = args[:update_time] if args.key?(:update_time) @uri = args[:uri] if args.key?(:uri) end |